from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Graphics.Gdi
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.Diagnostics.Debug
import win32more.Windows.Win32.System.SystemServices
ACCESS_REASON_TYPE = Int32
AccessReasonNone: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 0
AccessReasonAllowedAce: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 65536
AccessReasonDeniedAce: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 131072
AccessReasonAllowedParentAce: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 196608
AccessReasonDeniedParentAce: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 262144
AccessReasonNotGrantedByCape: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 327680
AccessReasonNotGrantedByParentCape: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 393216
AccessReasonNotGrantedToAppContainer: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 458752
AccessReasonMissingPrivilege: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 1048576
AccessReasonFromPrivilege: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 2097152
AccessReasonIntegrityLevel: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 3145728
AccessReasonOwnership: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 4194304
AccessReasonNullDacl: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 5242880
AccessReasonEmptyDacl: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 6291456
AccessReasonNoSD: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 7340032
AccessReasonNoGrant: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 8388608
AccessReasonTrustLabel: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 9437184
AccessReasonFilterAce: win32more.Windows.Win32.System.SystemServices.ACCESS_REASON_TYPE = 10485760
ACTIVATION_CONTEXT_INFO_CLASS = Int32
ActivationContextBasicInformation: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 1
ActivationContextDetailedInformation: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 2
AssemblyDetailedInformationInActivationContext: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 3
FileInformationInAssemblyOfAssemblyInActivationContext: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 4
RunlevelInformationInActivationContext: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 5
CompatibilityInformationInActivationContext: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 6
ActivationContextManifestResourceName: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 7
MaxActivationContextInfoClass: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 8
AssemblyDetailedInformationInActivationContxt: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 3
FileInformationInAssemblyOfAssemblyInActivationContxt: win32more.Windows.Win32.System.SystemServices.ACTIVATION_CONTEXT_INFO_CLASS = 4
ALERT_SYSTEM_SEV = UInt32
ALERT_SYSTEM_INFORMATIONAL: win32more.Windows.Win32.System.SystemServices.ALERT_SYSTEM_SEV = 1
ALERT_SYSTEM_WARNING: win32more.Windows.Win32.System.SystemServices.ALERT_SYSTEM_SEV = 2
ALERT_SYSTEM_ERROR: win32more.Windows.Win32.System.SystemServices.ALERT_SYSTEM_SEV = 3
ALERT_SYSTEM_QUERY: win32more.Windows.Win32.System.SystemServices.ALERT_SYSTEM_SEV = 4
ALERT_SYSTEM_CRITICAL: win32more.Windows.Win32.System.SystemServices.ALERT_SYSTEM_SEV = 5
class ANON_OBJECT_HEADER(Structure):
    Sig1: UInt16
    Sig2: UInt16
    Version: UInt16
    Machine: UInt16
    TimeDateStamp: UInt32
    ClassID: Guid
    SizeOfData: UInt32
class ANON_OBJECT_HEADER_BIGOBJ(Structure):
    Sig1: UInt16
    Sig2: UInt16
    Version: UInt16
    Machine: UInt16
    TimeDateStamp: UInt32
    ClassID: Guid
    SizeOfData: UInt32
    Flags: UInt32
    MetaDataSize: UInt32
    MetaDataOffset: UInt32
    NumberOfSections: UInt32
    PointerToSymbolTable: UInt32
    NumberOfSymbols: UInt32
class ANON_OBJECT_HEADER_V2(Structure):
    Sig1: UInt16
    Sig2: UInt16
    Version: UInt16
    Machine: UInt16
    TimeDateStamp: UInt32
    ClassID: Guid
    SizeOfData: UInt32
    Flags: UInt32
    MetaDataSize: UInt32
    MetaDataOffset: UInt32
APPCOMMAND_ID = UInt32
APPCOMMAND_BROWSER_BACKWARD: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 1
APPCOMMAND_BROWSER_FORWARD: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 2
APPCOMMAND_BROWSER_REFRESH: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 3
APPCOMMAND_BROWSER_STOP: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 4
APPCOMMAND_BROWSER_SEARCH: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 5
APPCOMMAND_BROWSER_FAVORITES: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 6
APPCOMMAND_BROWSER_HOME: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 7
APPCOMMAND_VOLUME_MUTE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 8
APPCOMMAND_VOLUME_DOWN: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 9
APPCOMMAND_VOLUME_UP: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 10
APPCOMMAND_MEDIA_NEXTTRACK: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 11
APPCOMMAND_MEDIA_PREVIOUSTRACK: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 12
APPCOMMAND_MEDIA_STOP: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 13
APPCOMMAND_MEDIA_PLAY_PAUSE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 14
APPCOMMAND_LAUNCH_MAIL: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 15
APPCOMMAND_LAUNCH_MEDIA_SELECT: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 16
APPCOMMAND_LAUNCH_APP1: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 17
APPCOMMAND_LAUNCH_APP2: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 18
APPCOMMAND_BASS_DOWN: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 19
APPCOMMAND_BASS_BOOST: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 20
APPCOMMAND_BASS_UP: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 21
APPCOMMAND_TREBLE_DOWN: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 22
APPCOMMAND_TREBLE_UP: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 23
APPCOMMAND_MICROPHONE_VOLUME_MUTE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 24
APPCOMMAND_MICROPHONE_VOLUME_DOWN: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 25
APPCOMMAND_MICROPHONE_VOLUME_UP: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 26
APPCOMMAND_HELP: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 27
APPCOMMAND_FIND: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 28
APPCOMMAND_NEW: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 29
APPCOMMAND_OPEN: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 30
APPCOMMAND_CLOSE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 31
APPCOMMAND_SAVE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 32
APPCOMMAND_PRINT: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 33
APPCOMMAND_UNDO: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 34
APPCOMMAND_REDO: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 35
APPCOMMAND_COPY: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 36
APPCOMMAND_CUT: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 37
APPCOMMAND_PASTE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 38
APPCOMMAND_REPLY_TO_MAIL: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 39
APPCOMMAND_FORWARD_MAIL: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 40
APPCOMMAND_SEND_MAIL: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 41
APPCOMMAND_SPELL_CHECK: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 42
APPCOMMAND_DICTATE_OR_COMMAND_CONTROL_TOGGLE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 43
APPCOMMAND_MIC_ON_OFF_TOGGLE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 44
APPCOMMAND_CORRECTION_LIST: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 45
APPCOMMAND_MEDIA_PLAY: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 46
APPCOMMAND_MEDIA_PAUSE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 47
APPCOMMAND_MEDIA_RECORD: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 48
APPCOMMAND_MEDIA_FAST_FORWARD: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 49
APPCOMMAND_MEDIA_REWIND: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 50
APPCOMMAND_MEDIA_CHANNEL_UP: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 51
APPCOMMAND_MEDIA_CHANNEL_DOWN: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 52
APPCOMMAND_DELETE: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 53
APPCOMMAND_DWM_FLIP3D: win32more.Windows.Win32.System.SystemServices.APPCOMMAND_ID = 54
class APPLICATIONLAUNCH_SETTING_VALUE(Structure):
    ActivationTime: Int64
    Flags: UInt32
    ButtonInstanceID: UInt32
ARM64_FNPDATA_CR = Int32
PdataCrUnchained: win32more.Windows.Win32.System.SystemServices.ARM64_FNPDATA_CR = 0
PdataCrUnchainedSavedLr: win32more.Windows.Win32.System.SystemServices.ARM64_FNPDATA_CR = 1
PdataCrChainedWithPac: win32more.Windows.Win32.System.SystemServices.ARM64_FNPDATA_CR = 2
PdataCrChained: win32more.Windows.Win32.System.SystemServices.ARM64_FNPDATA_CR = 3
ARM64_FNPDATA_FLAGS = Int32
PdataRefToFullXdata: win32more.Windows.Win32.System.SystemServices.ARM64_FNPDATA_FLAGS = 0
PdataPackedUnwindFunction: win32more.Windows.Win32.System.SystemServices.ARM64_FNPDATA_FLAGS = 1
PdataPackedUnwindFragment: win32more.Windows.Win32.System.SystemServices.ARM64_FNPDATA_FLAGS = 2
ATF_FLAGS = UInt32
ATF_TIMEOUTON: win32more.Windows.Win32.System.SystemServices.ATF_FLAGS = 1
ATF_ONOFFFEEDBACK: win32more.Windows.Win32.System.SystemServices.ATF_FLAGS = 2
_MM_HINT_T0: UInt32 = 1
_MM_HINT_T1: UInt32 = 2
_MM_HINT_T2: UInt32 = 3
_MM_HINT_NTA: UInt32 = 0
ANYSIZE_ARRAY: UInt32 = 1
MEMORY_ALLOCATION_ALIGNMENT: UInt32 = 16
X86_CACHE_ALIGNMENT_SIZE: UInt32 = 64
ARM_CACHE_ALIGNMENT_SIZE: UInt32 = 128
SYSTEM_CACHE_ALIGNMENT_SIZE: UInt32 = 64
PRAGMA_DEPRECATED_DDK: UInt32 = 1
UCSCHAR_INVALID_CHARACTER: UInt32 = 4294967295
MIN_UCSCHAR: UInt32 = 0
MAX_UCSCHAR: UInt32 = 1114111
MAXIMUM_PROC_PER_GROUP: UInt32 = 64
MAXIMUM_PROCESSORS: UInt32 = 64
APPLICATION_ERROR_MASK: UInt32 = 536870912
ERROR_SEVERITY_SUCCESS: UInt32 = 0
ERROR_SEVERITY_INFORMATIONAL: UInt32 = 1073741824
ERROR_SEVERITY_WARNING: UInt32 = 2147483648
ERROR_SEVERITY_ERROR: UInt32 = 3221225472
MAXLONGLONG: UInt64 = 9223372036854775807
UNICODE_STRING_MAX_CHARS: UInt32 = 32767
MINCHAR: UInt32 = 128
MAXCHAR: UInt32 = 127
MINSHORT: UInt32 = 32768
MAXSHORT: UInt32 = 32767
MINLONG: UInt32 = 2147483648
MAXLONG: UInt32 = 2147483647
MAXBYTE: UInt32 = 255
MAXWORD: UInt32 = 65535
MAXDWORD: UInt32 = 4294967295
ENCLAVE_SHORT_ID_LENGTH: UInt32 = 16
ENCLAVE_LONG_ID_LENGTH: UInt32 = 32
VER_SERVER_NT: UInt32 = 2147483648
VER_WORKSTATION_NT: UInt32 = 1073741824
VER_SUITE_SMALLBUSINESS: UInt32 = 1
VER_SUITE_ENTERPRISE: UInt32 = 2
VER_SUITE_BACKOFFICE: UInt32 = 4
VER_SUITE_COMMUNICATIONS: UInt32 = 8
VER_SUITE_TERMINAL: UInt32 = 16
VER_SUITE_SMALLBUSINESS_RESTRICTED: UInt32 = 32
VER_SUITE_EMBEDDEDNT: UInt32 = 64
VER_SUITE_DATACENTER: UInt32 = 128
VER_SUITE_SINGLEUSERTS: UInt32 = 256
VER_SUITE_PERSONAL: UInt32 = 512
VER_SUITE_BLADE: UInt32 = 1024
VER_SUITE_EMBEDDED_RESTRICTED: UInt32 = 2048
VER_SUITE_SECURITY_APPLIANCE: UInt32 = 4096
VER_SUITE_STORAGE_SERVER: UInt32 = 8192
VER_SUITE_COMPUTE_SERVER: UInt32 = 16384
VER_SUITE_WH_SERVER: UInt32 = 32768
VER_SUITE_MULTIUSERTS: UInt32 = 131072
PRODUCT_STANDARD_SERVER_CORE: UInt32 = 13
PRODUCT_SOLUTION_EMBEDDEDSERVER_CORE: UInt32 = 57
PRODUCT_PROFESSIONAL_EMBEDDED: UInt32 = 58
PRODUCT_EMBEDDED: UInt32 = 65
PRODUCT_EMBEDDED_AUTOMOTIVE: UInt32 = 85
PRODUCT_EMBEDDED_INDUSTRY_A: UInt32 = 86
PRODUCT_THINPC: UInt32 = 87
PRODUCT_EMBEDDED_A: UInt32 = 88
PRODUCT_EMBEDDED_INDUSTRY: UInt32 = 89
PRODUCT_EMBEDDED_E: UInt32 = 90
PRODUCT_EMBEDDED_INDUSTRY_E: UInt32 = 91
PRODUCT_EMBEDDED_INDUSTRY_A_E: UInt32 = 92
PRODUCT_CORE_ARM: UInt32 = 97
PRODUCT_EMBEDDED_INDUSTRY_EVAL: UInt32 = 105
PRODUCT_EMBEDDED_INDUSTRY_E_EVAL: UInt32 = 106
PRODUCT_EMBEDDED_EVAL: UInt32 = 107
PRODUCT_EMBEDDED_E_EVAL: UInt32 = 108
PRODUCT_NANO_SERVER: UInt32 = 109
PRODUCT_CLOUD_STORAGE_SERVER: UInt32 = 110
PRODUCT_CORE_CONNECTED: UInt32 = 111
PRODUCT_PROFESSIONAL_STUDENT: UInt32 = 112
PRODUCT_CORE_CONNECTED_N: UInt32 = 113
PRODUCT_PROFESSIONAL_STUDENT_N: UInt32 = 114
PRODUCT_CORE_CONNECTED_SINGLELANGUAGE: UInt32 = 115
PRODUCT_CORE_CONNECTED_COUNTRYSPECIFIC: UInt32 = 116
PRODUCT_CONNECTED_CAR: UInt32 = 117
PRODUCT_INDUSTRY_HANDHELD: UInt32 = 118
PRODUCT_PPI_PRO: UInt32 = 119
PRODUCT_ARM64_SERVER: UInt32 = 120
PRODUCT_CLOUD_HOST_INFRASTRUCTURE_SERVER: UInt32 = 124
PRODUCT_PROFESSIONAL_S: UInt32 = 127
PRODUCT_PROFESSIONAL_S_N: UInt32 = 128
PRODUCT_HOLOGRAPHIC: UInt32 = 135
PRODUCT_HOLOGRAPHIC_BUSINESS: UInt32 = 136
PRODUCT_PRO_SINGLE_LANGUAGE: UInt32 = 138
PRODUCT_PRO_CHINA: UInt32 = 139
PRODUCT_ENTERPRISE_SUBSCRIPTION: UInt32 = 140
PRODUCT_ENTERPRISE_SUBSCRIPTION_N: UInt32 = 141
PRODUCT_DATACENTER_NANO_SERVER: UInt32 = 143
PRODUCT_STANDARD_NANO_SERVER: UInt32 = 144
PRODUCT_DATACENTER_WS_SERVER_CORE: UInt32 = 147
PRODUCT_STANDARD_WS_SERVER_CORE: UInt32 = 148
PRODUCT_UTILITY_VM: UInt32 = 149
PRODUCT_DATACENTER_EVALUATION_SERVER_CORE: UInt32 = 159
PRODUCT_STANDARD_EVALUATION_SERVER_CORE: UInt32 = 160
PRODUCT_PRO_FOR_EDUCATION: UInt32 = 164
PRODUCT_PRO_FOR_EDUCATION_N: UInt32 = 165
PRODUCT_AZURE_SERVER_CORE: UInt32 = 168
PRODUCT_AZURE_NANO_SERVER: UInt32 = 169
PRODUCT_ENTERPRISEG: UInt32 = 171
PRODUCT_ENTERPRISEGN: UInt32 = 172
PRODUCT_SERVERRDSH: UInt32 = 175
PRODUCT_CLOUD: UInt32 = 178
PRODUCT_CLOUDN: UInt32 = 179
PRODUCT_HUBOS: UInt32 = 180
PRODUCT_ONECOREUPDATEOS: UInt32 = 182
PRODUCT_CLOUDE: UInt32 = 183
PRODUCT_IOTOS: UInt32 = 185
PRODUCT_CLOUDEN: UInt32 = 186
PRODUCT_IOTEDGEOS: UInt32 = 187
PRODUCT_IOTENTERPRISE: UInt32 = 188
PRODUCT_LITE: UInt32 = 189
PRODUCT_IOTENTERPRISES: UInt32 = 191
PRODUCT_XBOX_SYSTEMOS: UInt32 = 192
PRODUCT_XBOX_GAMEOS: UInt32 = 194
PRODUCT_XBOX_ERAOS: UInt32 = 195
PRODUCT_XBOX_DURANGOHOSTOS: UInt32 = 196
PRODUCT_XBOX_SCARLETTHOSTOS: UInt32 = 197
PRODUCT_XBOX_KEYSTONE: UInt32 = 198
PRODUCT_AZURE_SERVER_CLOUDHOST: UInt32 = 199
PRODUCT_AZURE_SERVER_CLOUDMOS: UInt32 = 200
PRODUCT_CLOUDEDITIONN: UInt32 = 202
PRODUCT_CLOUDEDITION: UInt32 = 203
PRODUCT_AZURESTACKHCI_SERVER_CORE: UInt32 = 406
PRODUCT_DATACENTER_SERVER_AZURE_EDITION: UInt32 = 407
PRODUCT_DATACENTER_SERVER_CORE_AZURE_EDITION: UInt32 = 408
PRODUCT_UNLICENSED: UInt32 = 2882382797
LANG_NEUTRAL: UInt32 = 0
LANG_INVARIANT: UInt32 = 127
LANG_AFRIKAANS: UInt32 = 54
LANG_ALBANIAN: UInt32 = 28
LANG_ALSATIAN: UInt32 = 132
LANG_AMHARIC: UInt32 = 94
LANG_ARABIC: UInt32 = 1
LANG_ARMENIAN: UInt32 = 43
LANG_ASSAMESE: UInt32 = 77
LANG_AZERI: UInt32 = 44
LANG_AZERBAIJANI: UInt32 = 44
LANG_BANGLA: UInt32 = 69
LANG_BASHKIR: UInt32 = 109
LANG_BASQUE: UInt32 = 45
LANG_BELARUSIAN: UInt32 = 35
LANG_BENGALI: UInt32 = 69
LANG_BRETON: UInt32 = 126
LANG_BOSNIAN: UInt32 = 26
LANG_BOSNIAN_NEUTRAL: UInt32 = 30746
LANG_BULGARIAN: UInt32 = 2
LANG_CATALAN: UInt32 = 3
LANG_CENTRAL_KURDISH: UInt32 = 146
LANG_CHEROKEE: UInt32 = 92
LANG_CHINESE: UInt32 = 4
LANG_CHINESE_SIMPLIFIED: UInt32 = 4
LANG_CHINESE_TRADITIONAL: UInt32 = 31748
LANG_CORSICAN: UInt32 = 131
LANG_CROATIAN: UInt32 = 26
LANG_CZECH: UInt32 = 5
LANG_DANISH: UInt32 = 6
LANG_DARI: UInt32 = 140
LANG_DIVEHI: UInt32 = 101
LANG_DUTCH: UInt32 = 19
LANG_ENGLISH: UInt32 = 9
LANG_ESTONIAN: UInt32 = 37
LANG_FAEROESE: UInt32 = 56
LANG_FARSI: UInt32 = 41
LANG_FILIPINO: UInt32 = 100
LANG_FINNISH: UInt32 = 11
LANG_FRENCH: UInt32 = 12
LANG_FRISIAN: UInt32 = 98
LANG_FULAH: UInt32 = 103
LANG_GALICIAN: UInt32 = 86
LANG_GEORGIAN: UInt32 = 55
LANG_GERMAN: UInt32 = 7
LANG_GREEK: UInt32 = 8
LANG_GREENLANDIC: UInt32 = 111
LANG_GUJARATI: UInt32 = 71
LANG_HAUSA: UInt32 = 104
LANG_HAWAIIAN: UInt32 = 117
LANG_HEBREW: UInt32 = 13
LANG_HINDI: UInt32 = 57
LANG_HUNGARIAN: UInt32 = 14
LANG_ICELANDIC: UInt32 = 15
LANG_IGBO: UInt32 = 112
LANG_INDONESIAN: UInt32 = 33
LANG_INUKTITUT: UInt32 = 93
LANG_IRISH: UInt32 = 60
LANG_ITALIAN: UInt32 = 16
LANG_JAPANESE: UInt32 = 17
LANG_KANNADA: UInt32 = 75
LANG_KASHMIRI: UInt32 = 96
LANG_KAZAK: UInt32 = 63
LANG_KHMER: UInt32 = 83
LANG_KICHE: UInt32 = 134
LANG_KINYARWANDA: UInt32 = 135
LANG_KONKANI: UInt32 = 87
LANG_KOREAN: UInt32 = 18
LANG_KYRGYZ: UInt32 = 64
LANG_LAO: UInt32 = 84
LANG_LATVIAN: UInt32 = 38
LANG_LITHUANIAN: UInt32 = 39
LANG_LOWER_SORBIAN: UInt32 = 46
LANG_LUXEMBOURGISH: UInt32 = 110
LANG_MACEDONIAN: UInt32 = 47
LANG_MALAY: UInt32 = 62
LANG_MALAYALAM: UInt32 = 76
LANG_MALTESE: UInt32 = 58
LANG_MANIPURI: UInt32 = 88
LANG_MAORI: UInt32 = 129
LANG_MAPUDUNGUN: UInt32 = 122
LANG_MARATHI: UInt32 = 78
LANG_MOHAWK: UInt32 = 124
LANG_MONGOLIAN: UInt32 = 80
LANG_NEPALI: UInt32 = 97
LANG_NORWEGIAN: UInt32 = 20
LANG_OCCITAN: UInt32 = 130
LANG_ODIA: UInt32 = 72
LANG_ORIYA: UInt32 = 72
LANG_PASHTO: UInt32 = 99
LANG_PERSIAN: UInt32 = 41
LANG_POLISH: UInt32 = 21
LANG_PORTUGUESE: UInt32 = 22
LANG_PULAR: UInt32 = 103
LANG_PUNJABI: UInt32 = 70
LANG_QUECHUA: UInt32 = 107
LANG_ROMANIAN: UInt32 = 24
LANG_ROMANSH: UInt32 = 23
LANG_RUSSIAN: UInt32 = 25
LANG_SAKHA: UInt32 = 133
LANG_SAMI: UInt32 = 59
LANG_SANSKRIT: UInt32 = 79
LANG_SCOTTISH_GAELIC: UInt32 = 145
LANG_SERBIAN: UInt32 = 26
LANG_SERBIAN_NEUTRAL: UInt32 = 31770
LANG_SINDHI: UInt32 = 89
LANG_SINHALESE: UInt32 = 91
LANG_SLOVAK: UInt32 = 27
LANG_SLOVENIAN: UInt32 = 36
LANG_SOTHO: UInt32 = 108
LANG_SPANISH: UInt32 = 10
LANG_SWAHILI: UInt32 = 65
LANG_SWEDISH: UInt32 = 29
LANG_SYRIAC: UInt32 = 90
LANG_TAJIK: UInt32 = 40
LANG_TAMAZIGHT: UInt32 = 95
LANG_TAMIL: UInt32 = 73
LANG_TATAR: UInt32 = 68
LANG_TELUGU: UInt32 = 74
LANG_THAI: UInt32 = 30
LANG_TIBETAN: UInt32 = 81
LANG_TIGRIGNA: UInt32 = 115
LANG_TIGRINYA: UInt32 = 115
LANG_TSWANA: UInt32 = 50
LANG_TURKISH: UInt32 = 31
LANG_TURKMEN: UInt32 = 66
LANG_UIGHUR: UInt32 = 128
LANG_UKRAINIAN: UInt32 = 34
LANG_UPPER_SORBIAN: UInt32 = 46
LANG_URDU: UInt32 = 32
LANG_UZBEK: UInt32 = 67
LANG_VALENCIAN: UInt32 = 3
LANG_VIETNAMESE: UInt32 = 42
LANG_WELSH: UInt32 = 82
LANG_WOLOF: UInt32 = 136
LANG_XHOSA: UInt32 = 52
LANG_YAKUT: UInt32 = 133
LANG_YI: UInt32 = 120
LANG_YORUBA: UInt32 = 106
LANG_ZULU: UInt32 = 53
SUBLANG_NEUTRAL: UInt32 = 0
SUBLANG_DEFAULT: UInt32 = 1
SUBLANG_SYS_DEFAULT: UInt32 = 2
SUBLANG_CUSTOM_DEFAULT: UInt32 = 3
SUBLANG_CUSTOM_UNSPECIFIED: UInt32 = 4
SUBLANG_UI_CUSTOM_DEFAULT: UInt32 = 5
SUBLANG_AFRIKAANS_SOUTH_AFRICA: UInt32 = 1
SUBLANG_ALBANIAN_ALBANIA: UInt32 = 1
SUBLANG_ALSATIAN_FRANCE: UInt32 = 1
SUBLANG_AMHARIC_ETHIOPIA: UInt32 = 1
SUBLANG_ARABIC_SAUDI_ARABIA: UInt32 = 1
SUBLANG_ARABIC_IRAQ: UInt32 = 2
SUBLANG_ARABIC_EGYPT: UInt32 = 3
SUBLANG_ARABIC_LIBYA: UInt32 = 4
SUBLANG_ARABIC_ALGERIA: UInt32 = 5
SUBLANG_ARABIC_MOROCCO: UInt32 = 6
SUBLANG_ARABIC_TUNISIA: UInt32 = 7
SUBLANG_ARABIC_OMAN: UInt32 = 8
SUBLANG_ARABIC_YEMEN: UInt32 = 9
SUBLANG_ARABIC_SYRIA: UInt32 = 10
SUBLANG_ARABIC_JORDAN: UInt32 = 11
SUBLANG_ARABIC_LEBANON: UInt32 = 12
SUBLANG_ARABIC_KUWAIT: UInt32 = 13
SUBLANG_ARABIC_UAE: UInt32 = 14
SUBLANG_ARABIC_BAHRAIN: UInt32 = 15
SUBLANG_ARABIC_QATAR: UInt32 = 16
SUBLANG_ARMENIAN_ARMENIA: UInt32 = 1
SUBLANG_ASSAMESE_INDIA: UInt32 = 1
SUBLANG_AZERI_LATIN: UInt32 = 1
SUBLANG_AZERI_CYRILLIC: UInt32 = 2
SUBLANG_AZERBAIJANI_AZERBAIJAN_LATIN: UInt32 = 1
SUBLANG_AZERBAIJANI_AZERBAIJAN_CYRILLIC: UInt32 = 2
SUBLANG_BANGLA_INDIA: UInt32 = 1
SUBLANG_BANGLA_BANGLADESH: UInt32 = 2
SUBLANG_BASHKIR_RUSSIA: UInt32 = 1
SUBLANG_BASQUE_BASQUE: UInt32 = 1
SUBLANG_BELARUSIAN_BELARUS: UInt32 = 1
SUBLANG_BENGALI_INDIA: UInt32 = 1
SUBLANG_BENGALI_BANGLADESH: UInt32 = 2
SUBLANG_BOSNIAN_BOSNIA_HERZEGOVINA_LATIN: UInt32 = 5
SUBLANG_BOSNIAN_BOSNIA_HERZEGOVINA_CYRILLIC: UInt32 = 8
SUBLANG_BRETON_FRANCE: UInt32 = 1
SUBLANG_BULGARIAN_BULGARIA: UInt32 = 1
SUBLANG_CATALAN_CATALAN: UInt32 = 1
SUBLANG_CENTRAL_KURDISH_IRAQ: UInt32 = 1
SUBLANG_CHEROKEE_CHEROKEE: UInt32 = 1
SUBLANG_CHINESE_TRADITIONAL: UInt32 = 1
SUBLANG_CHINESE_SIMPLIFIED: UInt32 = 2
SUBLANG_CHINESE_HONGKONG: UInt32 = 3
SUBLANG_CHINESE_SINGAPORE: UInt32 = 4
SUBLANG_CHINESE_MACAU: UInt32 = 5
SUBLANG_CORSICAN_FRANCE: UInt32 = 1
SUBLANG_CZECH_CZECH_REPUBLIC: UInt32 = 1
SUBLANG_CROATIAN_CROATIA: UInt32 = 1
SUBLANG_CROATIAN_BOSNIA_HERZEGOVINA_LATIN: UInt32 = 4
SUBLANG_DANISH_DENMARK: UInt32 = 1
SUBLANG_DARI_AFGHANISTAN: UInt32 = 1
SUBLANG_DIVEHI_MALDIVES: UInt32 = 1
SUBLANG_DUTCH: UInt32 = 1
SUBLANG_DUTCH_BELGIAN: UInt32 = 2
SUBLANG_ENGLISH_US: UInt32 = 1
SUBLANG_ENGLISH_UK: UInt32 = 2
SUBLANG_ENGLISH_AUS: UInt32 = 3
SUBLANG_ENGLISH_CAN: UInt32 = 4
SUBLANG_ENGLISH_NZ: UInt32 = 5
SUBLANG_ENGLISH_EIRE: UInt32 = 6
SUBLANG_ENGLISH_SOUTH_AFRICA: UInt32 = 7
SUBLANG_ENGLISH_JAMAICA: UInt32 = 8
SUBLANG_ENGLISH_CARIBBEAN: UInt32 = 9
SUBLANG_ENGLISH_BELIZE: UInt32 = 10
SUBLANG_ENGLISH_TRINIDAD: UInt32 = 11
SUBLANG_ENGLISH_ZIMBABWE: UInt32 = 12
SUBLANG_ENGLISH_PHILIPPINES: UInt32 = 13
SUBLANG_ENGLISH_INDIA: UInt32 = 16
SUBLANG_ENGLISH_MALAYSIA: UInt32 = 17
SUBLANG_ENGLISH_SINGAPORE: UInt32 = 18
SUBLANG_ESTONIAN_ESTONIA: UInt32 = 1
SUBLANG_FAEROESE_FAROE_ISLANDS: UInt32 = 1
SUBLANG_FILIPINO_PHILIPPINES: UInt32 = 1
SUBLANG_FINNISH_FINLAND: UInt32 = 1
SUBLANG_FRENCH: UInt32 = 1
SUBLANG_FRENCH_BELGIAN: UInt32 = 2
SUBLANG_FRENCH_CANADIAN: UInt32 = 3
SUBLANG_FRENCH_SWISS: UInt32 = 4
SUBLANG_FRENCH_LUXEMBOURG: UInt32 = 5
SUBLANG_FRENCH_MONACO: UInt32 = 6
SUBLANG_FRISIAN_NETHERLANDS: UInt32 = 1
SUBLANG_FULAH_SENEGAL: UInt32 = 2
SUBLANG_GALICIAN_GALICIAN: UInt32 = 1
SUBLANG_GEORGIAN_GEORGIA: UInt32 = 1
SUBLANG_GERMAN: UInt32 = 1
SUBLANG_GERMAN_SWISS: UInt32 = 2
SUBLANG_GERMAN_AUSTRIAN: UInt32 = 3
SUBLANG_GERMAN_LUXEMBOURG: UInt32 = 4
SUBLANG_GERMAN_LIECHTENSTEIN: UInt32 = 5
SUBLANG_GREEK_GREECE: UInt32 = 1
SUBLANG_GREENLANDIC_GREENLAND: UInt32 = 1
SUBLANG_GUJARATI_INDIA: UInt32 = 1
SUBLANG_HAUSA_NIGERIA_LATIN: UInt32 = 1
SUBLANG_HAWAIIAN_US: UInt32 = 1
SUBLANG_HEBREW_ISRAEL: UInt32 = 1
SUBLANG_HINDI_INDIA: UInt32 = 1
SUBLANG_HUNGARIAN_HUNGARY: UInt32 = 1
SUBLANG_ICELANDIC_ICELAND: UInt32 = 1
SUBLANG_IGBO_NIGERIA: UInt32 = 1
SUBLANG_INDONESIAN_INDONESIA: UInt32 = 1
SUBLANG_INUKTITUT_CANADA: UInt32 = 1
SUBLANG_INUKTITUT_CANADA_LATIN: UInt32 = 2
SUBLANG_IRISH_IRELAND: UInt32 = 2
SUBLANG_ITALIAN: UInt32 = 1
SUBLANG_ITALIAN_SWISS: UInt32 = 2
SUBLANG_JAPANESE_JAPAN: UInt32 = 1
SUBLANG_KANNADA_INDIA: UInt32 = 1
SUBLANG_KASHMIRI_SASIA: UInt32 = 2
SUBLANG_KASHMIRI_INDIA: UInt32 = 2
SUBLANG_KAZAK_KAZAKHSTAN: UInt32 = 1
SUBLANG_KHMER_CAMBODIA: UInt32 = 1
SUBLANG_KICHE_GUATEMALA: UInt32 = 1
SUBLANG_KINYARWANDA_RWANDA: UInt32 = 1
SUBLANG_KONKANI_INDIA: UInt32 = 1
SUBLANG_KOREAN: UInt32 = 1
SUBLANG_KYRGYZ_KYRGYZSTAN: UInt32 = 1
SUBLANG_LAO_LAO: UInt32 = 1
SUBLANG_LATVIAN_LATVIA: UInt32 = 1
SUBLANG_LITHUANIAN: UInt32 = 1
SUBLANG_LOWER_SORBIAN_GERMANY: UInt32 = 2
SUBLANG_LUXEMBOURGISH_LUXEMBOURG: UInt32 = 1
SUBLANG_MACEDONIAN_MACEDONIA: UInt32 = 1
SUBLANG_MALAY_MALAYSIA: UInt32 = 1
SUBLANG_MALAY_BRUNEI_DARUSSALAM: UInt32 = 2
SUBLANG_MALAYALAM_INDIA: UInt32 = 1
SUBLANG_MALTESE_MALTA: UInt32 = 1
SUBLANG_MAORI_NEW_ZEALAND: UInt32 = 1
SUBLANG_MAPUDUNGUN_CHILE: UInt32 = 1
SUBLANG_MARATHI_INDIA: UInt32 = 1
SUBLANG_MOHAWK_MOHAWK: UInt32 = 1
SUBLANG_MONGOLIAN_CYRILLIC_MONGOLIA: UInt32 = 1
SUBLANG_MONGOLIAN_PRC: UInt32 = 2
SUBLANG_NEPALI_INDIA: UInt32 = 2
SUBLANG_NEPALI_NEPAL: UInt32 = 1
SUBLANG_NORWEGIAN_BOKMAL: UInt32 = 1
SUBLANG_NORWEGIAN_NYNORSK: UInt32 = 2
SUBLANG_OCCITAN_FRANCE: UInt32 = 1
SUBLANG_ODIA_INDIA: UInt32 = 1
SUBLANG_ORIYA_INDIA: UInt32 = 1
SUBLANG_PASHTO_AFGHANISTAN: UInt32 = 1
SUBLANG_PERSIAN_IRAN: UInt32 = 1
SUBLANG_POLISH_POLAND: UInt32 = 1
SUBLANG_PORTUGUESE: UInt32 = 2
SUBLANG_PORTUGUESE_BRAZILIAN: UInt32 = 1
SUBLANG_PULAR_SENEGAL: UInt32 = 2
SUBLANG_PUNJABI_INDIA: UInt32 = 1
SUBLANG_PUNJABI_PAKISTAN: UInt32 = 2
SUBLANG_QUECHUA_BOLIVIA: UInt32 = 1
SUBLANG_QUECHUA_ECUADOR: UInt32 = 2
SUBLANG_QUECHUA_PERU: UInt32 = 3
SUBLANG_ROMANIAN_ROMANIA: UInt32 = 1
SUBLANG_ROMANSH_SWITZERLAND: UInt32 = 1
SUBLANG_RUSSIAN_RUSSIA: UInt32 = 1
SUBLANG_SAKHA_RUSSIA: UInt32 = 1
SUBLANG_SAMI_NORTHERN_NORWAY: UInt32 = 1
SUBLANG_SAMI_NORTHERN_SWEDEN: UInt32 = 2
SUBLANG_SAMI_NORTHERN_FINLAND: UInt32 = 3
SUBLANG_SAMI_LULE_NORWAY: UInt32 = 4
SUBLANG_SAMI_LULE_SWEDEN: UInt32 = 5
SUBLANG_SAMI_SOUTHERN_NORWAY: UInt32 = 6
SUBLANG_SAMI_SOUTHERN_SWEDEN: UInt32 = 7
SUBLANG_SAMI_SKOLT_FINLAND: UInt32 = 8
SUBLANG_SAMI_INARI_FINLAND: UInt32 = 9
SUBLANG_SANSKRIT_INDIA: UInt32 = 1
SUBLANG_SCOTTISH_GAELIC: UInt32 = 1
SUBLANG_SERBIAN_BOSNIA_HERZEGOVINA_LATIN: UInt32 = 6
SUBLANG_SERBIAN_BOSNIA_HERZEGOVINA_CYRILLIC: UInt32 = 7
SUBLANG_SERBIAN_MONTENEGRO_LATIN: UInt32 = 11
SUBLANG_SERBIAN_MONTENEGRO_CYRILLIC: UInt32 = 12
SUBLANG_SERBIAN_SERBIA_LATIN: UInt32 = 9
SUBLANG_SERBIAN_SERBIA_CYRILLIC: UInt32 = 10
SUBLANG_SERBIAN_CROATIA: UInt32 = 1
SUBLANG_SERBIAN_LATIN: UInt32 = 2
SUBLANG_SERBIAN_CYRILLIC: UInt32 = 3
SUBLANG_SINDHI_INDIA: UInt32 = 1
SUBLANG_SINDHI_PAKISTAN: UInt32 = 2
SUBLANG_SINDHI_AFGHANISTAN: UInt32 = 2
SUBLANG_SINHALESE_SRI_LANKA: UInt32 = 1
SUBLANG_SOTHO_NORTHERN_SOUTH_AFRICA: UInt32 = 1
SUBLANG_SLOVAK_SLOVAKIA: UInt32 = 1
SUBLANG_SLOVENIAN_SLOVENIA: UInt32 = 1
SUBLANG_SPANISH: UInt32 = 1
SUBLANG_SPANISH_MEXICAN: UInt32 = 2
SUBLANG_SPANISH_MODERN: UInt32 = 3
SUBLANG_SPANISH_GUATEMALA: UInt32 = 4
SUBLANG_SPANISH_COSTA_RICA: UInt32 = 5
SUBLANG_SPANISH_PANAMA: UInt32 = 6
SUBLANG_SPANISH_DOMINICAN_REPUBLIC: UInt32 = 7
SUBLANG_SPANISH_VENEZUELA: UInt32 = 8
SUBLANG_SPANISH_COLOMBIA: UInt32 = 9
SUBLANG_SPANISH_PERU: UInt32 = 10
SUBLANG_SPANISH_ARGENTINA: UInt32 = 11
SUBLANG_SPANISH_ECUADOR: UInt32 = 12
SUBLANG_SPANISH_CHILE: UInt32 = 13
SUBLANG_SPANISH_URUGUAY: UInt32 = 14
SUBLANG_SPANISH_PARAGUAY: UInt32 = 15
SUBLANG_SPANISH_BOLIVIA: UInt32 = 16
SUBLANG_SPANISH_EL_SALVADOR: UInt32 = 17
SUBLANG_SPANISH_HONDURAS: UInt32 = 18
SUBLANG_SPANISH_NICARAGUA: UInt32 = 19
SUBLANG_SPANISH_PUERTO_RICO: UInt32 = 20
SUBLANG_SPANISH_US: UInt32 = 21
SUBLANG_SWAHILI_KENYA: UInt32 = 1
SUBLANG_SWEDISH: UInt32 = 1
SUBLANG_SWEDISH_FINLAND: UInt32 = 2
SUBLANG_SYRIAC_SYRIA: UInt32 = 1
SUBLANG_TAJIK_TAJIKISTAN: UInt32 = 1
SUBLANG_TAMAZIGHT_ALGERIA_LATIN: UInt32 = 2
SUBLANG_TAMAZIGHT_MOROCCO_TIFINAGH: UInt32 = 4
SUBLANG_TAMIL_INDIA: UInt32 = 1
SUBLANG_TAMIL_SRI_LANKA: UInt32 = 2
SUBLANG_TATAR_RUSSIA: UInt32 = 1
SUBLANG_TELUGU_INDIA: UInt32 = 1
SUBLANG_THAI_THAILAND: UInt32 = 1
SUBLANG_TIBETAN_PRC: UInt32 = 1
SUBLANG_TIGRIGNA_ERITREA: UInt32 = 2
SUBLANG_TIGRINYA_ERITREA: UInt32 = 2
SUBLANG_TIGRINYA_ETHIOPIA: UInt32 = 1
SUBLANG_TSWANA_BOTSWANA: UInt32 = 2
SUBLANG_TSWANA_SOUTH_AFRICA: UInt32 = 1
SUBLANG_TURKISH_TURKEY: UInt32 = 1
SUBLANG_TURKMEN_TURKMENISTAN: UInt32 = 1
SUBLANG_UIGHUR_PRC: UInt32 = 1
SUBLANG_UKRAINIAN_UKRAINE: UInt32 = 1
SUBLANG_UPPER_SORBIAN_GERMANY: UInt32 = 1
SUBLANG_URDU_PAKISTAN: UInt32 = 1
SUBLANG_URDU_INDIA: UInt32 = 2
SUBLANG_UZBEK_LATIN: UInt32 = 1
SUBLANG_UZBEK_CYRILLIC: UInt32 = 2
SUBLANG_VALENCIAN_VALENCIA: UInt32 = 2
SUBLANG_VIETNAMESE_VIETNAM: UInt32 = 1
SUBLANG_WELSH_UNITED_KINGDOM: UInt32 = 1
SUBLANG_WOLOF_SENEGAL: UInt32 = 1
SUBLANG_XHOSA_SOUTH_AFRICA: UInt32 = 1
SUBLANG_YAKUT_RUSSIA: UInt32 = 1
SUBLANG_YI_PRC: UInt32 = 1
SUBLANG_YORUBA_NIGERIA: UInt32 = 1
SUBLANG_ZULU_SOUTH_AFRICA: UInt32 = 1
SORT_DEFAULT: UInt32 = 0
SORT_INVARIANT_MATH: UInt32 = 1
SORT_JAPANESE_XJIS: UInt32 = 0
SORT_JAPANESE_UNICODE: UInt32 = 1
SORT_JAPANESE_RADICALSTROKE: UInt32 = 4
SORT_CHINESE_BIG5: UInt32 = 0
SORT_CHINESE_PRCP: UInt32 = 0
SORT_CHINESE_UNICODE: UInt32 = 1
SORT_CHINESE_PRC: UInt32 = 2
SORT_CHINESE_BOPOMOFO: UInt32 = 3
SORT_CHINESE_RADICALSTROKE: UInt32 = 4
SORT_KOREAN_KSC: UInt32 = 0
SORT_KOREAN_UNICODE: UInt32 = 1
SORT_GERMAN_PHONE_BOOK: UInt32 = 1
SORT_HUNGARIAN_DEFAULT: UInt32 = 0
SORT_HUNGARIAN_TECHNICAL: UInt32 = 1
SORT_GEORGIAN_TRADITIONAL: UInt32 = 0
SORT_GEORGIAN_MODERN: UInt32 = 1
NLS_VALID_LOCALE_MASK: UInt32 = 1048575
LOCALE_NAME_MAX_LENGTH: UInt32 = 85
LOCALE_TRANSIENT_KEYBOARD1: UInt32 = 8192
LOCALE_TRANSIENT_KEYBOARD2: UInt32 = 9216
LOCALE_TRANSIENT_KEYBOARD3: UInt32 = 10240
LOCALE_TRANSIENT_KEYBOARD4: UInt32 = 11264
MAXIMUM_WAIT_OBJECTS: UInt32 = 64
MAXIMUM_SUSPEND_COUNT: UInt32 = 127
PF_TEMPORAL_LEVEL_1: UInt32 = 1
PF_TEMPORAL_LEVEL_2: UInt32 = 2
PF_TEMPORAL_LEVEL_3: UInt32 = 3
PF_NON_TEMPORAL_LEVEL_ALL: UInt32 = 0
EXCEPTION_READ_FAULT: UInt32 = 0
EXCEPTION_WRITE_FAULT: UInt32 = 1
EXCEPTION_EXECUTE_FAULT: UInt32 = 8
INITIAL_MXCSR: UInt32 = 8064
INITIAL_FPCSR: UInt32 = 639
RUNTIME_FUNCTION_INDIRECT: UInt32 = 1
UNW_FLAG_NO_EPILOGUE: UInt32 = 2147483648
UNWIND_CHAIN_LIMIT: UInt32 = 32
OUT_OF_PROCESS_FUNCTION_TABLE_CALLBACK_EXPORT_NAME: String = 'OutOfProcessFunctionTableCallback'
INITIAL_CPSR: UInt32 = 16
INITIAL_FPSCR: UInt32 = 0
ARM_MAX_BREAKPOINTS: UInt32 = 8
ARM_MAX_WATCHPOINTS: UInt32 = 1
ARM64_PREFETCH_PLD: UInt32 = 0
ARM64_PREFETCH_PLI: UInt32 = 8
ARM64_PREFETCH_PST: UInt32 = 16
ARM64_PREFETCH_L1: UInt32 = 0
ARM64_PREFETCH_L2: UInt32 = 2
ARM64_PREFETCH_L3: UInt32 = 4
ARM64_PREFETCH_KEEP: UInt32 = 0
ARM64_PREFETCH_STRM: UInt32 = 1
ARM64_MULT_INTRINSICS_SUPPORTED: UInt32 = 1
ARM64_MAX_BREAKPOINTS: UInt32 = 8
ARM64_MAX_WATCHPOINTS: UInt32 = 2
NONVOL_INT_NUMREG_ARM64: UInt32 = 11
NONVOL_FP_NUMREG_ARM64: UInt32 = 8
BREAK_DEBUG_BASE: UInt32 = 524288
ASSERT_BREAKPOINT: UInt32 = 524291
SIZE_OF_80387_REGISTERS: UInt32 = 80
MAXIMUM_SUPPORTED_EXTENSION: UInt32 = 512
EXCEPTION_NONCONTINUABLE: UInt32 = 1
EXCEPTION_UNWINDING: UInt32 = 2
EXCEPTION_EXIT_UNWIND: UInt32 = 4
EXCEPTION_STACK_INVALID: UInt32 = 8
EXCEPTION_NESTED_CALL: UInt32 = 16
EXCEPTION_TARGET_UNWIND: UInt32 = 32
EXCEPTION_COLLIDED_UNWIND: UInt32 = 64
EXCEPTION_SOFTWARE_ORIGINATE: UInt32 = 128
EXCEPTION_MAXIMUM_PARAMETERS: UInt32 = 15
ACCESS_SYSTEM_SECURITY: UInt32 = 16777216
MAXIMUM_ALLOWED: UInt32 = 33554432
SID_REVISION: UInt32 = 1
SID_MAX_SUB_AUTHORITIES: UInt32 = 15
SID_RECOMMENDED_SUB_AUTHORITIES: UInt32 = 1
SID_HASH_SIZE: UInt32 = 32
SECURITY_NULL_RID: Int32 = 0
SECURITY_WORLD_RID: Int32 = 0
SECURITY_LOCAL_RID: Int32 = 0
SECURITY_LOCAL_LOGON_RID: Int32 = 1
SECURITY_CREATOR_OWNER_RID: Int32 = 0
SECURITY_CREATOR_GROUP_RID: Int32 = 1
SECURITY_CREATOR_OWNER_SERVER_RID: Int32 = 2
SECURITY_CREATOR_GROUP_SERVER_RID: Int32 = 3
SECURITY_CREATOR_OWNER_RIGHTS_RID: Int32 = 4
SECURITY_DIALUP_RID: Int32 = 1
SECURITY_NETWORK_RID: Int32 = 2
SECURITY_BATCH_RID: Int32 = 3
SECURITY_INTERACTIVE_RID: Int32 = 4
SECURITY_LOGON_IDS_RID: Int32 = 5
SECURITY_LOGON_IDS_RID_COUNT: Int32 = 3
SECURITY_SERVICE_RID: Int32 = 6
SECURITY_ANONYMOUS_LOGON_RID: Int32 = 7
SECURITY_PROXY_RID: Int32 = 8
SECURITY_ENTERPRISE_CONTROLLERS_RID: Int32 = 9
SECURITY_SERVER_LOGON_RID: Int32 = 9
SECURITY_PRINCIPAL_SELF_RID: Int32 = 10
SECURITY_AUTHENTICATED_USER_RID: Int32 = 11
SECURITY_RESTRICTED_CODE_RID: Int32 = 12
SECURITY_TERMINAL_SERVER_RID: Int32 = 13
SECURITY_REMOTE_LOGON_RID: Int32 = 14
SECURITY_THIS_ORGANIZATION_RID: Int32 = 15
SECURITY_IUSER_RID: Int32 = 17
SECURITY_LOCAL_SYSTEM_RID: Int32 = 18
SECURITY_LOCAL_SERVICE_RID: Int32 = 19
SECURITY_NETWORK_SERVICE_RID: Int32 = 20
SECURITY_NT_NON_UNIQUE: Int32 = 21
SECURITY_NT_NON_UNIQUE_SUB_AUTH_COUNT: Int32 = 3
SECURITY_ENTERPRISE_READONLY_CONTROLLERS_RID: Int32 = 22
SECURITY_BUILTIN_DOMAIN_RID: Int32 = 32
SECURITY_WRITE_RESTRICTED_CODE_RID: Int32 = 33
SECURITY_PACKAGE_BASE_RID: Int32 = 64
SECURITY_PACKAGE_RID_COUNT: Int32 = 2
SECURITY_PACKAGE_NTLM_RID: Int32 = 10
SECURITY_PACKAGE_SCHANNEL_RID: Int32 = 14
SECURITY_PACKAGE_DIGEST_RID: Int32 = 21
SECURITY_CRED_TYPE_BASE_RID: Int32 = 65
SECURITY_CRED_TYPE_RID_COUNT: Int32 = 2
SECURITY_CRED_TYPE_THIS_ORG_CERT_RID: Int32 = 1
SECURITY_MIN_BASE_RID: Int32 = 80
SECURITY_SERVICE_ID_BASE_RID: Int32 = 80
SECURITY_SERVICE_ID_RID_COUNT: Int32 = 6
SECURITY_RESERVED_ID_BASE_RID: Int32 = 81
SECURITY_APPPOOL_ID_BASE_RID: Int32 = 82
SECURITY_APPPOOL_ID_RID_COUNT: Int32 = 6
SECURITY_VIRTUALSERVER_ID_BASE_RID: Int32 = 83
SECURITY_VIRTUALSERVER_ID_RID_COUNT: Int32 = 6
SECURITY_USERMODEDRIVERHOST_ID_BASE_RID: Int32 = 84
SECURITY_USERMODEDRIVERHOST_ID_RID_COUNT: Int32 = 6
SECURITY_CLOUD_INFRASTRUCTURE_SERVICES_ID_BASE_RID: Int32 = 85
SECURITY_CLOUD_INFRASTRUCTURE_SERVICES_ID_RID_COUNT: Int32 = 6
SECURITY_WMIHOST_ID_BASE_RID: Int32 = 86
SECURITY_WMIHOST_ID_RID_COUNT: Int32 = 6
SECURITY_TASK_ID_BASE_RID: Int32 = 87
SECURITY_NFS_ID_BASE_RID: Int32 = 88
SECURITY_COM_ID_BASE_RID: Int32 = 89
SECURITY_WINDOW_MANAGER_BASE_RID: Int32 = 90
SECURITY_RDV_GFX_BASE_RID: Int32 = 91
SECURITY_DASHOST_ID_BASE_RID: Int32 = 92
SECURITY_DASHOST_ID_RID_COUNT: Int32 = 6
SECURITY_USERMANAGER_ID_BASE_RID: Int32 = 93
SECURITY_USERMANAGER_ID_RID_COUNT: Int32 = 6
SECURITY_WINRM_ID_BASE_RID: Int32 = 94
SECURITY_WINRM_ID_RID_COUNT: Int32 = 6
SECURITY_CCG_ID_BASE_RID: Int32 = 95
SECURITY_UMFD_BASE_RID: Int32 = 96
SECURITY_VIRTUALACCOUNT_ID_RID_COUNT: Int32 = 6
SECURITY_MAX_BASE_RID: Int32 = 111
SECURITY_MAX_ALWAYS_FILTERED: Int32 = 999
SECURITY_MIN_NEVER_FILTERED: Int32 = 1000
SECURITY_OTHER_ORGANIZATION_RID: Int32 = 1000
SECURITY_WINDOWSMOBILE_ID_BASE_RID: Int32 = 112
SECURITY_INSTALLER_GROUP_CAPABILITY_BASE: UInt32 = 32
SECURITY_INSTALLER_GROUP_CAPABILITY_RID_COUNT: UInt32 = 9
SECURITY_INSTALLER_CAPABILITY_RID_COUNT: UInt32 = 10
SECURITY_LOCAL_ACCOUNT_RID: Int32 = 113
SECURITY_LOCAL_ACCOUNT_AND_ADMIN_RID: Int32 = 114
DOMAIN_GROUP_RID_AUTHORIZATION_DATA_IS_COMPOUNDED: Int32 = 496
DOMAIN_GROUP_RID_AUTHORIZATION_DATA_CONTAINS_CLAIMS: Int32 = 497
DOMAIN_GROUP_RID_ENTERPRISE_READONLY_DOMAIN_CONTROLLERS: Int32 = 498
FOREST_USER_RID_MAX: Int32 = 499
DOMAIN_USER_RID_ADMIN: Int32 = 500
DOMAIN_USER_RID_GUEST: Int32 = 501
DOMAIN_USER_RID_KRBTGT: Int32 = 502
DOMAIN_USER_RID_DEFAULT_ACCOUNT: Int32 = 503
DOMAIN_USER_RID_WDAG_ACCOUNT: Int32 = 504
DOMAIN_USER_RID_MAX: Int32 = 999
DOMAIN_GROUP_RID_ADMINS: Int32 = 512
DOMAIN_GROUP_RID_USERS: Int32 = 513
DOMAIN_GROUP_RID_GUESTS: Int32 = 514
DOMAIN_GROUP_RID_COMPUTERS: Int32 = 515
DOMAIN_GROUP_RID_CONTROLLERS: Int32 = 516
DOMAIN_GROUP_RID_CERT_ADMINS: Int32 = 517
DOMAIN_GROUP_RID_SCHEMA_ADMINS: Int32 = 518
DOMAIN_GROUP_RID_ENTERPRISE_ADMINS: Int32 = 519
DOMAIN_GROUP_RID_POLICY_ADMINS: Int32 = 520
DOMAIN_GROUP_RID_READONLY_CONTROLLERS: Int32 = 521
DOMAIN_GROUP_RID_CLONEABLE_CONTROLLERS: Int32 = 522
DOMAIN_GROUP_RID_CDC_RESERVED: Int32 = 524
DOMAIN_GROUP_RID_PROTECTED_USERS: Int32 = 525
DOMAIN_GROUP_RID_KEY_ADMINS: Int32 = 526
DOMAIN_GROUP_RID_ENTERPRISE_KEY_ADMINS: Int32 = 527
DOMAIN_ALIAS_RID_ADMINS: Int32 = 544
DOMAIN_ALIAS_RID_USERS: Int32 = 545
DOMAIN_ALIAS_RID_GUESTS: Int32 = 546
DOMAIN_ALIAS_RID_POWER_USERS: Int32 = 547
DOMAIN_ALIAS_RID_ACCOUNT_OPS: Int32 = 548
DOMAIN_ALIAS_RID_SYSTEM_OPS: Int32 = 549
DOMAIN_ALIAS_RID_PRINT_OPS: Int32 = 550
DOMAIN_ALIAS_RID_BACKUP_OPS: Int32 = 551
DOMAIN_ALIAS_RID_REPLICATOR: Int32 = 552
DOMAIN_ALIAS_RID_RAS_SERVERS: Int32 = 553
DOMAIN_ALIAS_RID_PREW2KCOMPACCESS: Int32 = 554
DOMAIN_ALIAS_RID_REMOTE_DESKTOP_USERS: Int32 = 555
DOMAIN_ALIAS_RID_NETWORK_CONFIGURATION_OPS: Int32 = 556
DOMAIN_ALIAS_RID_INCOMING_FOREST_TRUST_BUILDERS: Int32 = 557
DOMAIN_ALIAS_RID_MONITORING_USERS: Int32 = 558
DOMAIN_ALIAS_RID_LOGGING_USERS: Int32 = 559
DOMAIN_ALIAS_RID_AUTHORIZATIONACCESS: Int32 = 560
DOMAIN_ALIAS_RID_TS_LICENSE_SERVERS: Int32 = 561
DOMAIN_ALIAS_RID_DCOM_USERS: Int32 = 562
DOMAIN_ALIAS_RID_IUSERS: Int32 = 568
DOMAIN_ALIAS_RID_CRYPTO_OPERATORS: Int32 = 569
DOMAIN_ALIAS_RID_CACHEABLE_PRINCIPALS_GROUP: Int32 = 571
DOMAIN_ALIAS_RID_NON_CACHEABLE_PRINCIPALS_GROUP: Int32 = 572
DOMAIN_ALIAS_RID_EVENT_LOG_READERS_GROUP: Int32 = 573
DOMAIN_ALIAS_RID_CERTSVC_DCOM_ACCESS_GROUP: Int32 = 574
DOMAIN_ALIAS_RID_RDS_REMOTE_ACCESS_SERVERS: Int32 = 575
DOMAIN_ALIAS_RID_RDS_ENDPOINT_SERVERS: Int32 = 576
DOMAIN_ALIAS_RID_RDS_MANAGEMENT_SERVERS: Int32 = 577
DOMAIN_ALIAS_RID_HYPER_V_ADMINS: Int32 = 578
DOMAIN_ALIAS_RID_ACCESS_CONTROL_ASSISTANCE_OPS: Int32 = 579
DOMAIN_ALIAS_RID_REMOTE_MANAGEMENT_USERS: Int32 = 580
DOMAIN_ALIAS_RID_DEFAULT_ACCOUNT: Int32 = 581
DOMAIN_ALIAS_RID_STORAGE_REPLICA_ADMINS: Int32 = 582
DOMAIN_ALIAS_RID_DEVICE_OWNERS: Int32 = 583
SECURITY_APP_PACKAGE_BASE_RID: Int32 = 2
SECURITY_BUILTIN_APP_PACKAGE_RID_COUNT: Int32 = 2
SECURITY_APP_PACKAGE_RID_COUNT: Int32 = 8
SECURITY_CAPABILITY_BASE_RID: Int32 = 3
SECURITY_CAPABILITY_APP_RID: Int32 = 1024
SECURITY_CAPABILITY_APP_SILO_RID: Int32 = 65536
SECURITY_BUILTIN_CAPABILITY_RID_COUNT: Int32 = 2
SECURITY_CAPABILITY_RID_COUNT: Int32 = 5
SECURITY_PARENT_PACKAGE_RID_COUNT: Int32 = 8
SECURITY_CHILD_PACKAGE_RID_COUNT: Int32 = 12
SECURITY_BUILTIN_PACKAGE_ANY_PACKAGE: Int32 = 1
SECURITY_BUILTIN_PACKAGE_ANY_RESTRICTED_PACKAGE: Int32 = 2
SECURITY_CAPABILITY_INTERNET_CLIENT: Int32 = 1
SECURITY_CAPABILITY_INTERNET_CLIENT_SERVER: Int32 = 2
SECURITY_CAPABILITY_PRIVATE_NETWORK_CLIENT_SERVER: Int32 = 3
SECURITY_CAPABILITY_PICTURES_LIBRARY: Int32 = 4
SECURITY_CAPABILITY_VIDEOS_LIBRARY: Int32 = 5
SECURITY_CAPABILITY_MUSIC_LIBRARY: Int32 = 6
SECURITY_CAPABILITY_DOCUMENTS_LIBRARY: Int32 = 7
SECURITY_CAPABILITY_ENTERPRISE_AUTHENTICATION: Int32 = 8
SECURITY_CAPABILITY_SHARED_USER_CERTIFICATES: Int32 = 9
SECURITY_CAPABILITY_REMOVABLE_STORAGE: Int32 = 10
SECURITY_CAPABILITY_APPOINTMENTS: Int32 = 11
SECURITY_CAPABILITY_CONTACTS: Int32 = 12
SECURITY_CAPABILITY_INTERNET_EXPLORER: Int32 = 4096
SECURITY_MANDATORY_UNTRUSTED_RID: Int32 = 0
SECURITY_MANDATORY_LOW_RID: Int32 = 4096
SECURITY_MANDATORY_MEDIUM_RID: Int32 = 8192
SECURITY_MANDATORY_MEDIUM_PLUS_RID: UInt32 = 8448
SECURITY_MANDATORY_HIGH_RID: Int32 = 12288
SECURITY_MANDATORY_SYSTEM_RID: Int32 = 16384
SECURITY_MANDATORY_PROTECTED_PROCESS_RID: Int32 = 20480
SECURITY_MANDATORY_MAXIMUM_USER_RID: Int32 = 16384
SECURITY_AUTHENTICATION_AUTHORITY_RID_COUNT: Int32 = 1
SECURITY_AUTHENTICATION_AUTHORITY_ASSERTED_RID: Int32 = 1
SECURITY_AUTHENTICATION_SERVICE_ASSERTED_RID: Int32 = 2
SECURITY_AUTHENTICATION_FRESH_KEY_AUTH_RID: Int32 = 3
SECURITY_AUTHENTICATION_KEY_TRUST_RID: Int32 = 4
SECURITY_AUTHENTICATION_KEY_PROPERTY_MFA_RID: Int32 = 5
SECURITY_AUTHENTICATION_KEY_PROPERTY_ATTESTATION_RID: Int32 = 6
SECURITY_PROCESS_TRUST_AUTHORITY_RID_COUNT: Int32 = 2
SECURITY_PROCESS_PROTECTION_TYPE_FULL_RID: Int32 = 1024
SECURITY_PROCESS_PROTECTION_TYPE_LITE_RID: Int32 = 512
SECURITY_PROCESS_PROTECTION_TYPE_NONE_RID: Int32 = 0
SECURITY_PROCESS_PROTECTION_LEVEL_WINTCB_RID: Int32 = 8192
SECURITY_PROCESS_PROTECTION_LEVEL_WINDOWS_RID: Int32 = 4096
SECURITY_PROCESS_PROTECTION_LEVEL_APP_RID: Int32 = 2048
SECURITY_PROCESS_PROTECTION_LEVEL_ANTIMALWARE_RID: Int32 = 1536
SECURITY_PROCESS_PROTECTION_LEVEL_AUTHENTICODE_RID: Int32 = 1024
SECURITY_PROCESS_PROTECTION_LEVEL_NONE_RID: Int32 = 0
SECURITY_TRUSTED_INSTALLER_RID1: UInt32 = 956008885
SECURITY_TRUSTED_INSTALLER_RID2: UInt32 = 3418522649
SECURITY_TRUSTED_INSTALLER_RID3: UInt32 = 1831038044
SECURITY_TRUSTED_INSTALLER_RID4: UInt32 = 1853292631
SECURITY_TRUSTED_INSTALLER_RID5: UInt32 = 2271478464
SE_GROUP_MANDATORY: Int32 = 1
SE_GROUP_ENABLED_BY_DEFAULT: Int32 = 2
SE_GROUP_ENABLED: Int32 = 4
SE_GROUP_OWNER: Int32 = 8
SE_GROUP_USE_FOR_DENY_ONLY: Int32 = 16
SE_GROUP_INTEGRITY: Int32 = 32
SE_GROUP_INTEGRITY_ENABLED: Int32 = 64
SE_GROUP_LOGON_ID: Int32 = -1073741824
SE_GROUP_RESOURCE: Int32 = 536870912
ACL_REVISION1: UInt32 = 1
ACL_REVISION2: UInt32 = 2
ACL_REVISION3: UInt32 = 3
ACL_REVISION4: UInt32 = 4
MAX_ACL_REVISION: UInt32 = 4
ACCESS_MIN_MS_ACE_TYPE: UInt32 = 0
ACCESS_ALLOWED_ACE_TYPE: UInt32 = 0
ACCESS_DENIED_ACE_TYPE: UInt32 = 1
SYSTEM_AUDIT_ACE_TYPE: UInt32 = 2
SYSTEM_ALARM_ACE_TYPE: UInt32 = 3
ACCESS_MAX_MS_V2_ACE_TYPE: UInt32 = 3
ACCESS_ALLOWED_COMPOUND_ACE_TYPE: UInt32 = 4
ACCESS_MAX_MS_V3_ACE_TYPE: UInt32 = 4
ACCESS_MIN_MS_OBJECT_ACE_TYPE: UInt32 = 5
ACCESS_ALLOWED_OBJECT_ACE_TYPE: UInt32 = 5
ACCESS_DENIED_OBJECT_ACE_TYPE: UInt32 = 6
SYSTEM_AUDIT_OBJECT_ACE_TYPE: UInt32 = 7
SYSTEM_ALARM_OBJECT_ACE_TYPE: UInt32 = 8
ACCESS_MAX_MS_OBJECT_ACE_TYPE: UInt32 = 8
ACCESS_MAX_MS_V4_ACE_TYPE: UInt32 = 8
ACCESS_MAX_MS_ACE_TYPE: UInt32 = 8
ACCESS_ALLOWED_CALLBACK_ACE_TYPE: UInt32 = 9
ACCESS_DENIED_CALLBACK_ACE_TYPE: UInt32 = 10
ACCESS_ALLOWED_CALLBACK_OBJECT_ACE_TYPE: UInt32 = 11
ACCESS_DENIED_CALLBACK_OBJECT_ACE_TYPE: UInt32 = 12
SYSTEM_AUDIT_CALLBACK_ACE_TYPE: UInt32 = 13
SYSTEM_ALARM_CALLBACK_ACE_TYPE: UInt32 = 14
SYSTEM_AUDIT_CALLBACK_OBJECT_ACE_TYPE: UInt32 = 15
SYSTEM_ALARM_CALLBACK_OBJECT_ACE_TYPE: UInt32 = 16
SYSTEM_MANDATORY_LABEL_ACE_TYPE: UInt32 = 17
SYSTEM_RESOURCE_ATTRIBUTE_ACE_TYPE: UInt32 = 18
SYSTEM_SCOPED_POLICY_ID_ACE_TYPE: UInt32 = 19
SYSTEM_PROCESS_TRUST_LABEL_ACE_TYPE: UInt32 = 20
SYSTEM_ACCESS_FILTER_ACE_TYPE: UInt32 = 21
ACCESS_MAX_MS_V5_ACE_TYPE: UInt32 = 21
VALID_INHERIT_FLAGS: UInt32 = 31
CRITICAL_ACE_FLAG: UInt32 = 32
TRUST_PROTECTED_FILTER_ACE_FLAG: UInt32 = 64
SYSTEM_MANDATORY_LABEL_NO_WRITE_UP: UInt32 = 1
SYSTEM_MANDATORY_LABEL_NO_READ_UP: UInt32 = 2
SYSTEM_MANDATORY_LABEL_NO_EXECUTE_UP: UInt32 = 4
SYSTEM_PROCESS_TRUST_LABEL_VALID_MASK: UInt32 = 16777215
SYSTEM_PROCESS_TRUST_NOCONSTRAINT_MASK: UInt32 = 4294967295
SYSTEM_ACCESS_FILTER_VALID_MASK: UInt32 = 16777215
SYSTEM_ACCESS_FILTER_NOCONSTRAINT_MASK: UInt32 = 4294967295
SECURITY_DESCRIPTOR_REVISION: UInt32 = 1
SECURITY_DESCRIPTOR_REVISION1: UInt32 = 1
ACCESS_OBJECT_GUID: UInt32 = 0
ACCESS_PROPERTY_SET_GUID: UInt32 = 1
ACCESS_PROPERTY_GUID: UInt32 = 2
ACCESS_MAX_LEVEL: UInt32 = 4
AUDIT_ALLOW_NO_PRIVILEGE: UInt32 = 1
ACCESS_DS_SOURCE_A: String = 'DS'
ACCESS_DS_SOURCE_W: String = 'DS'
ACCESS_DS_OBJECT_TYPE_NAME_A: String = 'Directory Service Object'
ACCESS_DS_OBJECT_TYPE_NAME_W: String = 'Directory Service Object'
PRIVILEGE_SET_ALL_NECESSARY: UInt32 = 1
ACCESS_REASON_TYPE_MASK: UInt32 = 16711680
ACCESS_REASON_DATA_MASK: UInt32 = 65535
ACCESS_REASON_STAGING_MASK: UInt32 = 2147483648
ACCESS_REASON_EXDATA_MASK: UInt32 = 2130706432
SE_SECURITY_DESCRIPTOR_FLAG_NO_OWNER_ACE: UInt32 = 1
SE_SECURITY_DESCRIPTOR_FLAG_NO_LABEL_ACE: UInt32 = 2
SE_SECURITY_DESCRIPTOR_FLAG_NO_ACCESS_FILTER_ACE: UInt32 = 4
SE_SECURITY_DESCRIPTOR_VALID_FLAGS: UInt32 = 7
SE_ACCESS_CHECK_FLAG_NO_LEARNING_MODE_LOGGING: UInt32 = 8
SE_ACCESS_CHECK_VALID_FLAGS: UInt32 = 8
SE_ACTIVATE_AS_USER_CAPABILITY: String = 'activateAsUser'
SE_CONSTRAINED_IMPERSONATION_CAPABILITY: String = 'constrainedImpersonation'
SE_SESSION_IMPERSONATION_CAPABILITY: String = 'sessionImpersonation'
SE_MUMA_CAPABILITY: String = 'muma'
SE_DEVELOPMENT_MODE_NETWORK_CAPABILITY: String = 'developmentModeNetwork'
SE_LEARNING_MODE_LOGGING_CAPABILITY: String = 'learningModeLogging'
SE_PERMISSIVE_LEARNING_MODE_CAPABILITY: String = 'permissiveLearningMode'
SE_APP_SILO_VOLUME_ROOT_MINIMAL_CAPABILITY: String = 'isolatedWin32-volumeRootMinimal'
SE_APP_SILO_PROFILES_ROOT_MINIMAL_CAPABILITY: String = 'isolatedWin32-profilesRootMinimal'
SE_APP_SILO_USER_PROFILE_MINIMAL_CAPABILITY: String = 'isolatedWin32-userProfileMinimal'
SE_APP_SILO_PRINT_CAPABILITY: String = 'isolatedWin32-print'
POLICY_AUDIT_SUBCATEGORY_COUNT: UInt32 = 59
TOKEN_SOURCE_LENGTH: UInt32 = 8
CLAIM_SECURITY_ATTRIBUTE_TYPE_INVALID: UInt32 = 0
CLAIM_SECURITY_ATTRIBUTE_CUSTOM_FLAGS: UInt32 = 4294901760
CLAIM_SECURITY_ATTRIBUTES_INFORMATION_VERSION_V1: UInt32 = 1
CLAIM_SECURITY_ATTRIBUTES_INFORMATION_VERSION: UInt32 = 1
PROCESS_TRUST_LABEL_SECURITY_INFORMATION: Int32 = 128
ACCESS_FILTER_SECURITY_INFORMATION: Int32 = 256
SE_SIGNING_LEVEL_UNCHECKED: UInt32 = 0
SE_SIGNING_LEVEL_UNSIGNED: UInt32 = 1
SE_SIGNING_LEVEL_ENTERPRISE: UInt32 = 2
SE_SIGNING_LEVEL_CUSTOM_1: UInt32 = 3
SE_SIGNING_LEVEL_DEVELOPER: UInt32 = 3
SE_SIGNING_LEVEL_AUTHENTICODE: UInt32 = 4
SE_SIGNING_LEVEL_CUSTOM_2: UInt32 = 5
SE_SIGNING_LEVEL_STORE: UInt32 = 6
SE_SIGNING_LEVEL_CUSTOM_3: UInt32 = 7
SE_SIGNING_LEVEL_ANTIMALWARE: UInt32 = 7
SE_SIGNING_LEVEL_MICROSOFT: UInt32 = 8
SE_SIGNING_LEVEL_CUSTOM_4: UInt32 = 9
SE_SIGNING_LEVEL_CUSTOM_5: UInt32 = 10
SE_SIGNING_LEVEL_DYNAMIC_CODEGEN: UInt32 = 11
SE_SIGNING_LEVEL_WINDOWS: UInt32 = 12
SE_SIGNING_LEVEL_CUSTOM_7: UInt32 = 13
SE_SIGNING_LEVEL_WINDOWS_TCB: UInt32 = 14
SE_SIGNING_LEVEL_CUSTOM_6: UInt32 = 15
JOB_OBJECT_ASSIGN_PROCESS: UInt32 = 1
JOB_OBJECT_SET_ATTRIBUTES: UInt32 = 2
JOB_OBJECT_QUERY: UInt32 = 4
JOB_OBJECT_TERMINATE: UInt32 = 8
JOB_OBJECT_SET_SECURITY_ATTRIBUTES: UInt32 = 16
JOB_OBJECT_IMPERSONATE: UInt32 = 32
FLS_MAXIMUM_AVAILABLE: UInt32 = 4080
TLS_MINIMUM_AVAILABLE: UInt32 = 64
THREAD_DYNAMIC_CODE_ALLOW: UInt32 = 1
THREAD_BASE_PRIORITY_LOWRT: UInt32 = 15
THREAD_BASE_PRIORITY_MAX: UInt32 = 2
THREAD_BASE_PRIORITY_MIN: Int32 = -2
THREAD_BASE_PRIORITY_IDLE: Int32 = -15
COMPONENT_KTM: UInt32 = 1
COMPONENT_VALID_FLAGS: UInt32 = 1
MEMORY_PRIORITY_LOWEST: UInt32 = 0
DYNAMIC_EH_CONTINUATION_TARGET_ADD: UInt32 = 1
DYNAMIC_EH_CONTINUATION_TARGET_PROCESSED: UInt32 = 2
DYNAMIC_ENFORCED_ADDRESS_RANGE_ADD: UInt32 = 1
DYNAMIC_ENFORCED_ADDRESS_RANGE_PROCESSED: UInt32 = 2
QUOTA_LIMITS_USE_DEFAULT_LIMITS: UInt32 = 16
MAX_HW_COUNTERS: UInt32 = 16
THREAD_PROFILING_FLAG_DISPATCH: UInt32 = 1
JOB_OBJECT_NET_RATE_CONTROL_MAX_DSCP_TAG: UInt32 = 64
JOB_OBJECT_MSG_END_OF_JOB_TIME: UInt32 = 1
JOB_OBJECT_MSG_END_OF_PROCESS_TIME: UInt32 = 2
JOB_OBJECT_MSG_ACTIVE_PROCESS_LIMIT: UInt32 = 3
JOB_OBJECT_MSG_ACTIVE_PROCESS_ZERO: UInt32 = 4
JOB_OBJECT_MSG_NEW_PROCESS: UInt32 = 6
JOB_OBJECT_MSG_EXIT_PROCESS: UInt32 = 7
JOB_OBJECT_MSG_ABNORMAL_EXIT_PROCESS: UInt32 = 8
JOB_OBJECT_MSG_PROCESS_MEMORY_LIMIT: UInt32 = 9
JOB_OBJECT_MSG_JOB_MEMORY_LIMIT: UInt32 = 10
JOB_OBJECT_MSG_NOTIFICATION_LIMIT: UInt32 = 11
JOB_OBJECT_MSG_JOB_CYCLE_TIME_LIMIT: UInt32 = 12
JOB_OBJECT_MSG_SILO_TERMINATED: UInt32 = 13
JOB_OBJECT_MSG_MINIMUM: UInt32 = 1
JOB_OBJECT_MSG_MAXIMUM: UInt32 = 13
JOB_OBJECT_UILIMIT_IME: UInt32 = 256
JOB_OBJECT_UILIMIT_ALL: UInt32 = 511
JOB_OBJECT_UI_VALID_FLAGS: UInt32 = 511
MEMORY_PARTITION_QUERY_ACCESS: UInt32 = 1
MEMORY_PARTITION_MODIFY_ACCESS: UInt32 = 2
MUTANT_QUERY_STATE: UInt32 = 1
TIME_ZONE_ID_UNKNOWN: UInt32 = 0
TIME_ZONE_ID_STANDARD: UInt32 = 1
TIME_ZONE_ID_DAYLIGHT: UInt32 = 2
LTP_PC_SMT: UInt32 = 1
CACHE_FULLY_ASSOCIATIVE: UInt32 = 255
PROCESSOR_INTEL_386: UInt32 = 386
PROCESSOR_INTEL_486: UInt32 = 486
PROCESSOR_INTEL_PENTIUM: UInt32 = 586
PROCESSOR_INTEL_IA64: UInt32 = 2200
PROCESSOR_AMD_X8664: UInt32 = 8664
PROCESSOR_MIPS_R4000: UInt32 = 4000
PROCESSOR_ALPHA_21064: UInt32 = 21064
PROCESSOR_PPC_601: UInt32 = 601
PROCESSOR_PPC_603: UInt32 = 603
PROCESSOR_PPC_604: UInt32 = 604
PROCESSOR_PPC_620: UInt32 = 620
PROCESSOR_HITACHI_SH3: UInt32 = 10003
PROCESSOR_HITACHI_SH3E: UInt32 = 10004
PROCESSOR_HITACHI_SH4: UInt32 = 10005
PROCESSOR_MOTOROLA_821: UInt32 = 821
PROCESSOR_SHx_SH3: UInt32 = 103
PROCESSOR_SHx_SH4: UInt32 = 104
PROCESSOR_STRONGARM: UInt32 = 2577
PROCESSOR_ARM720: UInt32 = 1824
PROCESSOR_ARM820: UInt32 = 2080
PROCESSOR_ARM920: UInt32 = 2336
PROCESSOR_ARM_7TDMI: UInt32 = 70001
PROCESSOR_OPTIL: UInt32 = 18767
XSTATE_LEGACY_FLOATING_POINT: UInt32 = 0
XSTATE_LEGACY_SSE: UInt32 = 1
XSTATE_GSSE: UInt32 = 2
XSTATE_AVX: UInt32 = 2
XSTATE_MPX_BNDREGS: UInt32 = 3
XSTATE_MPX_BNDCSR: UInt32 = 4
XSTATE_AVX512_KMASK: UInt32 = 5
XSTATE_AVX512_ZMM_H: UInt32 = 6
XSTATE_AVX512_ZMM: UInt32 = 7
XSTATE_IPT: UInt32 = 8
XSTATE_PASID: UInt32 = 10
XSTATE_CET_U: UInt32 = 11
XSTATE_CET_S: UInt32 = 12
XSTATE_AMX_TILE_CONFIG: UInt32 = 17
XSTATE_AMX_TILE_DATA: UInt32 = 18
XSTATE_LWP: UInt32 = 62
MAXIMUM_XSTATE_FEATURES: UInt32 = 64
XSTATE_COMPACTION_ENABLE: UInt32 = 63
XSTATE_ALIGN_BIT: UInt32 = 1
XSTATE_XFD_BIT: UInt32 = 2
XSTATE_CONTROLFLAG_XSAVEOPT_MASK: UInt32 = 1
XSTATE_CONTROLFLAG_XSAVEC_MASK: UInt32 = 2
XSTATE_CONTROLFLAG_XFD_MASK: UInt32 = 4
CFG_CALL_TARGET_VALID: UInt32 = 1
CFG_CALL_TARGET_PROCESSED: UInt32 = 2
CFG_CALL_TARGET_CONVERT_EXPORT_SUPPRESSED_TO_VALID: UInt32 = 4
CFG_CALL_TARGET_VALID_XFG: UInt32 = 8
CFG_CALL_TARGET_CONVERT_XFG_TO_CFG: UInt32 = 16
SESSION_QUERY_ACCESS: UInt32 = 1
SESSION_MODIFY_ACCESS: UInt32 = 2
MEM_TOP_DOWN: UInt32 = 1048576
MEM_WRITE_WATCH: UInt32 = 2097152
MEM_PHYSICAL: UInt32 = 4194304
MEM_ROTATE: UInt32 = 8388608
MEM_DIFFERENT_IMAGE_BASE_OK: UInt32 = 8388608
MEM_4MB_PAGES: UInt32 = 2147483648
MEM_COALESCE_PLACEHOLDERS: UInt32 = 1
MEM_EXTENDED_PARAMETER_GRAPHICS: UInt32 = 1
MEM_EXTENDED_PARAMETER_NONPAGED: UInt32 = 2
MEM_EXTENDED_PARAMETER_ZERO_PAGES_OPTIONAL: UInt32 = 4
MEM_EXTENDED_PARAMETER_NONPAGED_LARGE: UInt32 = 8
MEM_EXTENDED_PARAMETER_NONPAGED_HUGE: UInt32 = 16
MEM_EXTENDED_PARAMETER_SOFT_FAULT_PAGES: UInt32 = 32
MEM_EXTENDED_PARAMETER_EC_CODE: UInt32 = 64
MEM_EXTENDED_PARAMETER_IMAGE_NO_HPAT: UInt32 = 128
MEM_EXTENDED_PARAMETER_TYPE_BITS: UInt32 = 8
SEC_HUGE_PAGES: UInt32 = 131072
WRITE_WATCH_FLAG_RESET: UInt32 = 1
ENCLAVE_TYPE_SGX: UInt32 = 1
ENCLAVE_TYPE_SGX2: UInt32 = 2
ENCLAVE_TYPE_VBS: UInt32 = 16
ENCLAVE_VBS_FLAG_DEBUG: UInt32 = 1
ENCLAVE_TYPE_VBS_BASIC: UInt32 = 17
VBS_BASIC_PAGE_MEASURED_DATA: UInt32 = 1
VBS_BASIC_PAGE_UNMEASURED_DATA: UInt32 = 2
VBS_BASIC_PAGE_ZERO_FILL: UInt32 = 3
VBS_BASIC_PAGE_THREAD_DESCRIPTOR: UInt32 = 4
VBS_BASIC_PAGE_SYSTEM_CALL: UInt32 = 5
DEDICATED_MEMORY_CACHE_ELIGIBLE: UInt32 = 1
TREE_CONNECT_ATTRIBUTE_PRIVACY: UInt32 = 16384
TREE_CONNECT_ATTRIBUTE_INTEGRITY: UInt32 = 32768
TREE_CONNECT_ATTRIBUTE_GLOBAL: UInt32 = 4
TREE_CONNECT_ATTRIBUTE_PINNED: UInt32 = 2
FILE_ATTRIBUTE_STRICTLY_SEQUENTIAL: UInt32 = 536870912
MAILSLOT_NO_MESSAGE: UInt32 = 4294967295
MAILSLOT_WAIT_FOREVER: UInt32 = 4294967295
FILE_CASE_SENSITIVE_SEARCH: UInt32 = 1
FILE_CASE_PRESERVED_NAMES: UInt32 = 2
FILE_UNICODE_ON_DISK: UInt32 = 4
FILE_PERSISTENT_ACLS: UInt32 = 8
FILE_FILE_COMPRESSION: UInt32 = 16
FILE_VOLUME_QUOTAS: UInt32 = 32
FILE_SUPPORTS_SPARSE_FILES: UInt32 = 64
FILE_SUPPORTS_REPARSE_POINTS: UInt32 = 128
FILE_SUPPORTS_REMOTE_STORAGE: UInt32 = 256
FILE_RETURNS_CLEANUP_RESULT_INFO: UInt32 = 512
FILE_SUPPORTS_POSIX_UNLINK_RENAME: UInt32 = 1024
FILE_SUPPORTS_BYPASS_IO: UInt32 = 2048
FILE_SUPPORTS_STREAM_SNAPSHOTS: UInt32 = 4096
FILE_SUPPORTS_CASE_SENSITIVE_DIRS: UInt32 = 8192
FILE_VOLUME_IS_COMPRESSED: UInt32 = 32768
FILE_SUPPORTS_OBJECT_IDS: UInt32 = 65536
FILE_SUPPORTS_ENCRYPTION: UInt32 = 131072
FILE_NAMED_STREAMS: UInt32 = 262144
FILE_READ_ONLY_VOLUME: UInt32 = 524288
FILE_SEQUENTIAL_WRITE_ONCE: UInt32 = 1048576
FILE_SUPPORTS_TRANSACTIONS: UInt32 = 2097152
FILE_SUPPORTS_HARD_LINKS: UInt32 = 4194304
FILE_SUPPORTS_EXTENDED_ATTRIBUTES: UInt32 = 8388608
FILE_SUPPORTS_OPEN_BY_FILE_ID: UInt32 = 16777216
FILE_SUPPORTS_USN_JOURNAL: UInt32 = 33554432
FILE_SUPPORTS_INTEGRITY_STREAMS: UInt32 = 67108864
FILE_SUPPORTS_BLOCK_REFCOUNTING: UInt32 = 134217728
FILE_SUPPORTS_SPARSE_VDL: UInt32 = 268435456
FILE_DAX_VOLUME: UInt32 = 536870912
FILE_SUPPORTS_GHOSTING: UInt32 = 1073741824
FILE_NAME_FLAG_HARDLINK: UInt32 = 0
FILE_NAME_FLAG_NTFS: UInt32 = 1
FILE_NAME_FLAG_DOS: UInt32 = 2
FILE_NAME_FLAG_BOTH: UInt32 = 3
FILE_NAME_FLAGS_UNSPECIFIED: UInt32 = 128
FILE_CS_FLAG_CASE_SENSITIVE_DIR: UInt32 = 1
FLUSH_FLAGS_FILE_DATA_ONLY: UInt32 = 1
FLUSH_FLAGS_NO_SYNC: UInt32 = 2
FLUSH_FLAGS_FILE_DATA_SYNC_ONLY: UInt32 = 4
IO_REPARSE_TAG_RESERVED_ZERO: UInt32 = 0
IO_REPARSE_TAG_RESERVED_ONE: UInt32 = 1
IO_REPARSE_TAG_RESERVED_TWO: UInt32 = 2
IO_REPARSE_TAG_RESERVED_RANGE: UInt32 = 2
IO_REPARSE_TAG_RESERVED_INVALID: Int32 = -1073709056
IO_REPARSE_TAG_MOUNT_POINT: UInt32 = 2684354563
IO_REPARSE_TAG_HSM: UInt32 = 3221225476
IO_REPARSE_TAG_HSM2: UInt32 = 2147483654
IO_REPARSE_TAG_SIS: UInt32 = 2147483655
IO_REPARSE_TAG_WIM: UInt32 = 2147483656
IO_REPARSE_TAG_CSV: UInt32 = 2147483657
IO_REPARSE_TAG_DFS: UInt32 = 2147483658
IO_REPARSE_TAG_SYMLINK: UInt32 = 2684354572
IO_REPARSE_TAG_DFSR: UInt32 = 2147483666
IO_REPARSE_TAG_DEDUP: UInt32 = 2147483667
IO_REPARSE_TAG_NFS: UInt32 = 2147483668
IO_REPARSE_TAG_FILE_PLACEHOLDER: UInt32 = 2147483669
IO_REPARSE_TAG_WOF: UInt32 = 2147483671
IO_REPARSE_TAG_WCI: UInt32 = 2147483672
IO_REPARSE_TAG_WCI_1: UInt32 = 2415923224
IO_REPARSE_TAG_GLOBAL_REPARSE: UInt32 = 2684354585
IO_REPARSE_TAG_CLOUD: UInt32 = 2415919130
IO_REPARSE_TAG_CLOUD_1: UInt32 = 2415923226
IO_REPARSE_TAG_CLOUD_2: UInt32 = 2415927322
IO_REPARSE_TAG_CLOUD_3: UInt32 = 2415931418
IO_REPARSE_TAG_CLOUD_4: UInt32 = 2415935514
IO_REPARSE_TAG_CLOUD_5: UInt32 = 2415939610
IO_REPARSE_TAG_CLOUD_6: UInt32 = 2415943706
IO_REPARSE_TAG_CLOUD_7: UInt32 = 2415947802
IO_REPARSE_TAG_CLOUD_8: UInt32 = 2415951898
IO_REPARSE_TAG_CLOUD_9: UInt32 = 2415955994
IO_REPARSE_TAG_CLOUD_A: UInt32 = 2415960090
IO_REPARSE_TAG_CLOUD_B: UInt32 = 2415964186
IO_REPARSE_TAG_CLOUD_C: UInt32 = 2415968282
IO_REPARSE_TAG_CLOUD_D: UInt32 = 2415972378
IO_REPARSE_TAG_CLOUD_E: UInt32 = 2415976474
IO_REPARSE_TAG_CLOUD_F: UInt32 = 2415980570
IO_REPARSE_TAG_CLOUD_MASK: UInt32 = 61440
IO_REPARSE_TAG_APPEXECLINK: UInt32 = 2147483675
IO_REPARSE_TAG_PROJFS: UInt32 = 2415919132
IO_REPARSE_TAG_STORAGE_SYNC: UInt32 = 2147483678
IO_REPARSE_TAG_WCI_TOMBSTONE: UInt32 = 2684354591
IO_REPARSE_TAG_UNHANDLED: UInt32 = 2147483680
IO_REPARSE_TAG_ONEDRIVE: UInt32 = 2147483681
IO_REPARSE_TAG_PROJFS_TOMBSTONE: UInt32 = 2684354594
IO_REPARSE_TAG_AF_UNIX: UInt32 = 2147483683
IO_REPARSE_TAG_WCI_LINK: UInt32 = 2684354599
IO_REPARSE_TAG_WCI_LINK_1: UInt32 = 2684358695
IO_REPARSE_TAG_DATALESS_CIM: UInt32 = 2684354600
SCRUB_DATA_INPUT_FLAG_RESUME: UInt32 = 1
SCRUB_DATA_INPUT_FLAG_SKIP_IN_SYNC: UInt32 = 2
SCRUB_DATA_INPUT_FLAG_SKIP_NON_INTEGRITY_DATA: UInt32 = 4
SCRUB_DATA_INPUT_FLAG_IGNORE_REDUNDANCY: UInt32 = 8
SCRUB_DATA_INPUT_FLAG_SKIP_DATA: UInt32 = 16
SCRUB_DATA_INPUT_FLAG_SCRUB_BY_OBJECT_ID: UInt32 = 32
SCRUB_DATA_INPUT_FLAG_OPLOCK_NOT_ACQUIRED: UInt32 = 64
SCRUB_DATA_OUTPUT_FLAG_INCOMPLETE: UInt32 = 1
SCRUB_DATA_OUTPUT_FLAG_NON_USER_DATA_RANGE: UInt32 = 65536
SCRUB_DATA_OUTPUT_FLAG_PARITY_EXTENT_DATA_RETURNED: UInt32 = 131072
SCRUB_DATA_OUTPUT_FLAG_RESUME_CONTEXT_LENGTH_SPECIFIED: UInt32 = 262144
SHUFFLE_FILE_FLAG_SKIP_INITIALIZING_NEW_CLUSTERS: UInt32 = 1
IO_COMPLETION_MODIFY_STATE: UInt32 = 2
SMB_CCF_APP_INSTANCE_EA_NAME: String = 'ClusteredApplicationInstance'
NETWORK_APP_INSTANCE_CSV_FLAGS_VALID_ONLY_IF_CSV_COORDINATOR: UInt32 = 1
GUID_MAX_POWER_SAVINGS: Guid = Guid('{a1841308-3541-4fab-bc81-f71556f20b4a}')
GUID_MIN_POWER_SAVINGS: Guid = Guid('{8c5e7fda-e8bf-4a96-9a85-a6e23a8c635c}')
GUID_TYPICAL_POWER_SAVINGS: Guid = Guid('{381b4222-f694-41f0-9685-ff5bb260df2e}')
NO_SUBGROUP_GUID: Guid = Guid('{fea3413e-7e05-4911-9a71-700331f1c294}')
ALL_POWERSCHEMES_GUID: Guid = Guid('{68a1e95e-13ea-41e1-8011-0c496ca490b0}')
GUID_POWERSCHEME_PERSONALITY: Guid = Guid('{245d8541-3943-4422-b025-13a784f679b7}')
GUID_ACTIVE_POWERSCHEME: Guid = Guid('{31f9f286-5084-42fe-b720-2b0264993763}')
GUID_IDLE_RESILIENCY_SUBGROUP: Guid = Guid('{2e601130-5351-4d9d-8e04-252966bad054}')
GUID_IDLE_RESILIENCY_PERIOD: Guid = Guid('{c42b79aa-aa3a-484b-a98f-2cf32aa90a28}')
GUID_DEEP_SLEEP_ENABLED: Guid = Guid('{d502f7ee-1dc7-4efd-a55d-f04b6f5c0545}')
GUID_DEEP_SLEEP_PLATFORM_STATE: Guid = Guid('{d23f2fb8-9536-4038-9c94-1ce02e5c2152}')
GUID_DISK_COALESCING_POWERDOWN_TIMEOUT: Guid = Guid('{c36f0eb4-2988-4a70-8eee-0884fc2c2433}')
GUID_EXECUTION_REQUIRED_REQUEST_TIMEOUT: Guid = Guid('{3166bc41-7e98-4e03-b34e-ec0f5f2b218e}')
GUID_VIDEO_SUBGROUP: Guid = Guid('{7516b95f-f776-4464-8c53-06167f40cc99}')
GUID_VIDEO_POWERDOWN_TIMEOUT: Guid = Guid('{3c0bc021-c8a8-4e07-a973-6b14cbcb2b7e}')
GUID_VIDEO_ANNOYANCE_TIMEOUT: Guid = Guid('{82dbcf2d-cd67-40c5-bfdc-9f1a5ccd4663}')
GUID_VIDEO_ADAPTIVE_PERCENT_INCREASE: Guid = Guid('{eed904df-b142-4183-b10b-5a1197a37864}')
GUID_VIDEO_DIM_TIMEOUT: Guid = Guid('{17aaa29b-8b43-4b94-aafe-35f64daaf1ee}')
GUID_VIDEO_ADAPTIVE_POWERDOWN: Guid = Guid('{90959d22-d6a1-49b9-af93-bce885ad335b}')
GUID_MONITOR_POWER_ON: Guid = Guid('{02731015-4510-4526-99e6-e5a17ebd1aea}')
GUID_DEVICE_POWER_POLICY_VIDEO_BRIGHTNESS: Guid = Guid('{aded5e82-b909-4619-9949-f5d71dac0bcb}')
GUID_DEVICE_POWER_POLICY_VIDEO_DIM_BRIGHTNESS: Guid = Guid('{f1fbfde2-a960-4165-9f88-50667911ce96}')
GUID_VIDEO_CURRENT_MONITOR_BRIGHTNESS: Guid = Guid('{8ffee2c6-2d01-46be-adb9-398addc5b4ff}')
GUID_VIDEO_ADAPTIVE_DISPLAY_BRIGHTNESS: Guid = Guid('{fbd9aa66-9553-4097-ba44-ed6e9d65eab8}')
GUID_CONSOLE_DISPLAY_STATE: Guid = Guid('{6fe69556-704a-47a0-8f24-c28d936fda47}')
GUID_ALLOW_DISPLAY_REQUIRED: Guid = Guid('{a9ceb8da-cd46-44fb-a98b-02af69de4623}')
GUID_VIDEO_CONSOLE_LOCK_TIMEOUT: Guid = Guid('{8ec4b3a5-6868-48c2-be75-4f3044be88a7}')
GUID_ADVANCED_COLOR_QUALITY_BIAS: Guid = Guid('{684c3e69-a4f7-4014-8754-d45179a56167}')
GUID_ADAPTIVE_POWER_BEHAVIOR_SUBGROUP: Guid = Guid('{8619b916-e004-4dd8-9b66-dae86f806698}')
GUID_NON_ADAPTIVE_INPUT_TIMEOUT: Guid = Guid('{5adbbfbc-074e-4da1-ba38-db8b36b2c8f3}')
GUID_ADAPTIVE_INPUT_CONTROLLER_STATE: Guid = Guid('{0e98fae9-f45a-4de1-a757-6031f197f6ea}')
GUID_DISK_SUBGROUP: Guid = Guid('{0012ee47-9041-4b5d-9b77-535fba8b1442}')
GUID_DISK_MAX_POWER: Guid = Guid('{51dea550-bb38-4bc4-991b-eacf37be5ec8}')
GUID_DISK_POWERDOWN_TIMEOUT: Guid = Guid('{6738e2c4-e8a5-4a42-b16a-e040e769756e}')
GUID_DISK_IDLE_TIMEOUT: Guid = Guid('{58e39ba8-b8e6-4ef6-90d0-89ae32b258d6}')
GUID_DISK_BURST_IGNORE_THRESHOLD: Guid = Guid('{80e3c60e-bb94-4ad8-bbe0-0d3195efc663}')
GUID_DISK_ADAPTIVE_POWERDOWN: Guid = Guid('{396a32e1-499a-40b2-9124-a96afe707667}')
GUID_DISK_NVME_NOPPME: Guid = Guid('{fc7372b6-ab2d-43ee-8797-15e9841f2cca}')
GUID_SLEEP_SUBGROUP: Guid = Guid('{238c9fa8-0aad-41ed-83f4-97be242c8f20}')
GUID_SLEEP_IDLE_THRESHOLD: Guid = Guid('{81cd32e0-7833-44f3-8737-7081f38d1f70}')
GUID_STANDBY_TIMEOUT: Guid = Guid('{29f6c1db-86da-48c5-9fdb-f2b67b1f44da}')
GUID_UNATTEND_SLEEP_TIMEOUT: Guid = Guid('{7bc4a2f9-d8fc-4469-b07b-33eb785aaca0}')
GUID_HIBERNATE_TIMEOUT: Guid = Guid('{9d7815a6-7ee4-497e-8888-515a05f02364}')
GUID_HIBERNATE_FASTS4_POLICY: Guid = Guid('{94ac6d29-73ce-41a6-809f-6363ba21b47e}')
GUID_CRITICAL_POWER_TRANSITION: Guid = Guid('{b7a27025-e569-46c2-a504-2b96cad225a1}')
GUID_SYSTEM_AWAYMODE: Guid = Guid('{98a7f580-01f7-48aa-9c0f-44352c29e5c0}')
GUID_ALLOW_AWAYMODE: Guid = Guid('{25dfa149-5dd1-4736-b5ab-e8a37b5b8187}')
GUID_USER_PRESENCE_PREDICTION: Guid = Guid('{82011705-fb95-4d46-8d35-4042b1d20def}')
GUID_STANDBY_BUDGET_GRACE_PERIOD: Guid = Guid('{60c07fe1-0556-45cf-9903-d56e32210242}')
GUID_STANDBY_BUDGET_PERCENT: Guid = Guid('{9fe527be-1b70-48da-930d-7bcf17b44990}')
GUID_STANDBY_RESERVE_GRACE_PERIOD: Guid = Guid('{c763ee92-71e8-4127-84eb-f6ed043a3e3d}')
GUID_STANDBY_RESERVE_TIME: Guid = Guid('{468fe7e5-1158-46ec-88bc-5b96c9e44fd0}')
GUID_STANDBY_RESET_PERCENT: Guid = Guid('{49cb11a5-56e2-4afb-9d38-3df47872e21b}')
GUID_HUPR_ADAPTIVE_AWAY_DISPLAY_TIMEOUT: Guid = Guid('{0a7d6ab6-ac83-4ad1-8282-eca5b58308f3}')
GUID_HUPR_ADAPTIVE_INATTENTIVE_DIM_TIMEOUT: Guid = Guid('{cf8c6097-12b8-4279-bbdd-44601ee5209d}')
GUID_HUPR_ADAPTIVE_INATTENTIVE_DISPLAY_TIMEOUT: Guid = Guid('{ee16691e-6ab3-4619-bb48-1c77c9357e5a}')
GUID_HUPR_ADAPTIVE_AWAY_DIM_TIMEOUT: Guid = Guid('{a79c8e0e-f271-482d-8f8a-5db9a18312de}')
GUID_ALLOW_STANDBY_STATES: Guid = Guid('{abfc2519-3608-4c2a-94ea-171b0ed546ab}')
GUID_ALLOW_RTC_WAKE: Guid = Guid('{bd3b718a-0680-4d9d-8ab2-e1d2b4ac806d}')
GUID_LEGACY_RTC_MITIGATION: Guid = Guid('{1a34bdc3-7e6b-442e-a9d0-64b6ef378e84}')
GUID_ALLOW_SYSTEM_REQUIRED: Guid = Guid('{a4b195f5-8225-47d8-8012-9d41369786e2}')
GUID_POWER_SAVING_STATUS: Guid = Guid('{e00958c0-c213-4ace-ac77-fecced2eeea5}')
GUID_ENERGY_SAVER_SUBGROUP: Guid = Guid('{de830923-a562-41af-a086-e3a2c6bad2da}')
GUID_ENERGY_SAVER_BATTERY_THRESHOLD: Guid = Guid('{e69653ca-cf7f-4f05-aa73-cb833fa90ad4}')
GUID_ENERGY_SAVER_BRIGHTNESS: Guid = Guid('{13d09884-f74e-474a-a852-b6bde8ad03a8}')
GUID_ENERGY_SAVER_POLICY: Guid = Guid('{5c5bb349-ad29-4ee2-9d0b-2b25270f7a81}')
GUID_SYSTEM_BUTTON_SUBGROUP: Guid = Guid('{4f971e89-eebd-4455-a8de-9e59040e7347}')
POWERBUTTON_ACTION_INDEX_NOTHING: UInt32 = 0
POWERBUTTON_ACTION_INDEX_SLEEP: UInt32 = 1
POWERBUTTON_ACTION_INDEX_HIBERNATE: UInt32 = 2
POWERBUTTON_ACTION_INDEX_SHUTDOWN: UInt32 = 3
POWERBUTTON_ACTION_INDEX_TURN_OFF_THE_DISPLAY: UInt32 = 4
POWERBUTTON_ACTION_VALUE_NOTHING: UInt32 = 0
POWERBUTTON_ACTION_VALUE_SLEEP: UInt32 = 2
POWERBUTTON_ACTION_VALUE_HIBERNATE: UInt32 = 3
POWERBUTTON_ACTION_VALUE_SHUTDOWN: UInt32 = 6
POWERBUTTON_ACTION_VALUE_TURN_OFF_THE_DISPLAY: UInt32 = 8
GUID_POWERBUTTON_ACTION: Guid = Guid('{7648efa3-dd9c-4e3e-b566-50f929386280}')
GUID_SLEEPBUTTON_ACTION: Guid = Guid('{96996bc0-ad50-47ec-923b-6f41874dd9eb}')
GUID_USERINTERFACEBUTTON_ACTION: Guid = Guid('{a7066653-8d6c-40a8-910e-a1f54b84c7e5}')
GUID_LIDCLOSE_ACTION: Guid = Guid('{5ca83367-6e45-459f-a27b-476b1d01c936}')
GUID_LIDOPEN_POWERSTATE: Guid = Guid('{99ff10e7-23b1-4c07-a9d1-5c3206d741b4}')
GUID_BATTERY_SUBGROUP: Guid = Guid('{e73a048d-bf27-4f12-9731-8b2076e8891f}')
GUID_BATTERY_DISCHARGE_ACTION_0: Guid = Guid('{637ea02f-bbcb-4015-8e2c-a1c7b9c0b546}')
GUID_BATTERY_DISCHARGE_LEVEL_0: Guid = Guid('{9a66d8d7-4ff7-4ef9-b5a2-5a326ca2a469}')
GUID_BATTERY_DISCHARGE_FLAGS_0: Guid = Guid('{5dbb7c9f-38e9-40d2-9749-4f8a0e9f640f}')
GUID_BATTERY_DISCHARGE_ACTION_1: Guid = Guid('{d8742dcb-3e6a-4b3c-b3fe-374623cdcf06}')
GUID_BATTERY_DISCHARGE_LEVEL_1: Guid = Guid('{8183ba9a-e910-48da-8769-14ae6dc1170a}')
GUID_BATTERY_DISCHARGE_FLAGS_1: Guid = Guid('{bcded951-187b-4d05-bccc-f7e51960c258}')
GUID_BATTERY_DISCHARGE_ACTION_2: Guid = Guid('{421cba38-1a8e-4881-ac89-e33a8b04ece4}')
GUID_BATTERY_DISCHARGE_LEVEL_2: Guid = Guid('{07a07ca2-adaf-40d7-b077-533aaded1bfa}')
GUID_BATTERY_DISCHARGE_FLAGS_2: Guid = Guid('{7fd2f0c4-feb7-4da3-8117-e3fbedc46582}')
GUID_BATTERY_DISCHARGE_ACTION_3: Guid = Guid('{80472613-9780-455e-b308-72d3003cf2f8}')
GUID_BATTERY_DISCHARGE_LEVEL_3: Guid = Guid('{58afd5a6-c2dd-47d2-9fbf-ef70cc5c5965}')
GUID_BATTERY_DISCHARGE_FLAGS_3: Guid = Guid('{73613ccf-dbfa-4279-8356-4935f6bf62f3}')
GUID_PROCESSOR_SETTINGS_SUBGROUP: Guid = Guid('{54533251-82be-4824-96c1-47b60b740d00}')
GUID_PROCESSOR_THROTTLE_POLICY: Guid = Guid('{57027304-4af6-4104-9260-e3d95248fc36}')
PERFSTATE_POLICY_CHANGE_IDEAL: UInt32 = 0
PERFSTATE_POLICY_CHANGE_SINGLE: UInt32 = 1
PERFSTATE_POLICY_CHANGE_ROCKET: UInt32 = 2
PERFSTATE_POLICY_CHANGE_IDEAL_AGGRESSIVE: UInt32 = 3
PERFSTATE_POLICY_CHANGE_DECREASE_MAX: UInt32 = 2
PERFSTATE_POLICY_CHANGE_INCREASE_MAX: UInt32 = 3
GUID_PROCESSOR_THROTTLE_MAXIMUM: Guid = Guid('{bc5038f7-23e0-4960-96da-33abaf5935ec}')
GUID_PROCESSOR_THROTTLE_MAXIMUM_1: Guid = Guid('{bc5038f7-23e0-4960-96da-33abaf5935ed}')
GUID_PROCESSOR_THROTTLE_MINIMUM: Guid = Guid('{893dee8e-2bef-41e0-89c6-b55d0929964c}')
GUID_PROCESSOR_THROTTLE_MINIMUM_1: Guid = Guid('{893dee8e-2bef-41e0-89c6-b55d0929964d}')
GUID_PROCESSOR_FREQUENCY_LIMIT: Guid = Guid('{75b0ae3f-bce0-45a7-8c89-c9611c25e100}')
GUID_PROCESSOR_FREQUENCY_LIMIT_1: Guid = Guid('{75b0ae3f-bce0-45a7-8c89-c9611c25e101}')
GUID_PROCESSOR_ALLOW_THROTTLING: Guid = Guid('{3b04d4fd-1cc7-4f23-ab1c-d1337819c4bb}')
PROCESSOR_THROTTLE_DISABLED: UInt32 = 0
PROCESSOR_THROTTLE_ENABLED: UInt32 = 1
PROCESSOR_THROTTLE_AUTOMATIC: UInt32 = 2
GUID_PROCESSOR_IDLESTATE_POLICY: Guid = Guid('{68f262a7-f621-4069-b9a5-4874169be23c}')
GUID_PROCESSOR_PERFSTATE_POLICY: Guid = Guid('{bbdc3814-18e9-4463-8a55-d197327c45c0}')
GUID_PROCESSOR_PERF_INCREASE_THRESHOLD: Guid = Guid('{06cadf0e-64ed-448a-8927-ce7bf90eb35d}')
GUID_PROCESSOR_PERF_INCREASE_THRESHOLD_1: Guid = Guid('{06cadf0e-64ed-448a-8927-ce7bf90eb35e}')
GUID_PROCESSOR_PERF_DECREASE_THRESHOLD: Guid = Guid('{12a0ab44-fe28-4fa9-b3bd-4b64f44960a6}')
GUID_PROCESSOR_PERF_DECREASE_THRESHOLD_1: Guid = Guid('{12a0ab44-fe28-4fa9-b3bd-4b64f44960a7}')
GUID_PROCESSOR_PERF_INCREASE_POLICY: Guid = Guid('{465e1f50-b610-473a-ab58-00d1077dc418}')
GUID_PROCESSOR_PERF_INCREASE_POLICY_1: Guid = Guid('{465e1f50-b610-473a-ab58-00d1077dc419}')
GUID_PROCESSOR_PERF_DECREASE_POLICY: Guid = Guid('{40fbefc7-2e9d-4d25-a185-0cfd8574bac6}')
GUID_PROCESSOR_PERF_DECREASE_POLICY_1: Guid = Guid('{40fbefc7-2e9d-4d25-a185-0cfd8574bac7}')
GUID_PROCESSOR_PERF_INCREASE_TIME: Guid = Guid('{984cf492-3bed-4488-a8f9-4286c97bf5aa}')
GUID_PROCESSOR_PERF_INCREASE_TIME_1: Guid = Guid('{984cf492-3bed-4488-a8f9-4286c97bf5ab}')
GUID_PROCESSOR_PERF_DECREASE_TIME: Guid = Guid('{d8edeb9b-95cf-4f95-a73c-b061973693c8}')
GUID_PROCESSOR_PERF_DECREASE_TIME_1: Guid = Guid('{d8edeb9b-95cf-4f95-a73c-b061973693c9}')
GUID_PROCESSOR_PERF_TIME_CHECK: Guid = Guid('{4d2b0152-7d5c-498b-88e2-34345392a2c5}')
GUID_PROCESSOR_PERF_BOOST_POLICY: Guid = Guid('{45bcc044-d885-43e2-8605-ee0ec6e96b59}')
PROCESSOR_PERF_BOOST_POLICY_DISABLED: UInt32 = 0
PROCESSOR_PERF_BOOST_POLICY_MAX: UInt32 = 100
GUID_PROCESSOR_PERF_BOOST_MODE: Guid = Guid('{be337238-0d82-4146-a960-4f3749d470c7}')
PROCESSOR_PERF_BOOST_MODE_DISABLED: UInt32 = 0
PROCESSOR_PERF_BOOST_MODE_ENABLED: UInt32 = 1
PROCESSOR_PERF_BOOST_MODE_AGGRESSIVE: UInt32 = 2
PROCESSOR_PERF_BOOST_MODE_EFFICIENT_ENABLED: UInt32 = 3
PROCESSOR_PERF_BOOST_MODE_EFFICIENT_AGGRESSIVE: UInt32 = 4
PROCESSOR_PERF_BOOST_MODE_AGGRESSIVE_AT_GUARANTEED: UInt32 = 5
PROCESSOR_PERF_BOOST_MODE_EFFICIENT_AGGRESSIVE_AT_GUARANTEED: UInt32 = 6
PROCESSOR_PERF_BOOST_MODE_MAX: UInt32 = 6
GUID_PROCESSOR_PERF_AUTONOMOUS_MODE: Guid = Guid('{8baa4a8a-14c6-4451-8e8b-14bdbd197537}')
PROCESSOR_PERF_AUTONOMOUS_MODE_DISABLED: UInt32 = 0
PROCESSOR_PERF_AUTONOMOUS_MODE_ENABLED: UInt32 = 1
GUID_PROCESSOR_PERF_ENERGY_PERFORMANCE_PREFERENCE: Guid = Guid('{36687f9e-e3a5-4dbf-b1dc-15eb381c6863}')
GUID_PROCESSOR_PERF_ENERGY_PERFORMANCE_PREFERENCE_1: Guid = Guid('{36687f9e-e3a5-4dbf-b1dc-15eb381c6864}')
PROCESSOR_PERF_PERFORMANCE_PREFERENCE: UInt32 = 255
PROCESSOR_PERF_ENERGY_PREFERENCE: UInt32 = 0
GUID_PROCESSOR_PERF_AUTONOMOUS_ACTIVITY_WINDOW: Guid = Guid('{cfeda3d0-7697-4566-a922-a9086cd49dfa}')
PROCESSOR_PERF_MINIMUM_ACTIVITY_WINDOW: UInt32 = 0
PROCESSOR_PERF_MAXIMUM_ACTIVITY_WINDOW: UInt32 = 1270000000
GUID_PROCESSOR_DUTY_CYCLING: Guid = Guid('{4e4450b3-6179-4e91-b8f1-5bb9938f81a1}')
PROCESSOR_DUTY_CYCLING_DISABLED: UInt32 = 0
PROCESSOR_DUTY_CYCLING_ENABLED: UInt32 = 1
GUID_PROCESSOR_IDLE_ALLOW_SCALING: Guid = Guid('{6c2993b0-8f48-481f-bcc6-00dd2742aa06}')
GUID_PROCESSOR_IDLE_DISABLE: Guid = Guid('{5d76a2ca-e8c0-402f-a133-2158492d58ad}')
GUID_PROCESSOR_IDLE_STATE_MAXIMUM: Guid = Guid('{9943e905-9a30-4ec1-9b99-44dd3b76f7a2}')
GUID_PROCESSOR_IDLE_TIME_CHECK: Guid = Guid('{c4581c31-89ab-4597-8e2b-9c9cab440e6b}')
GUID_PROCESSOR_IDLE_DEMOTE_THRESHOLD: Guid = Guid('{4b92d758-5a24-4851-a470-815d78aee119}')
GUID_PROCESSOR_IDLE_PROMOTE_THRESHOLD: Guid = Guid('{7b224883-b3cc-4d79-819f-8374152cbe7c}')
GUID_PROCESSOR_CORE_PARKING_INCREASE_THRESHOLD: Guid = Guid('{df142941-20f3-4edf-9a4a-9c83d3d717d1}')
GUID_PROCESSOR_CORE_PARKING_DECREASE_THRESHOLD: Guid = Guid('{68dd2f27-a4ce-4e11-8487-3794e4135dfa}')
GUID_PROCESSOR_CORE_PARKING_INCREASE_POLICY: Guid = Guid('{c7be0679-2817-4d69-9d02-519a537ed0c6}')
CORE_PARKING_POLICY_CHANGE_IDEAL: UInt32 = 0
CORE_PARKING_POLICY_CHANGE_SINGLE: UInt32 = 1
CORE_PARKING_POLICY_CHANGE_ROCKET: UInt32 = 2
CORE_PARKING_POLICY_CHANGE_MULTISTEP: UInt32 = 3
CORE_PARKING_POLICY_CHANGE_MAX: UInt32 = 3
GUID_PROCESSOR_CORE_PARKING_DECREASE_POLICY: Guid = Guid('{71021b41-c749-4d21-be74-a00f335d582b}')
GUID_PROCESSOR_CORE_PARKING_MAX_CORES: Guid = Guid('{ea062031-0e34-4ff1-9b6d-eb1059334028}')
GUID_PROCESSOR_CORE_PARKING_MAX_CORES_1: Guid = Guid('{ea062031-0e34-4ff1-9b6d-eb1059334029}')
GUID_PROCESSOR_CORE_PARKING_MIN_CORES: Guid = Guid('{0cc5b647-c1df-4637-891a-dec35c318583}')
GUID_PROCESSOR_CORE_PARKING_MIN_CORES_1: Guid = Guid('{0cc5b647-c1df-4637-891a-dec35c318584}')
GUID_PROCESSOR_CORE_PARKING_INCREASE_TIME: Guid = Guid('{2ddd5a84-5a71-437e-912a-db0b8c788732}')
GUID_PROCESSOR_CORE_PARKING_DECREASE_TIME: Guid = Guid('{dfd10d17-d5eb-45dd-877a-9a34ddd15c82}')
GUID_PROCESSOR_CORE_PARKING_AFFINITY_HISTORY_DECREASE_FACTOR: Guid = Guid('{8f7b45e3-c393-480a-878c-f67ac3d07082}')
GUID_PROCESSOR_CORE_PARKING_AFFINITY_HISTORY_THRESHOLD: Guid = Guid('{5b33697b-e89d-4d38-aa46-9e7dfb7cd2f9}')
GUID_PROCESSOR_CORE_PARKING_AFFINITY_WEIGHTING: Guid = Guid('{e70867f1-fa2f-4f4e-aea1-4d8a0ba23b20}')
GUID_PROCESSOR_CORE_PARKING_OVER_UTILIZATION_HISTORY_DECREASE_FACTOR: Guid = Guid('{1299023c-bc28-4f0a-81ec-d3295a8d815d}')
GUID_PROCESSOR_CORE_PARKING_OVER_UTILIZATION_HISTORY_THRESHOLD: Guid = Guid('{9ac18e92-aa3c-4e27-b307-01ae37307129}')
GUID_PROCESSOR_CORE_PARKING_OVER_UTILIZATION_WEIGHTING: Guid = Guid('{8809c2d8-b155-42d4-bcda-0d345651b1db}')
GUID_PROCESSOR_CORE_PARKING_OVER_UTILIZATION_THRESHOLD: Guid = Guid('{943c8cb6-6f93-4227-ad87-e9a3feec08d1}')
GUID_PROCESSOR_PARKING_CORE_OVERRIDE: Guid = Guid('{a55612aa-f624-42c6-a443-7397d064c04f}')
GUID_PROCESSOR_PARKING_PERF_STATE: Guid = Guid('{447235c7-6a8d-4cc0-8e24-9eaf70b96e2b}')
GUID_PROCESSOR_PARKING_PERF_STATE_1: Guid = Guid('{447235c7-6a8d-4cc0-8e24-9eaf70b96e2c}')
GUID_PROCESSOR_PARKING_CONCURRENCY_THRESHOLD: Guid = Guid('{2430ab6f-a520-44a2-9601-f7f23b5134b1}')
GUID_PROCESSOR_PARKING_HEADROOM_THRESHOLD: Guid = Guid('{f735a673-2066-4f80-a0c5-ddee0cf1bf5d}')
GUID_PROCESSOR_PARKING_DISTRIBUTION_THRESHOLD: Guid = Guid('{4bdaf4e9-d103-46d7-a5f0-6280121616ef}')
GUID_PROCESSOR_SOFT_PARKING_LATENCY: Guid = Guid('{97cfac41-2217-47eb-992d-618b1977c907}')
GUID_PROCESSOR_PERF_HISTORY: Guid = Guid('{7d24baa7-0b84-480f-840c-1b0743c00f5f}')
GUID_PROCESSOR_PERF_HISTORY_1: Guid = Guid('{7d24baa7-0b84-480f-840c-1b0743c00f60}')
GUID_PROCESSOR_PERF_INCREASE_HISTORY: Guid = Guid('{99b3ef01-752f-46a1-80fb-7730011f2354}')
GUID_PROCESSOR_PERF_DECREASE_HISTORY: Guid = Guid('{0300f6f8-abd6-45a9-b74f-4908691a40b5}')
GUID_PROCESSOR_PERF_CORE_PARKING_HISTORY: Guid = Guid('{77d7f282-8f1a-42cd-8537-45450a839be8}')
GUID_PROCESSOR_PERF_LATENCY_HINT: Guid = Guid('{0822df31-9c83-441c-a079-0de4cf009c7b}')
GUID_PROCESSOR_PERF_LATENCY_HINT_PERF: Guid = Guid('{619b7505-003b-4e82-b7a6-4dd29c300971}')
GUID_PROCESSOR_PERF_LATENCY_HINT_PERF_1: Guid = Guid('{619b7505-003b-4e82-b7a6-4dd29c300972}')
GUID_PROCESSOR_LATENCY_HINT_MIN_UNPARK: Guid = Guid('{616cdaa5-695e-4545-97ad-97dc2d1bdd88}')
GUID_PROCESSOR_LATENCY_HINT_MIN_UNPARK_1: Guid = Guid('{616cdaa5-695e-4545-97ad-97dc2d1bdd89}')
GUID_PROCESSOR_MODULE_PARKING_POLICY: Guid = Guid('{b0deaf6b-59c0-4523-8a45-ca7f40244114}')
GUID_PROCESSOR_COMPLEX_PARKING_POLICY: Guid = Guid('{b669a5e9-7b1d-4132-baaa-49190abcfeb6}')
PARKING_TOPOLOGY_POLICY_DISABLED: UInt32 = 0
PARKING_TOPOLOGY_POLICY_ROUNDROBIN: UInt32 = 1
PARKING_TOPOLOGY_POLICY_SEQUENTIAL: UInt32 = 2
GUID_PROCESSOR_SMT_UNPARKING_POLICY: Guid = Guid('{b28a6829-c5f7-444e-8f61-10e24e85c532}')
SMT_UNPARKING_POLICY_CORE: UInt32 = 0
SMT_UNPARKING_POLICY_CORE_PER_THREAD: UInt32 = 1
SMT_UNPARKING_POLICY_LP_ROUNDROBIN: UInt32 = 2
SMT_UNPARKING_POLICY_LP_SEQUENTIAL: UInt32 = 3
GUID_PROCESSOR_DISTRIBUTE_UTILITY: Guid = Guid('{e0007330-f589-42ed-a401-5ddb10e785d3}')
GUID_PROCESSOR_HETEROGENEOUS_POLICY: Guid = Guid('{7f2f5cfa-f10c-4823-b5e1-e93ae85f46b5}')
GUID_PROCESSOR_HETERO_DECREASE_TIME: Guid = Guid('{7f2492b6-60b1-45e5-ae55-773f8cd5caec}')
GUID_PROCESSOR_HETERO_INCREASE_TIME: Guid = Guid('{4009efa7-e72d-4cba-9edf-91084ea8cbc3}')
GUID_PROCESSOR_HETERO_DECREASE_THRESHOLD: Guid = Guid('{f8861c27-95e7-475c-865b-13c0cb3f9d6b}')
GUID_PROCESSOR_HETERO_DECREASE_THRESHOLD_1: Guid = Guid('{f8861c27-95e7-475c-865b-13c0cb3f9d6c}')
GUID_PROCESSOR_HETERO_INCREASE_THRESHOLD: Guid = Guid('{b000397d-9b0b-483d-98c9-692a6060cfbf}')
GUID_PROCESSOR_HETERO_INCREASE_THRESHOLD_1: Guid = Guid('{b000397d-9b0b-483d-98c9-692a6060cfc0}')
GUID_PROCESSOR_CLASS0_FLOOR_PERF: Guid = Guid('{fddc842b-8364-4edc-94cf-c17f60de1c80}')
GUID_PROCESSOR_CLASS1_INITIAL_PERF: Guid = Guid('{1facfc65-a930-4bc5-9f38-504ec097bbc0}')
GUID_PROCESSOR_THREAD_SCHEDULING_POLICY: Guid = Guid('{93b8b6dc-0698-4d1c-9ee4-0644e900c85d}')
GUID_PROCESSOR_SHORT_THREAD_SCHEDULING_POLICY: Guid = Guid('{bae08b81-2d5e-4688-ad6a-13243356654b}')
GUID_PROCESSOR_SHORT_THREAD_RUNTIME_THRESHOLD: Guid = Guid('{d92998c2-6a48-49ca-85d4-8cceec294570}')
GUID_PROCESSOR_SHORT_THREAD_ARCH_CLASS_UPPER_THRESHOLD: Guid = Guid('{828423eb-8662-4344-90f7-52bf15870f5a}')
GUID_PROCESSOR_SHORT_THREAD_ARCH_CLASS_LOWER_THRESHOLD: Guid = Guid('{53824d46-87bd-4739-aa1b-aa793fac36d6}')
GUID_PROCESSOR_LONG_THREAD_ARCH_CLASS_UPPER_THRESHOLD: Guid = Guid('{bf903d33-9d24-49d3-a468-e65e0325046a}')
GUID_PROCESSOR_LONG_THREAD_ARCH_CLASS_LOWER_THRESHOLD: Guid = Guid('{43f278bc-0f8a-46d0-8b31-9a23e615d713}')
GUID_SYSTEM_COOLING_POLICY: Guid = Guid('{94d3a615-a899-4ac5-ae2b-e4d8f634367f}')
GUID_PROCESSOR_RESPONSIVENESS_DISABLE_THRESHOLD: Guid = Guid('{38b8383d-cce0-4c79-9e3e-56a4f17cc480}')
GUID_PROCESSOR_RESPONSIVENESS_DISABLE_THRESHOLD_1: Guid = Guid('{38b8383d-cce0-4c79-9e3e-56a4f17cc481}')
GUID_PROCESSOR_RESPONSIVENESS_ENABLE_THRESHOLD: Guid = Guid('{3d44e256-7222-4415-a9ed-9c45fa3dd830}')
GUID_PROCESSOR_RESPONSIVENESS_ENABLE_THRESHOLD_1: Guid = Guid('{3d44e256-7222-4415-a9ed-9c45fa3dd831}')
GUID_PROCESSOR_RESPONSIVENESS_DISABLE_TIME: Guid = Guid('{f565999f-3fb0-411a-a226-3f0198dec130}')
GUID_PROCESSOR_RESPONSIVENESS_DISABLE_TIME_1: Guid = Guid('{f565999f-3fb0-411a-a226-3f0198dec131}')
GUID_PROCESSOR_RESPONSIVENESS_ENABLE_TIME: Guid = Guid('{3d915188-7830-49ae-a79a-0fb0a1e5a200}')
GUID_PROCESSOR_RESPONSIVENESS_ENABLE_TIME_1: Guid = Guid('{3d915188-7830-49ae-a79a-0fb0a1e5a201}')
GUID_PROCESSOR_RESPONSIVENESS_EPP_CEILING: Guid = Guid('{4427c73b-9756-4a5c-b84b-c7bda79c7320}')
GUID_PROCESSOR_RESPONSIVENESS_EPP_CEILING_1: Guid = Guid('{4427c73b-9756-4a5c-b84b-c7bda79c7321}')
GUID_PROCESSOR_RESPONSIVENESS_PERF_FLOOR: Guid = Guid('{ce8e92ee-6a86-4572-bfe0-20c21d03cd40}')
GUID_PROCESSOR_RESPONSIVENESS_PERF_FLOOR_1: Guid = Guid('{ce8e92ee-6a86-4572-bfe0-20c21d03cd41}')
GUID_LOCK_CONSOLE_ON_WAKE: Guid = Guid('{0e796bdb-100d-47d6-a2d5-f7d2daa51f51}')
GUID_DEVICE_IDLE_POLICY: Guid = Guid('{4faab71a-92e5-4726-b531-224559672d19}')
POWER_DEVICE_IDLE_POLICY_PERFORMANCE: UInt32 = 0
POWER_DEVICE_IDLE_POLICY_CONSERVATIVE: UInt32 = 1
GUID_CONNECTIVITY_IN_STANDBY: Guid = Guid('{f15576e8-98b7-4186-b944-eafa664402d9}')
POWER_CONNECTIVITY_IN_STANDBY_DISABLED: UInt32 = 0
POWER_CONNECTIVITY_IN_STANDBY_ENABLED: UInt32 = 1
POWER_CONNECTIVITY_IN_STANDBY_SYSTEM_MANAGED: UInt32 = 2
GUID_DISCONNECTED_STANDBY_MODE: Guid = Guid('{68afb2d9-ee95-47a8-8f50-4115088073b1}')
POWER_DISCONNECTED_STANDBY_MODE_NORMAL: UInt32 = 0
POWER_DISCONNECTED_STANDBY_MODE_AGGRESSIVE: UInt32 = 1
GUID_ACDC_POWER_SOURCE: Guid = Guid('{5d3e9a59-e9d5-4b00-a6bd-ff34ff516548}')
GUID_LIDSWITCH_STATE_CHANGE: Guid = Guid('{ba3e0f4d-b817-4094-a2d1-d56379e6a0f3}')
GUID_LIDSWITCH_STATE_RELIABILITY: Guid = Guid('{ae4c4ff1-d361-43f4-80aa-bbb6eb03de94}')
GUID_BATTERY_PERCENTAGE_REMAINING: Guid = Guid('{a7ad8041-b45a-4cae-87a3-eecbb468a9e1}')
GUID_BATTERY_COUNT: Guid = Guid('{7d263f15-fca4-49e5-854b-a9f2bfbd5c24}')
GUID_GLOBAL_USER_PRESENCE: Guid = Guid('{786e8a1d-b427-4344-9207-09e70bdcbea9}')
GUID_SESSION_DISPLAY_STATUS: Guid = Guid('{2b84c20e-ad23-4ddf-93db-05ffbd7efca5}')
GUID_SESSION_USER_PRESENCE: Guid = Guid('{3c0f4548-c03f-4c4d-b9f2-237ede686376}')
GUID_IDLE_BACKGROUND_TASK: Guid = Guid('{515c31d8-f734-163d-a0fd-11a08c91e8f1}')
GUID_BACKGROUND_TASK_NOTIFICATION: Guid = Guid('{cf23f240-2a54-48d8-b114-de1518ff052e}')
GUID_APPLAUNCH_BUTTON: Guid = Guid('{1a689231-7399-4e9a-8f99-b71f999db3fa}')
GUID_PCIEXPRESS_SETTINGS_SUBGROUP: Guid = Guid('{501a4d13-42af-4429-9fd1-a8218c268e20}')
GUID_PCIEXPRESS_ASPM_POLICY: Guid = Guid('{ee12f906-d277-404b-b6da-e5fa1a576df5}')
GUID_ENABLE_SWITCH_FORCED_SHUTDOWN: Guid = Guid('{833a6b62-dfa4-46d1-82f8-e09e34d029d6}')
GUID_INTSTEER_SUBGROUP: Guid = Guid('{48672f38-7a9a-4bb2-8bf8-3d85be19de4e}')
GUID_INTSTEER_MODE: Guid = Guid('{2bfc24f9-5ea2-4801-8213-3dbae01aa39d}')
GUID_INTSTEER_LOAD_PER_PROC_TRIGGER: Guid = Guid('{73cde64d-d720-4bb2-a860-c755afe77ef2}')
GUID_INTSTEER_TIME_UNPARK_TRIGGER: Guid = Guid('{d6ba4903-386f-4c2c-8adb-5c21b3328d25}')
GUID_GRAPHICS_SUBGROUP: Guid = Guid('{5fb4938d-1ee8-4b0f-9a3c-5036b0ab995c}')
GUID_GPU_PREFERENCE_POLICY: Guid = Guid('{dd848b2a-8a5d-4451-9ae2-39cd41658f6c}')
GUID_MIXED_REALITY_MODE: Guid = Guid('{1e626b4e-cf04-4f8d-9cc7-c97c5b0f2391}')
GUID_SPR_ACTIVE_SESSION_CHANGE: Guid = Guid('{0e24ce38-c393-4742-bdb1-744f4b9ee08e}')
POWER_SYSTEM_MAXIMUM: UInt32 = 7
DIAGNOSTIC_REASON_VERSION: UInt32 = 0
DIAGNOSTIC_REASON_SIMPLE_STRING: UInt32 = 1
DIAGNOSTIC_REASON_DETAILED_STRING: UInt32 = 2
DIAGNOSTIC_REASON_NOT_SPECIFIED: UInt32 = 2147483648
POWER_REQUEST_CONTEXT_VERSION: UInt32 = 0
POWER_SETTING_VALUE_VERSION: UInt32 = 1
PROC_IDLE_BUCKET_COUNT: UInt32 = 6
PROC_IDLE_BUCKET_COUNT_EX: UInt32 = 16
ACPI_PPM_SOFTWARE_ALL: UInt32 = 252
ACPI_PPM_SOFTWARE_ANY: UInt32 = 253
ACPI_PPM_HARDWARE_ALL: UInt32 = 254
MS_PPM_SOFTWARE_ALL: UInt32 = 1
POWER_ACTION_QUERY_ALLOWED: UInt32 = 1
POWER_ACTION_UI_ALLOWED: UInt32 = 2
POWER_ACTION_OVERRIDE_APPS: UInt32 = 4
POWER_ACTION_HIBERBOOT: UInt32 = 8
POWER_ACTION_USER_NOTIFY: UInt32 = 16
POWER_ACTION_DOZE_TO_HIBERNATE: UInt32 = 32
POWER_ACTION_ACPI_CRITICAL: UInt32 = 16777216
POWER_ACTION_ACPI_USER_NOTIFY: UInt32 = 33554432
POWER_ACTION_DIRECTED_DRIPS: UInt32 = 67108864
POWER_ACTION_PSEUDO_TRANSITION: UInt32 = 134217728
POWER_ACTION_LIGHTEST_FIRST: UInt32 = 268435456
POWER_ACTION_LOCK_CONSOLE: UInt32 = 536870912
POWER_ACTION_DISABLE_WAKES: UInt32 = 1073741824
POWER_ACTION_CRITICAL: UInt32 = 2147483648
POWER_USER_NOTIFY_FORCED_SHUTDOWN: UInt32 = 32
BATTERY_DISCHARGE_FLAGS_EVENTCODE_MASK: UInt32 = 7
BATTERY_DISCHARGE_FLAGS_ENABLE: UInt32 = 2147483648
NUM_DISCHARGE_POLICIES: UInt32 = 4
DISCHARGE_POLICY_CRITICAL: UInt32 = 0
DISCHARGE_POLICY_LOW: UInt32 = 1
PROCESSOR_IDLESTATE_POLICY_COUNT: UInt32 = 3
PO_THROTTLE_NONE: UInt32 = 0
PO_THROTTLE_CONSTANT: UInt32 = 1
PO_THROTTLE_DEGRADE: UInt32 = 2
PO_THROTTLE_ADAPTIVE: UInt32 = 3
PO_THROTTLE_MAXIMUM: UInt32 = 4
HIBERFILE_TYPE_NONE: UInt32 = 0
HIBERFILE_TYPE_REDUCED: UInt32 = 1
HIBERFILE_TYPE_FULL: UInt32 = 2
HIBERFILE_TYPE_MAX: UInt32 = 3
IMAGE_DOS_SIGNATURE: UInt16 = 23117
IMAGE_OS2_SIGNATURE: UInt16 = 17742
IMAGE_OS2_SIGNATURE_LE: UInt16 = 17740
IMAGE_VXD_SIGNATURE: UInt16 = 17740
IMAGE_NT_SIGNATURE: UInt32 = 17744
IMAGE_SIZEOF_FILE_HEADER: UInt32 = 20
IMAGE_NUMBEROF_DIRECTORY_ENTRIES: UInt32 = 16
IMAGE_SIZEOF_SHORT_NAME: UInt32 = 8
IMAGE_SIZEOF_SECTION_HEADER: UInt32 = 40
IMAGE_SIZEOF_SYMBOL: UInt32 = 18
IMAGE_SYM_SECTION_MAX: UInt32 = 65279
IMAGE_SYM_SECTION_MAX_EX: UInt32 = 2147483647
IMAGE_SYM_TYPE_NULL: UInt32 = 0
IMAGE_SYM_TYPE_VOID: UInt32 = 1
IMAGE_SYM_TYPE_CHAR: UInt32 = 2
IMAGE_SYM_TYPE_SHORT: UInt32 = 3
IMAGE_SYM_TYPE_INT: UInt32 = 4
IMAGE_SYM_TYPE_LONG: UInt32 = 5
IMAGE_SYM_TYPE_FLOAT: UInt32 = 6
IMAGE_SYM_TYPE_DOUBLE: UInt32 = 7
IMAGE_SYM_TYPE_STRUCT: UInt32 = 8
IMAGE_SYM_TYPE_UNION: UInt32 = 9
IMAGE_SYM_TYPE_ENUM: UInt32 = 10
IMAGE_SYM_TYPE_MOE: UInt32 = 11
IMAGE_SYM_TYPE_BYTE: UInt32 = 12
IMAGE_SYM_TYPE_WORD: UInt32 = 13
IMAGE_SYM_TYPE_UINT: UInt32 = 14
IMAGE_SYM_TYPE_DWORD: UInt32 = 15
IMAGE_SYM_TYPE_PCODE: UInt32 = 32768
IMAGE_SYM_DTYPE_NULL: UInt32 = 0
IMAGE_SYM_DTYPE_POINTER: UInt32 = 1
IMAGE_SYM_DTYPE_FUNCTION: UInt32 = 2
IMAGE_SYM_DTYPE_ARRAY: UInt32 = 3
IMAGE_SYM_CLASS_NULL: UInt32 = 0
IMAGE_SYM_CLASS_AUTOMATIC: UInt32 = 1
IMAGE_SYM_CLASS_EXTERNAL: UInt32 = 2
IMAGE_SYM_CLASS_STATIC: UInt32 = 3
IMAGE_SYM_CLASS_REGISTER: UInt32 = 4
IMAGE_SYM_CLASS_EXTERNAL_DEF: UInt32 = 5
IMAGE_SYM_CLASS_LABEL: UInt32 = 6
IMAGE_SYM_CLASS_UNDEFINED_LABEL: UInt32 = 7
IMAGE_SYM_CLASS_MEMBER_OF_STRUCT: UInt32 = 8
IMAGE_SYM_CLASS_ARGUMENT: UInt32 = 9
IMAGE_SYM_CLASS_STRUCT_TAG: UInt32 = 10
IMAGE_SYM_CLASS_MEMBER_OF_UNION: UInt32 = 11
IMAGE_SYM_CLASS_UNION_TAG: UInt32 = 12
IMAGE_SYM_CLASS_TYPE_DEFINITION: UInt32 = 13
IMAGE_SYM_CLASS_UNDEFINED_STATIC: UInt32 = 14
IMAGE_SYM_CLASS_ENUM_TAG: UInt32 = 15
IMAGE_SYM_CLASS_MEMBER_OF_ENUM: UInt32 = 16
IMAGE_SYM_CLASS_REGISTER_PARAM: UInt32 = 17
IMAGE_SYM_CLASS_BIT_FIELD: UInt32 = 18
IMAGE_SYM_CLASS_FAR_EXTERNAL: UInt32 = 68
IMAGE_SYM_CLASS_BLOCK: UInt32 = 100
IMAGE_SYM_CLASS_FUNCTION: UInt32 = 101
IMAGE_SYM_CLASS_END_OF_STRUCT: UInt32 = 102
IMAGE_SYM_CLASS_FILE: UInt32 = 103
IMAGE_SYM_CLASS_SECTION: UInt32 = 104
IMAGE_SYM_CLASS_WEAK_EXTERNAL: UInt32 = 105
IMAGE_SYM_CLASS_CLR_TOKEN: UInt32 = 107
N_BTMASK: UInt32 = 15
N_TMASK: UInt32 = 48
N_TMASK1: UInt32 = 192
N_TMASK2: UInt32 = 240
N_BTSHFT: UInt32 = 4
N_TSHIFT: UInt32 = 2
IMAGE_COMDAT_SELECT_NODUPLICATES: UInt32 = 1
IMAGE_COMDAT_SELECT_ANY: UInt32 = 2
IMAGE_COMDAT_SELECT_SAME_SIZE: UInt32 = 3
IMAGE_COMDAT_SELECT_EXACT_MATCH: UInt32 = 4
IMAGE_COMDAT_SELECT_ASSOCIATIVE: UInt32 = 5
IMAGE_COMDAT_SELECT_LARGEST: UInt32 = 6
IMAGE_COMDAT_SELECT_NEWEST: UInt32 = 7
IMAGE_WEAK_EXTERN_SEARCH_NOLIBRARY: UInt32 = 1
IMAGE_WEAK_EXTERN_SEARCH_LIBRARY: UInt32 = 2
IMAGE_WEAK_EXTERN_SEARCH_ALIAS: UInt32 = 3
IMAGE_WEAK_EXTERN_ANTI_DEPENDENCY: UInt32 = 4
IMAGE_REL_I386_ABSOLUTE: UInt32 = 0
IMAGE_REL_I386_DIR16: UInt32 = 1
IMAGE_REL_I386_REL16: UInt32 = 2
IMAGE_REL_I386_DIR32: UInt32 = 6
IMAGE_REL_I386_DIR32NB: UInt32 = 7
IMAGE_REL_I386_SEG12: UInt32 = 9
IMAGE_REL_I386_SECTION: UInt32 = 10
IMAGE_REL_I386_SECREL: UInt32 = 11
IMAGE_REL_I386_TOKEN: UInt32 = 12
IMAGE_REL_I386_SECREL7: UInt32 = 13
IMAGE_REL_I386_REL32: UInt32 = 20
IMAGE_REL_MIPS_ABSOLUTE: UInt32 = 0
IMAGE_REL_MIPS_REFHALF: UInt32 = 1
IMAGE_REL_MIPS_REFWORD: UInt32 = 2
IMAGE_REL_MIPS_JMPADDR: UInt32 = 3
IMAGE_REL_MIPS_REFHI: UInt32 = 4
IMAGE_REL_MIPS_REFLO: UInt32 = 5
IMAGE_REL_MIPS_GPREL: UInt32 = 6
IMAGE_REL_MIPS_LITERAL: UInt32 = 7
IMAGE_REL_MIPS_SECTION: UInt32 = 10
IMAGE_REL_MIPS_SECREL: UInt32 = 11
IMAGE_REL_MIPS_SECRELLO: UInt32 = 12
IMAGE_REL_MIPS_SECRELHI: UInt32 = 13
IMAGE_REL_MIPS_TOKEN: UInt32 = 14
IMAGE_REL_MIPS_JMPADDR16: UInt32 = 16
IMAGE_REL_MIPS_REFWORDNB: UInt32 = 34
IMAGE_REL_MIPS_PAIR: UInt32 = 37
IMAGE_REL_ALPHA_ABSOLUTE: UInt32 = 0
IMAGE_REL_ALPHA_REFLONG: UInt32 = 1
IMAGE_REL_ALPHA_REFQUAD: UInt32 = 2
IMAGE_REL_ALPHA_GPREL32: UInt32 = 3
IMAGE_REL_ALPHA_LITERAL: UInt32 = 4
IMAGE_REL_ALPHA_LITUSE: UInt32 = 5
IMAGE_REL_ALPHA_GPDISP: UInt32 = 6
IMAGE_REL_ALPHA_BRADDR: UInt32 = 7
IMAGE_REL_ALPHA_HINT: UInt32 = 8
IMAGE_REL_ALPHA_INLINE_REFLONG: UInt32 = 9
IMAGE_REL_ALPHA_REFHI: UInt32 = 10
IMAGE_REL_ALPHA_REFLO: UInt32 = 11
IMAGE_REL_ALPHA_PAIR: UInt32 = 12
IMAGE_REL_ALPHA_MATCH: UInt32 = 13
IMAGE_REL_ALPHA_SECTION: UInt32 = 14
IMAGE_REL_ALPHA_SECREL: UInt32 = 15
IMAGE_REL_ALPHA_REFLONGNB: UInt32 = 16
IMAGE_REL_ALPHA_SECRELLO: UInt32 = 17
IMAGE_REL_ALPHA_SECRELHI: UInt32 = 18
IMAGE_REL_ALPHA_REFQ3: UInt32 = 19
IMAGE_REL_ALPHA_REFQ2: UInt32 = 20
IMAGE_REL_ALPHA_REFQ1: UInt32 = 21
IMAGE_REL_ALPHA_GPRELLO: UInt32 = 22
IMAGE_REL_ALPHA_GPRELHI: UInt32 = 23
IMAGE_REL_PPC_ABSOLUTE: UInt32 = 0
IMAGE_REL_PPC_ADDR64: UInt32 = 1
IMAGE_REL_PPC_ADDR32: UInt32 = 2
IMAGE_REL_PPC_ADDR24: UInt32 = 3
IMAGE_REL_PPC_ADDR16: UInt32 = 4
IMAGE_REL_PPC_ADDR14: UInt32 = 5
IMAGE_REL_PPC_REL24: UInt32 = 6
IMAGE_REL_PPC_REL14: UInt32 = 7
IMAGE_REL_PPC_TOCREL16: UInt32 = 8
IMAGE_REL_PPC_TOCREL14: UInt32 = 9
IMAGE_REL_PPC_ADDR32NB: UInt32 = 10
IMAGE_REL_PPC_SECREL: UInt32 = 11
IMAGE_REL_PPC_SECTION: UInt32 = 12
IMAGE_REL_PPC_IFGLUE: UInt32 = 13
IMAGE_REL_PPC_IMGLUE: UInt32 = 14
IMAGE_REL_PPC_SECREL16: UInt32 = 15
IMAGE_REL_PPC_REFHI: UInt32 = 16
IMAGE_REL_PPC_REFLO: UInt32 = 17
IMAGE_REL_PPC_PAIR: UInt32 = 18
IMAGE_REL_PPC_SECRELLO: UInt32 = 19
IMAGE_REL_PPC_SECRELHI: UInt32 = 20
IMAGE_REL_PPC_GPREL: UInt32 = 21
IMAGE_REL_PPC_TOKEN: UInt32 = 22
IMAGE_REL_PPC_TYPEMASK: UInt32 = 255
IMAGE_REL_PPC_NEG: UInt32 = 256
IMAGE_REL_PPC_BRTAKEN: UInt32 = 512
IMAGE_REL_PPC_BRNTAKEN: UInt32 = 1024
IMAGE_REL_PPC_TOCDEFN: UInt32 = 2048
IMAGE_REL_SH3_ABSOLUTE: UInt32 = 0
IMAGE_REL_SH3_DIRECT16: UInt32 = 1
IMAGE_REL_SH3_DIRECT32: UInt32 = 2
IMAGE_REL_SH3_DIRECT8: UInt32 = 3
IMAGE_REL_SH3_DIRECT8_WORD: UInt32 = 4
IMAGE_REL_SH3_DIRECT8_LONG: UInt32 = 5
IMAGE_REL_SH3_DIRECT4: UInt32 = 6
IMAGE_REL_SH3_DIRECT4_WORD: UInt32 = 7
IMAGE_REL_SH3_DIRECT4_LONG: UInt32 = 8
IMAGE_REL_SH3_PCREL8_WORD: UInt32 = 9
IMAGE_REL_SH3_PCREL8_LONG: UInt32 = 10
IMAGE_REL_SH3_PCREL12_WORD: UInt32 = 11
IMAGE_REL_SH3_STARTOF_SECTION: UInt32 = 12
IMAGE_REL_SH3_SIZEOF_SECTION: UInt32 = 13
IMAGE_REL_SH3_SECTION: UInt32 = 14
IMAGE_REL_SH3_SECREL: UInt32 = 15
IMAGE_REL_SH3_DIRECT32_NB: UInt32 = 16
IMAGE_REL_SH3_GPREL4_LONG: UInt32 = 17
IMAGE_REL_SH3_TOKEN: UInt32 = 18
IMAGE_REL_SHM_PCRELPT: UInt32 = 19
IMAGE_REL_SHM_REFLO: UInt32 = 20
IMAGE_REL_SHM_REFHALF: UInt32 = 21
IMAGE_REL_SHM_RELLO: UInt32 = 22
IMAGE_REL_SHM_RELHALF: UInt32 = 23
IMAGE_REL_SHM_PAIR: UInt32 = 24
IMAGE_REL_SH_NOMODE: UInt32 = 32768
IMAGE_REL_ARM_ABSOLUTE: UInt32 = 0
IMAGE_REL_ARM_ADDR32: UInt32 = 1
IMAGE_REL_ARM_ADDR32NB: UInt32 = 2
IMAGE_REL_ARM_BRANCH24: UInt32 = 3
IMAGE_REL_ARM_BRANCH11: UInt32 = 4
IMAGE_REL_ARM_TOKEN: UInt32 = 5
IMAGE_REL_ARM_GPREL12: UInt32 = 6
IMAGE_REL_ARM_GPREL7: UInt32 = 7
IMAGE_REL_ARM_BLX24: UInt32 = 8
IMAGE_REL_ARM_BLX11: UInt32 = 9
IMAGE_REL_ARM_SECTION: UInt32 = 14
IMAGE_REL_ARM_SECREL: UInt32 = 15
IMAGE_REL_ARM_MOV32A: UInt32 = 16
IMAGE_REL_ARM_MOV32: UInt32 = 16
IMAGE_REL_ARM_MOV32T: UInt32 = 17
IMAGE_REL_THUMB_MOV32: UInt32 = 17
IMAGE_REL_ARM_BRANCH20T: UInt32 = 18
IMAGE_REL_THUMB_BRANCH20: UInt32 = 18
IMAGE_REL_ARM_BRANCH24T: UInt32 = 20
IMAGE_REL_THUMB_BRANCH24: UInt32 = 20
IMAGE_REL_ARM_BLX23T: UInt32 = 21
IMAGE_REL_THUMB_BLX23: UInt32 = 21
IMAGE_REL_AM_ABSOLUTE: UInt32 = 0
IMAGE_REL_AM_ADDR32: UInt32 = 1
IMAGE_REL_AM_ADDR32NB: UInt32 = 2
IMAGE_REL_AM_CALL32: UInt32 = 3
IMAGE_REL_AM_FUNCINFO: UInt32 = 4
IMAGE_REL_AM_REL32_1: UInt32 = 5
IMAGE_REL_AM_REL32_2: UInt32 = 6
IMAGE_REL_AM_SECREL: UInt32 = 7
IMAGE_REL_AM_SECTION: UInt32 = 8
IMAGE_REL_AM_TOKEN: UInt32 = 9
IMAGE_REL_ARM64_ABSOLUTE: UInt32 = 0
IMAGE_REL_ARM64_ADDR32: UInt32 = 1
IMAGE_REL_ARM64_ADDR32NB: UInt32 = 2
IMAGE_REL_ARM64_BRANCH26: UInt32 = 3
IMAGE_REL_ARM64_PAGEBASE_REL21: UInt32 = 4
IMAGE_REL_ARM64_REL21: UInt32 = 5
IMAGE_REL_ARM64_PAGEOFFSET_12A: UInt32 = 6
IMAGE_REL_ARM64_PAGEOFFSET_12L: UInt32 = 7
IMAGE_REL_ARM64_SECREL: UInt32 = 8
IMAGE_REL_ARM64_SECREL_LOW12A: UInt32 = 9
IMAGE_REL_ARM64_SECREL_HIGH12A: UInt32 = 10
IMAGE_REL_ARM64_SECREL_LOW12L: UInt32 = 11
IMAGE_REL_ARM64_TOKEN: UInt32 = 12
IMAGE_REL_ARM64_SECTION: UInt32 = 13
IMAGE_REL_ARM64_ADDR64: UInt32 = 14
IMAGE_REL_ARM64_BRANCH19: UInt32 = 15
IMAGE_REL_AMD64_ABSOLUTE: UInt32 = 0
IMAGE_REL_AMD64_ADDR64: UInt32 = 1
IMAGE_REL_AMD64_ADDR32: UInt32 = 2
IMAGE_REL_AMD64_ADDR32NB: UInt32 = 3
IMAGE_REL_AMD64_REL32: UInt32 = 4
IMAGE_REL_AMD64_REL32_1: UInt32 = 5
IMAGE_REL_AMD64_REL32_2: UInt32 = 6
IMAGE_REL_AMD64_REL32_3: UInt32 = 7
IMAGE_REL_AMD64_REL32_4: UInt32 = 8
IMAGE_REL_AMD64_REL32_5: UInt32 = 9
IMAGE_REL_AMD64_SECTION: UInt32 = 10
IMAGE_REL_AMD64_SECREL: UInt32 = 11
IMAGE_REL_AMD64_SECREL7: UInt32 = 12
IMAGE_REL_AMD64_TOKEN: UInt32 = 13
IMAGE_REL_AMD64_SREL32: UInt32 = 14
IMAGE_REL_AMD64_PAIR: UInt32 = 15
IMAGE_REL_AMD64_SSPAN32: UInt32 = 16
IMAGE_REL_AMD64_EHANDLER: UInt32 = 17
IMAGE_REL_AMD64_IMPORT_BR: UInt32 = 18
IMAGE_REL_AMD64_IMPORT_CALL: UInt32 = 19
IMAGE_REL_AMD64_CFG_BR: UInt32 = 20
IMAGE_REL_AMD64_CFG_BR_REX: UInt32 = 21
IMAGE_REL_AMD64_CFG_CALL: UInt32 = 22
IMAGE_REL_AMD64_INDIR_BR: UInt32 = 23
IMAGE_REL_AMD64_INDIR_BR_REX: UInt32 = 24
IMAGE_REL_AMD64_INDIR_CALL: UInt32 = 25
IMAGE_REL_AMD64_INDIR_BR_SWITCHTABLE_FIRST: UInt32 = 32
IMAGE_REL_AMD64_INDIR_BR_SWITCHTABLE_LAST: UInt32 = 47
IMAGE_REL_IA64_ABSOLUTE: UInt32 = 0
IMAGE_REL_IA64_IMM14: UInt32 = 1
IMAGE_REL_IA64_IMM22: UInt32 = 2
IMAGE_REL_IA64_IMM64: UInt32 = 3
IMAGE_REL_IA64_DIR32: UInt32 = 4
IMAGE_REL_IA64_DIR64: UInt32 = 5
IMAGE_REL_IA64_PCREL21B: UInt32 = 6
IMAGE_REL_IA64_PCREL21M: UInt32 = 7
IMAGE_REL_IA64_PCREL21F: UInt32 = 8
IMAGE_REL_IA64_GPREL22: UInt32 = 9
IMAGE_REL_IA64_LTOFF22: UInt32 = 10
IMAGE_REL_IA64_SECTION: UInt32 = 11
IMAGE_REL_IA64_SECREL22: UInt32 = 12
IMAGE_REL_IA64_SECREL64I: UInt32 = 13
IMAGE_REL_IA64_SECREL32: UInt32 = 14
IMAGE_REL_IA64_DIR32NB: UInt32 = 16
IMAGE_REL_IA64_SREL14: UInt32 = 17
IMAGE_REL_IA64_SREL22: UInt32 = 18
IMAGE_REL_IA64_SREL32: UInt32 = 19
IMAGE_REL_IA64_UREL32: UInt32 = 20
IMAGE_REL_IA64_PCREL60X: UInt32 = 21
IMAGE_REL_IA64_PCREL60B: UInt32 = 22
IMAGE_REL_IA64_PCREL60F: UInt32 = 23
IMAGE_REL_IA64_PCREL60I: UInt32 = 24
IMAGE_REL_IA64_PCREL60M: UInt32 = 25
IMAGE_REL_IA64_IMMGPREL64: UInt32 = 26
IMAGE_REL_IA64_TOKEN: UInt32 = 27
IMAGE_REL_IA64_GPREL32: UInt32 = 28
IMAGE_REL_IA64_ADDEND: UInt32 = 31
IMAGE_REL_CEF_ABSOLUTE: UInt32 = 0
IMAGE_REL_CEF_ADDR32: UInt32 = 1
IMAGE_REL_CEF_ADDR64: UInt32 = 2
IMAGE_REL_CEF_ADDR32NB: UInt32 = 3
IMAGE_REL_CEF_SECTION: UInt32 = 4
IMAGE_REL_CEF_SECREL: UInt32 = 5
IMAGE_REL_CEF_TOKEN: UInt32 = 6
IMAGE_REL_CEE_ABSOLUTE: UInt32 = 0
IMAGE_REL_CEE_ADDR32: UInt32 = 1
IMAGE_REL_CEE_ADDR64: UInt32 = 2
IMAGE_REL_CEE_ADDR32NB: UInt32 = 3
IMAGE_REL_CEE_SECTION: UInt32 = 4
IMAGE_REL_CEE_SECREL: UInt32 = 5
IMAGE_REL_CEE_TOKEN: UInt32 = 6
IMAGE_REL_M32R_ABSOLUTE: UInt32 = 0
IMAGE_REL_M32R_ADDR32: UInt32 = 1
IMAGE_REL_M32R_ADDR32NB: UInt32 = 2
IMAGE_REL_M32R_ADDR24: UInt32 = 3
IMAGE_REL_M32R_GPREL16: UInt32 = 4
IMAGE_REL_M32R_PCREL24: UInt32 = 5
IMAGE_REL_M32R_PCREL16: UInt32 = 6
IMAGE_REL_M32R_PCREL8: UInt32 = 7
IMAGE_REL_M32R_REFHALF: UInt32 = 8
IMAGE_REL_M32R_REFHI: UInt32 = 9
IMAGE_REL_M32R_REFLO: UInt32 = 10
IMAGE_REL_M32R_PAIR: UInt32 = 11
IMAGE_REL_M32R_SECTION: UInt32 = 12
IMAGE_REL_M32R_SECREL32: UInt32 = 13
IMAGE_REL_M32R_TOKEN: UInt32 = 14
IMAGE_REL_EBC_ABSOLUTE: UInt32 = 0
IMAGE_REL_EBC_ADDR32NB: UInt32 = 1
IMAGE_REL_EBC_REL32: UInt32 = 2
IMAGE_REL_EBC_SECTION: UInt32 = 3
IMAGE_REL_EBC_SECREL: UInt32 = 4
EMARCH_ENC_I17_IMM7B_INST_WORD_X: UInt32 = 3
EMARCH_ENC_I17_IMM7B_SIZE_X: UInt32 = 7
EMARCH_ENC_I17_IMM7B_INST_WORD_POS_X: UInt32 = 4
EMARCH_ENC_I17_IMM7B_VAL_POS_X: UInt32 = 0
EMARCH_ENC_I17_IMM9D_INST_WORD_X: UInt32 = 3
EMARCH_ENC_I17_IMM9D_SIZE_X: UInt32 = 9
EMARCH_ENC_I17_IMM9D_INST_WORD_POS_X: UInt32 = 18
EMARCH_ENC_I17_IMM9D_VAL_POS_X: UInt32 = 7
EMARCH_ENC_I17_IMM5C_INST_WORD_X: UInt32 = 3
EMARCH_ENC_I17_IMM5C_SIZE_X: UInt32 = 5
EMARCH_ENC_I17_IMM5C_INST_WORD_POS_X: UInt32 = 13
EMARCH_ENC_I17_IMM5C_VAL_POS_X: UInt32 = 16
EMARCH_ENC_I17_IC_INST_WORD_X: UInt32 = 3
EMARCH_ENC_I17_IC_SIZE_X: UInt32 = 1
EMARCH_ENC_I17_IC_INST_WORD_POS_X: UInt32 = 12
EMARCH_ENC_I17_IC_VAL_POS_X: UInt32 = 21
EMARCH_ENC_I17_IMM41a_INST_WORD_X: UInt32 = 1
EMARCH_ENC_I17_IMM41a_SIZE_X: UInt32 = 10
EMARCH_ENC_I17_IMM41a_INST_WORD_POS_X: UInt32 = 14
EMARCH_ENC_I17_IMM41a_VAL_POS_X: UInt32 = 22
EMARCH_ENC_I17_IMM41b_INST_WORD_X: UInt32 = 1
EMARCH_ENC_I17_IMM41b_SIZE_X: UInt32 = 8
EMARCH_ENC_I17_IMM41b_INST_WORD_POS_X: UInt32 = 24
EMARCH_ENC_I17_IMM41b_VAL_POS_X: UInt32 = 32
EMARCH_ENC_I17_IMM41c_INST_WORD_X: UInt32 = 2
EMARCH_ENC_I17_IMM41c_SIZE_X: UInt32 = 23
EMARCH_ENC_I17_IMM41c_INST_WORD_POS_X: UInt32 = 0
EMARCH_ENC_I17_IMM41c_VAL_POS_X: UInt32 = 40
EMARCH_ENC_I17_SIGN_INST_WORD_X: UInt32 = 3
EMARCH_ENC_I17_SIGN_SIZE_X: UInt32 = 1
EMARCH_ENC_I17_SIGN_INST_WORD_POS_X: UInt32 = 27
EMARCH_ENC_I17_SIGN_VAL_POS_X: UInt32 = 63
X3_OPCODE_INST_WORD_X: UInt32 = 3
X3_OPCODE_SIZE_X: UInt32 = 4
X3_OPCODE_INST_WORD_POS_X: UInt32 = 28
X3_OPCODE_SIGN_VAL_POS_X: UInt32 = 0
X3_I_INST_WORD_X: UInt32 = 3
X3_I_SIZE_X: UInt32 = 1
X3_I_INST_WORD_POS_X: UInt32 = 27
X3_I_SIGN_VAL_POS_X: UInt32 = 59
X3_D_WH_INST_WORD_X: UInt32 = 3
X3_D_WH_SIZE_X: UInt32 = 3
X3_D_WH_INST_WORD_POS_X: UInt32 = 24
X3_D_WH_SIGN_VAL_POS_X: UInt32 = 0
X3_IMM20_INST_WORD_X: UInt32 = 3
X3_IMM20_SIZE_X: UInt32 = 20
X3_IMM20_INST_WORD_POS_X: UInt32 = 4
X3_IMM20_SIGN_VAL_POS_X: UInt32 = 0
X3_IMM39_1_INST_WORD_X: UInt32 = 2
X3_IMM39_1_SIZE_X: UInt32 = 23
X3_IMM39_1_INST_WORD_POS_X: UInt32 = 0
X3_IMM39_1_SIGN_VAL_POS_X: UInt32 = 36
X3_IMM39_2_INST_WORD_X: UInt32 = 1
X3_IMM39_2_SIZE_X: UInt32 = 16
X3_IMM39_2_INST_WORD_POS_X: UInt32 = 16
X3_IMM39_2_SIGN_VAL_POS_X: UInt32 = 20
X3_P_INST_WORD_X: UInt32 = 3
X3_P_SIZE_X: UInt32 = 4
X3_P_INST_WORD_POS_X: UInt32 = 0
X3_P_SIGN_VAL_POS_X: UInt32 = 0
X3_TMPLT_INST_WORD_X: UInt32 = 0
X3_TMPLT_SIZE_X: UInt32 = 4
X3_TMPLT_INST_WORD_POS_X: UInt32 = 0
X3_TMPLT_SIGN_VAL_POS_X: UInt32 = 0
X3_BTYPE_QP_INST_WORD_X: UInt32 = 2
X3_BTYPE_QP_SIZE_X: UInt32 = 9
X3_BTYPE_QP_INST_WORD_POS_X: UInt32 = 23
X3_BTYPE_QP_INST_VAL_POS_X: UInt32 = 0
X3_EMPTY_INST_WORD_X: UInt32 = 1
X3_EMPTY_SIZE_X: UInt32 = 2
X3_EMPTY_INST_WORD_POS_X: UInt32 = 14
X3_EMPTY_INST_VAL_POS_X: UInt32 = 0
IMAGE_REL_BASED_ABSOLUTE: UInt32 = 0
IMAGE_REL_BASED_HIGH: UInt32 = 1
IMAGE_REL_BASED_LOW: UInt32 = 2
IMAGE_REL_BASED_HIGHLOW: UInt32 = 3
IMAGE_REL_BASED_HIGHADJ: UInt32 = 4
IMAGE_REL_BASED_MACHINE_SPECIFIC_5: UInt32 = 5
IMAGE_REL_BASED_RESERVED: UInt32 = 6
IMAGE_REL_BASED_MACHINE_SPECIFIC_7: UInt32 = 7
IMAGE_REL_BASED_MACHINE_SPECIFIC_8: UInt32 = 8
IMAGE_REL_BASED_MACHINE_SPECIFIC_9: UInt32 = 9
IMAGE_REL_BASED_DIR64: UInt32 = 10
IMAGE_REL_BASED_IA64_IMM64: UInt32 = 9
IMAGE_REL_BASED_MIPS_JMPADDR: UInt32 = 5
IMAGE_REL_BASED_MIPS_JMPADDR16: UInt32 = 9
IMAGE_REL_BASED_ARM_MOV32: UInt32 = 5
IMAGE_REL_BASED_THUMB_MOV32: UInt32 = 7
IMAGE_ARCHIVE_START_SIZE: UInt32 = 8
IMAGE_ARCHIVE_START: String = '!<arch>\n'
IMAGE_ARCHIVE_END: String = '`\n'
IMAGE_ARCHIVE_PAD: String = '\n'
IMAGE_ARCHIVE_LINKER_MEMBER: String = '/               '
IMAGE_ARCHIVE_LONGNAMES_MEMBER: String = '//              '
IMAGE_ARCHIVE_HYBRIDMAP_MEMBER: String = '/<HYBRIDMAP>/   '
IMAGE_SIZEOF_ARCHIVE_MEMBER_HDR: UInt32 = 60
IMAGE_ORDINAL_FLAG64: UInt64 = 9223372036854775808
IMAGE_ORDINAL_FLAG32: UInt32 = 2147483648
IMAGE_RESOURCE_NAME_IS_STRING: UInt32 = 2147483648
IMAGE_RESOURCE_DATA_IS_DIRECTORY: UInt32 = 2147483648
IMAGE_DYNAMIC_RELOCATION_GUARD_RF_PROLOGUE: UInt32 = 1
IMAGE_DYNAMIC_RELOCATION_GUARD_RF_EPILOGUE: UInt32 = 2
IMAGE_DYNAMIC_RELOCATION_GUARD_IMPORT_CONTROL_TRANSFER: UInt32 = 3
IMAGE_DYNAMIC_RELOCATION_GUARD_INDIR_CONTROL_TRANSFER: UInt32 = 4
IMAGE_DYNAMIC_RELOCATION_GUARD_SWITCHTABLE_BRANCH: UInt32 = 5
IMAGE_DYNAMIC_RELOCATION_FUNCTION_OVERRIDE: UInt32 = 7
IMAGE_FUNCTION_OVERRIDE_INVALID: UInt32 = 0
IMAGE_FUNCTION_OVERRIDE_X64_REL32: UInt32 = 1
IMAGE_FUNCTION_OVERRIDE_ARM64_BRANCH26: UInt32 = 2
IMAGE_FUNCTION_OVERRIDE_ARM64_THUNK: UInt32 = 3
IMAGE_HOT_PATCH_BASE_OBLIGATORY: UInt32 = 1
IMAGE_HOT_PATCH_BASE_CAN_ROLL_BACK: UInt32 = 2
IMAGE_HOT_PATCH_CHUNK_INVERSE: UInt32 = 2147483648
IMAGE_HOT_PATCH_CHUNK_OBLIGATORY: UInt32 = 1073741824
IMAGE_HOT_PATCH_CHUNK_RESERVED: UInt32 = 1072705536
IMAGE_HOT_PATCH_CHUNK_TYPE: UInt32 = 1032192
IMAGE_HOT_PATCH_CHUNK_SOURCE_RVA: UInt32 = 32768
IMAGE_HOT_PATCH_CHUNK_TARGET_RVA: UInt32 = 16384
IMAGE_HOT_PATCH_CHUNK_SIZE: UInt32 = 4095
IMAGE_HOT_PATCH_NONE: UInt32 = 0
IMAGE_HOT_PATCH_FUNCTION: UInt32 = 114688
IMAGE_HOT_PATCH_ABSOLUTE: UInt32 = 180224
IMAGE_HOT_PATCH_REL32: UInt32 = 245760
IMAGE_HOT_PATCH_CALL_TARGET: UInt32 = 278528
IMAGE_HOT_PATCH_INDIRECT: UInt32 = 376832
IMAGE_HOT_PATCH_NO_CALL_TARGET: UInt32 = 409600
IMAGE_HOT_PATCH_DYNAMIC_VALUE: UInt32 = 491520
IMAGE_GUARD_CF_INSTRUMENTED: UInt32 = 256
IMAGE_GUARD_CFW_INSTRUMENTED: UInt32 = 512
IMAGE_GUARD_CF_FUNCTION_TABLE_PRESENT: UInt32 = 1024
IMAGE_GUARD_SECURITY_COOKIE_UNUSED: UInt32 = 2048
IMAGE_GUARD_PROTECT_DELAYLOAD_IAT: UInt32 = 4096
IMAGE_GUARD_DELAYLOAD_IAT_IN_ITS_OWN_SECTION: UInt32 = 8192
IMAGE_GUARD_CF_EXPORT_SUPPRESSION_INFO_PRESENT: UInt32 = 16384
IMAGE_GUARD_CF_ENABLE_EXPORT_SUPPRESSION: UInt32 = 32768
IMAGE_GUARD_CF_LONGJUMP_TABLE_PRESENT: UInt32 = 65536
IMAGE_GUARD_RF_INSTRUMENTED: UInt32 = 131072
IMAGE_GUARD_RF_ENABLE: UInt32 = 262144
IMAGE_GUARD_RF_STRICT: UInt32 = 524288
IMAGE_GUARD_RETPOLINE_PRESENT: UInt32 = 1048576
IMAGE_GUARD_EH_CONTINUATION_TABLE_PRESENT: UInt32 = 4194304
IMAGE_GUARD_XFG_ENABLED: UInt32 = 8388608
IMAGE_GUARD_CASTGUARD_PRESENT: UInt32 = 16777216
IMAGE_GUARD_MEMCPY_PRESENT: UInt32 = 33554432
IMAGE_GUARD_CF_FUNCTION_TABLE_SIZE_MASK: UInt32 = 4026531840
IMAGE_GUARD_CF_FUNCTION_TABLE_SIZE_SHIFT: UInt32 = 28
IMAGE_GUARD_FLAG_FID_SUPPRESSED: UInt32 = 1
IMAGE_GUARD_FLAG_EXPORT_SUPPRESSED: UInt32 = 2
IMAGE_GUARD_FLAG_FID_LANGEXCPTHANDLER: UInt32 = 4
IMAGE_GUARD_FLAG_FID_XFG: UInt32 = 8
IMAGE_ENCLAVE_LONG_ID_LENGTH: UInt32 = 32
IMAGE_ENCLAVE_SHORT_ID_LENGTH: UInt32 = 16
IMAGE_ENCLAVE_POLICY_DEBUGGABLE: UInt32 = 1
IMAGE_ENCLAVE_FLAG_PRIMARY_IMAGE: UInt32 = 1
IMAGE_ENCLAVE_IMPORT_MATCH_NONE: UInt32 = 0
IMAGE_ENCLAVE_IMPORT_MATCH_UNIQUE_ID: UInt32 = 1
IMAGE_ENCLAVE_IMPORT_MATCH_AUTHOR_ID: UInt32 = 2
IMAGE_ENCLAVE_IMPORT_MATCH_FAMILY_ID: UInt32 = 3
IMAGE_ENCLAVE_IMPORT_MATCH_IMAGE_ID: UInt32 = 4
IMAGE_DEBUG_TYPE_OMAP_TO_SRC: UInt32 = 7
IMAGE_DEBUG_TYPE_OMAP_FROM_SRC: UInt32 = 8
IMAGE_DEBUG_TYPE_RESERVED10: UInt32 = 10
IMAGE_DEBUG_TYPE_BBT: UInt32 = 10
IMAGE_DEBUG_TYPE_CLSID: UInt32 = 11
IMAGE_DEBUG_TYPE_VC_FEATURE: UInt32 = 12
IMAGE_DEBUG_TYPE_POGO: UInt32 = 13
IMAGE_DEBUG_TYPE_ILTCG: UInt32 = 14
IMAGE_DEBUG_TYPE_MPX: UInt32 = 15
IMAGE_DEBUG_TYPE_REPRO: UInt32 = 16
IMAGE_DEBUG_TYPE_SPGO: UInt32 = 18
IMAGE_DEBUG_TYPE_EX_DLLCHARACTERISTICS: UInt32 = 20
FRAME_FPO: UInt32 = 0
FRAME_TRAP: UInt32 = 1
FRAME_TSS: UInt32 = 2
FRAME_NONFPO: UInt32 = 3
SIZEOF_RFPO_DATA: UInt32 = 16
IMAGE_DEBUG_MISC_EXENAME: UInt32 = 1
IMAGE_SEPARATE_DEBUG_SIGNATURE: UInt32 = 18756
NON_PAGED_DEBUG_SIGNATURE: UInt32 = 18766
IMAGE_SEPARATE_DEBUG_FLAGS_MASK: UInt32 = 32768
IMAGE_SEPARATE_DEBUG_MISMATCH: UInt32 = 32768
IMPORT_OBJECT_HDR_SIG2: UInt32 = 65535
UNWIND_HISTORY_TABLE_SIZE: UInt32 = 12
FAST_FAIL_LEGACY_GS_VIOLATION: UInt32 = 0
FAST_FAIL_VTGUARD_CHECK_FAILURE: UInt32 = 1
FAST_FAIL_STACK_COOKIE_CHECK_FAILURE: UInt32 = 2
FAST_FAIL_CORRUPT_LIST_ENTRY: UInt32 = 3
FAST_FAIL_INCORRECT_STACK: UInt32 = 4
FAST_FAIL_INVALID_ARG: UInt32 = 5
FAST_FAIL_GS_COOKIE_INIT: UInt32 = 6
FAST_FAIL_FATAL_APP_EXIT: UInt32 = 7
FAST_FAIL_RANGE_CHECK_FAILURE: UInt32 = 8
FAST_FAIL_UNSAFE_REGISTRY_ACCESS: UInt32 = 9
FAST_FAIL_GUARD_ICALL_CHECK_FAILURE: UInt32 = 10
FAST_FAIL_GUARD_WRITE_CHECK_FAILURE: UInt32 = 11
FAST_FAIL_INVALID_FIBER_SWITCH: UInt32 = 12
FAST_FAIL_INVALID_SET_OF_CONTEXT: UInt32 = 13
FAST_FAIL_INVALID_REFERENCE_COUNT: UInt32 = 14
FAST_FAIL_INVALID_JUMP_BUFFER: UInt32 = 18
FAST_FAIL_MRDATA_MODIFIED: UInt32 = 19
FAST_FAIL_CERTIFICATION_FAILURE: UInt32 = 20
FAST_FAIL_INVALID_EXCEPTION_CHAIN: UInt32 = 21
FAST_FAIL_CRYPTO_LIBRARY: UInt32 = 22
FAST_FAIL_INVALID_CALL_IN_DLL_CALLOUT: UInt32 = 23
FAST_FAIL_INVALID_IMAGE_BASE: UInt32 = 24
FAST_FAIL_DLOAD_PROTECTION_FAILURE: UInt32 = 25
FAST_FAIL_UNSAFE_EXTENSION_CALL: UInt32 = 26
FAST_FAIL_DEPRECATED_SERVICE_INVOKED: UInt32 = 27
FAST_FAIL_INVALID_BUFFER_ACCESS: UInt32 = 28
FAST_FAIL_INVALID_BALANCED_TREE: UInt32 = 29
FAST_FAIL_INVALID_NEXT_THREAD: UInt32 = 30
FAST_FAIL_GUARD_ICALL_CHECK_SUPPRESSED: UInt32 = 31
FAST_FAIL_APCS_DISABLED: UInt32 = 32
FAST_FAIL_INVALID_IDLE_STATE: UInt32 = 33
FAST_FAIL_MRDATA_PROTECTION_FAILURE: UInt32 = 34
FAST_FAIL_UNEXPECTED_HEAP_EXCEPTION: UInt32 = 35
FAST_FAIL_INVALID_LOCK_STATE: UInt32 = 36
FAST_FAIL_GUARD_JUMPTABLE: UInt32 = 37
FAST_FAIL_INVALID_LONGJUMP_TARGET: UInt32 = 38
FAST_FAIL_INVALID_DISPATCH_CONTEXT: UInt32 = 39
FAST_FAIL_INVALID_THREAD: UInt32 = 40
FAST_FAIL_INVALID_SYSCALL_NUMBER: UInt32 = 41
FAST_FAIL_INVALID_FILE_OPERATION: UInt32 = 42
FAST_FAIL_LPAC_ACCESS_DENIED: UInt32 = 43
FAST_FAIL_GUARD_SS_FAILURE: UInt32 = 44
FAST_FAIL_LOADER_CONTINUITY_FAILURE: UInt32 = 45
FAST_FAIL_GUARD_EXPORT_SUPPRESSION_FAILURE: UInt32 = 46
FAST_FAIL_INVALID_CONTROL_STACK: UInt32 = 47
FAST_FAIL_SET_CONTEXT_DENIED: UInt32 = 48
FAST_FAIL_INVALID_IAT: UInt32 = 49
FAST_FAIL_HEAP_METADATA_CORRUPTION: UInt32 = 50
FAST_FAIL_PAYLOAD_RESTRICTION_VIOLATION: UInt32 = 51
FAST_FAIL_LOW_LABEL_ACCESS_DENIED: UInt32 = 52
FAST_FAIL_ENCLAVE_CALL_FAILURE: UInt32 = 53
FAST_FAIL_UNHANDLED_LSS_EXCEPTON: UInt32 = 54
FAST_FAIL_ADMINLESS_ACCESS_DENIED: UInt32 = 55
FAST_FAIL_UNEXPECTED_CALL: UInt32 = 56
FAST_FAIL_CONTROL_INVALID_RETURN_ADDRESS: UInt32 = 57
FAST_FAIL_UNEXPECTED_HOST_BEHAVIOR: UInt32 = 58
FAST_FAIL_FLAGS_CORRUPTION: UInt32 = 59
FAST_FAIL_VEH_CORRUPTION: UInt32 = 60
FAST_FAIL_ETW_CORRUPTION: UInt32 = 61
FAST_FAIL_RIO_ABORT: UInt32 = 62
FAST_FAIL_INVALID_PFN: UInt32 = 63
FAST_FAIL_GUARD_ICALL_CHECK_FAILURE_XFG: UInt32 = 64
FAST_FAIL_CAST_GUARD: UInt32 = 65
FAST_FAIL_HOST_VISIBILITY_CHANGE: UInt32 = 66
FAST_FAIL_KERNEL_CET_SHADOW_STACK_ASSIST: UInt32 = 67
FAST_FAIL_PATCH_CALLBACK_FAILED: UInt32 = 68
FAST_FAIL_NTDLL_PATCH_FAILED: UInt32 = 69
FAST_FAIL_INVALID_FLS_DATA: UInt32 = 70
FAST_FAIL_INVALID_FAST_FAIL_CODE: UInt32 = 4294967295
IS_TEXT_UNICODE_DBCS_LEADBYTE: UInt32 = 1024
IS_TEXT_UNICODE_UTF8: UInt32 = 2048
COMPRESSION_ENGINE_STANDARD: UInt32 = 0
COMPRESSION_ENGINE_MAXIMUM: UInt32 = 256
COMPRESSION_ENGINE_HIBER: UInt32 = 512
SEF_AI_USE_EXTRA_PARAMS: UInt32 = 2048
SEF_FORCE_USER_MODE: UInt32 = 8192
SEF_NORMALIZE_OUTPUT_DESCRIPTOR: UInt32 = 16384
MESSAGE_RESOURCE_UNICODE: UInt32 = 1
MESSAGE_RESOURCE_UTF8: UInt32 = 2
VER_EQUAL: UInt32 = 1
VER_GREATER: UInt32 = 2
VER_GREATER_EQUAL: UInt32 = 3
VER_LESS: UInt32 = 4
VER_LESS_EQUAL: UInt32 = 5
VER_AND: UInt32 = 6
VER_OR: UInt32 = 7
VER_CONDITION_MASK: UInt32 = 7
VER_NUM_BITS_PER_CONDITION_MASK: UInt32 = 3
VER_NT_WORKSTATION: UInt32 = 1
VER_NT_DOMAIN_CONTROLLER: UInt32 = 2
VER_NT_SERVER: UInt32 = 3
RTL_UMS_VERSION: UInt32 = 256
VRL_PREDEFINED_CLASS_BEGIN: UInt32 = 1
VRL_CUSTOM_CLASS_BEGIN: UInt32 = 256
VRL_ENABLE_KERNEL_BREAKS: UInt32 = 2147483648
CTMF_INCLUDE_APPCONTAINER: UInt32 = 1
CTMF_INCLUDE_LPAC: UInt32 = 2
FLUSH_NV_MEMORY_IN_FLAG_NO_DRAIN: UInt32 = 1
WRITE_NV_MEMORY_FLAG_FLUSH: UInt32 = 1
WRITE_NV_MEMORY_FLAG_NON_TEMPORAL: UInt32 = 2
WRITE_NV_MEMORY_FLAG_NO_DRAIN: UInt32 = 256
FILL_NV_MEMORY_FLAG_FLUSH: UInt32 = 1
FILL_NV_MEMORY_FLAG_NON_TEMPORAL: UInt32 = 2
FILL_NV_MEMORY_FLAG_NO_DRAIN: UInt32 = 256
IMAGE_POLICY_METADATA_VERSION: UInt32 = 1
IMAGE_POLICY_SECTION_NAME: String = '.tPolicy'
RTL_VIRTUAL_UNWIND2_VALIDATE_PAC: UInt32 = 1
HEAP_OPTIMIZE_RESOURCES_CURRENT_VERSION: UInt32 = 1
WT_EXECUTEINUITHREAD: UInt32 = 2
WT_EXECUTEINPERSISTENTIOTHREAD: UInt32 = 64
WT_EXECUTEINLONGTHREAD: UInt32 = 16
WT_EXECUTEDELETEWAIT: UInt32 = 8
ACTIVATION_CONTEXT_PATH_TYPE_NONE: UInt32 = 1
ACTIVATION_CONTEXT_PATH_TYPE_WIN32_FILE: UInt32 = 2
ACTIVATION_CONTEXT_PATH_TYPE_URL: UInt32 = 3
ACTIVATION_CONTEXT_PATH_TYPE_ASSEMBLYREF: UInt32 = 4
CREATE_BOUNDARY_DESCRIPTOR_ADD_APPCONTAINER_SID: UInt32 = 1
PERFORMANCE_DATA_VERSION: UInt32 = 1
READ_THREAD_PROFILING_FLAG_DISPATCHING: UInt32 = 1
READ_THREAD_PROFILING_FLAG_HARDWARE_COUNTERS: UInt32 = 2
UNIFIEDBUILDREVISION_KEY: String = '\\Registry\\Machine\\Software\\Microsoft\\Windows NT\\CurrentVersion'
UNIFIEDBUILDREVISION_VALUE: String = 'UBR'
UNIFIEDBUILDREVISION_MIN: UInt32 = 0
DEVICEFAMILYDEVICEFORM_KEY: String = '\\Registry\\Machine\\Software\\Microsoft\\Windows NT\\CurrentVersion\\OEM'
DEVICEFAMILYDEVICEFORM_VALUE: String = 'DeviceForm'
DLL_PROCESS_ATTACH: UInt32 = 1
DLL_THREAD_ATTACH: UInt32 = 2
DLL_THREAD_DETACH: UInt32 = 3
DLL_PROCESS_DETACH: UInt32 = 0
EVENTLOG_FORWARDS_READ: UInt32 = 4
EVENTLOG_BACKWARDS_READ: UInt32 = 8
EVENTLOG_START_PAIRED_EVENT: UInt32 = 1
EVENTLOG_END_PAIRED_EVENT: UInt32 = 2
EVENTLOG_END_ALL_PAIRED_EVENTS: UInt32 = 4
EVENTLOG_PAIRED_EVENT_ACTIVE: UInt32 = 8
EVENTLOG_PAIRED_EVENT_INACTIVE: UInt32 = 16
MAXLOGICALLOGNAMESIZE: UInt32 = 256
REG_REFRESH_HIVE: Int32 = 2
REG_NO_LAZY_FLUSH: Int32 = 4
REG_APP_HIVE: Int32 = 16
REG_PROCESS_PRIVATE: Int32 = 32
REG_START_JOURNAL: Int32 = 64
REG_HIVE_EXACT_FILE_GROWTH: Int32 = 128
REG_HIVE_NO_RM: Int32 = 256
REG_HIVE_SINGLE_LOG: Int32 = 512
REG_BOOT_HIVE: Int32 = 1024
REG_LOAD_HIVE_OPEN_HANDLE: Int32 = 2048
REG_FLUSH_HIVE_FILE_GROWTH: Int32 = 4096
REG_OPEN_READ_ONLY: Int32 = 8192
REG_IMMUTABLE: Int32 = 16384
REG_NO_IMPERSONATION_FALLBACK: Int32 = 32768
REG_APP_HIVE_OPEN_READ_ONLY: Int32 = 8192
REG_FORCE_UNLOAD: UInt32 = 1
REG_UNLOAD_LEGAL_FLAGS: UInt32 = 1
SERVICE_USER_SERVICE: UInt32 = 64
SERVICE_USERSERVICE_INSTANCE: UInt32 = 128
SERVICE_INTERACTIVE_PROCESS: UInt32 = 256
SERVICE_PKG_SERVICE: UInt32 = 512
CM_SERVICE_NETWORK_BOOT_LOAD: UInt32 = 1
CM_SERVICE_VIRTUAL_DISK_BOOT_LOAD: UInt32 = 2
CM_SERVICE_USB_DISK_BOOT_LOAD: UInt32 = 4
CM_SERVICE_SD_DISK_BOOT_LOAD: UInt32 = 8
CM_SERVICE_USB3_DISK_BOOT_LOAD: UInt32 = 16
CM_SERVICE_MEASURED_BOOT_LOAD: UInt32 = 32
CM_SERVICE_VERIFIER_BOOT_LOAD: UInt32 = 64
CM_SERVICE_WINPE_BOOT_LOAD: UInt32 = 128
CM_SERVICE_RAM_DISK_BOOT_LOAD: UInt32 = 256
TAPE_PSEUDO_LOGICAL_POSITION: Int32 = 2
TAPE_PSEUDO_LOGICAL_BLOCK: Int32 = 3
TAPE_DRIVE_FIXED: UInt32 = 1
TAPE_DRIVE_SELECT: UInt32 = 2
TAPE_DRIVE_INITIATOR: UInt32 = 4
TAPE_DRIVE_ERASE_SHORT: UInt32 = 16
TAPE_DRIVE_ERASE_LONG: UInt32 = 32
TAPE_DRIVE_ERASE_BOP_ONLY: UInt32 = 64
TAPE_DRIVE_ERASE_IMMEDIATE: UInt32 = 128
TAPE_DRIVE_TAPE_CAPACITY: UInt32 = 256
TAPE_DRIVE_TAPE_REMAINING: UInt32 = 512
TAPE_DRIVE_FIXED_BLOCK: UInt32 = 1024
TAPE_DRIVE_VARIABLE_BLOCK: UInt32 = 2048
TAPE_DRIVE_WRITE_PROTECT: UInt32 = 4096
TAPE_DRIVE_EOT_WZ_SIZE: UInt32 = 8192
TAPE_DRIVE_ECC: UInt32 = 65536
TAPE_DRIVE_COMPRESSION: UInt32 = 131072
TAPE_DRIVE_PADDING: UInt32 = 262144
TAPE_DRIVE_REPORT_SMKS: UInt32 = 524288
TAPE_DRIVE_GET_ABSOLUTE_BLK: UInt32 = 1048576
TAPE_DRIVE_GET_LOGICAL_BLK: UInt32 = 2097152
TAPE_DRIVE_SET_EOT_WZ_SIZE: UInt32 = 4194304
TAPE_DRIVE_EJECT_MEDIA: UInt32 = 16777216
TAPE_DRIVE_CLEAN_REQUESTS: UInt32 = 33554432
TAPE_DRIVE_SET_CMP_BOP_ONLY: UInt32 = 67108864
TAPE_DRIVE_RESERVED_BIT: UInt32 = 2147483648
TAPE_DRIVE_FORMAT: UInt32 = 2684354560
TAPE_DRIVE_FORMAT_IMMEDIATE: UInt32 = 3221225472
TAPE_DRIVE_HIGH_FEATURES: UInt32 = 2147483648
TAPE_QUERY_DRIVE_PARAMETERS: Int32 = 0
TAPE_QUERY_MEDIA_CAPACITY: Int32 = 1
TAPE_CHECK_FOR_DRIVE_PROBLEM: Int32 = 2
TAPE_QUERY_IO_ERROR_DATA: Int32 = 3
TAPE_QUERY_DEVICE_ERROR_DATA: Int32 = 4
TRANSACTIONMANAGER_QUERY_INFORMATION: UInt32 = 1
TRANSACTIONMANAGER_SET_INFORMATION: UInt32 = 2
TRANSACTIONMANAGER_RECOVER: UInt32 = 4
TRANSACTIONMANAGER_RENAME: UInt32 = 8
TRANSACTIONMANAGER_CREATE_RM: UInt32 = 16
TRANSACTIONMANAGER_BIND_TRANSACTION: UInt32 = 32
TRANSACTION_QUERY_INFORMATION: UInt32 = 1
TRANSACTION_SET_INFORMATION: UInt32 = 2
TRANSACTION_ENLIST: UInt32 = 4
TRANSACTION_COMMIT: UInt32 = 8
TRANSACTION_ROLLBACK: UInt32 = 16
TRANSACTION_PROPAGATE: UInt32 = 32
TRANSACTION_RIGHT_RESERVED1: UInt32 = 64
RESOURCEMANAGER_QUERY_INFORMATION: UInt32 = 1
RESOURCEMANAGER_SET_INFORMATION: UInt32 = 2
RESOURCEMANAGER_RECOVER: UInt32 = 4
RESOURCEMANAGER_ENLIST: UInt32 = 8
RESOURCEMANAGER_GET_NOTIFICATION: UInt32 = 16
RESOURCEMANAGER_REGISTER_PROTOCOL: UInt32 = 32
RESOURCEMANAGER_COMPLETE_PROPAGATION: UInt32 = 64
ENLISTMENT_QUERY_INFORMATION: UInt32 = 1
ENLISTMENT_SET_INFORMATION: UInt32 = 2
ENLISTMENT_RECOVER: UInt32 = 4
ENLISTMENT_SUBORDINATE_RIGHTS: UInt32 = 8
ENLISTMENT_SUPERIOR_RIGHTS: UInt32 = 16
PcTeb: UInt32 = 24
ACTIVATION_CONTEXT_SECTION_ASSEMBLY_INFORMATION: UInt32 = 1
ACTIVATION_CONTEXT_SECTION_DLL_REDIRECTION: UInt32 = 2
ACTIVATION_CONTEXT_SECTION_WINDOW_CLASS_REDIRECTION: UInt32 = 3
ACTIVATION_CONTEXT_SECTION_COM_SERVER_REDIRECTION: UInt32 = 4
ACTIVATION_CONTEXT_SECTION_COM_INTERFACE_REDIRECTION: UInt32 = 5
ACTIVATION_CONTEXT_SECTION_COM_TYPE_LIBRARY_REDIRECTION: UInt32 = 6
ACTIVATION_CONTEXT_SECTION_COM_PROGID_REDIRECTION: UInt32 = 7
ACTIVATION_CONTEXT_SECTION_GLOBAL_OBJECT_RENAME_TABLE: UInt32 = 8
ACTIVATION_CONTEXT_SECTION_CLR_SURROGATES: UInt32 = 9
ACTIVATION_CONTEXT_SECTION_APPLICATION_SETTINGS: UInt32 = 10
ACTIVATION_CONTEXT_SECTION_COMPATIBILITY_INFO: UInt32 = 11
ACTIVATION_CONTEXT_SECTION_WINRT_ACTIVATABLE_CLASSES: UInt32 = 12
ROT_COMPARE_MAX: UInt32 = 2048
WDT_INPROC_CALL: UInt32 = 1215587415
WDT_REMOTE_CALL: UInt32 = 1383359575
WDT_INPROC64_CALL: UInt32 = 1349805143
DECIMAL_NEG: Byte = 128
PROCESS_HEAP_REGION: UInt32 = 1
PROCESS_HEAP_UNCOMMITTED_RANGE: UInt32 = 2
PROCESS_HEAP_ENTRY_BUSY: UInt32 = 4
PROCESS_HEAP_SEG_ALLOC: UInt32 = 8
PROCESS_HEAP_ENTRY_MOVEABLE: UInt32 = 16
PROCESS_HEAP_ENTRY_DDESHARE: UInt32 = 32
LMEM_NOCOMPACT: UInt32 = 16
LMEM_NODISCARD: UInt32 = 32
LMEM_MODIFY: UInt32 = 128
LMEM_DISCARDABLE: UInt32 = 3840
LMEM_VALID_FLAGS: UInt32 = 3954
LMEM_INVALID_HANDLE: UInt32 = 32768
LMEM_DISCARDED: UInt32 = 16384
LMEM_LOCKCOUNT: UInt32 = 255
NUMA_NO_PREFERRED_NODE: UInt32 = 4294967295
REDBOOK_DIGITAL_AUDIO_EXTRACTION_INFO_VERSION: UInt32 = 1
CFE_UNDERLINE = UInt32
CFU_CF1UNDERLINE: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 255
CFU_INVERT: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 254
CFU_UNDERLINETHICKLONGDASH: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 18
CFU_UNDERLINETHICKDOTTED: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 17
CFU_UNDERLINETHICKDASHDOTDOT: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 16
CFU_UNDERLINETHICKDASHDOT: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 15
CFU_UNDERLINETHICKDASH: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 14
CFU_UNDERLINELONGDASH: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 13
CFU_UNDERLINEHEAVYWAVE: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 12
CFU_UNDERLINEDOUBLEWAVE: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 11
CFU_UNDERLINEHAIRLINE: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 10
CFU_UNDERLINETHICK: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 9
CFU_UNDERLINEWAVE: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 8
CFU_UNDERLINEDASHDOTDOT: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 7
CFU_UNDERLINEDASHDOT: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 6
CFU_UNDERLINEDASH: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 5
CFU_UNDERLINEDOTTED: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 4
CFU_UNDERLINEDOUBLE: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 3
CFU_UNDERLINEWORD: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 2
CFU_UNDERLINE: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 1
CFU_UNDERLINENONE: win32more.Windows.Win32.System.SystemServices.CFE_UNDERLINE = 0
class COMPONENT_FILTER(Structure):
    ComponentFlags: UInt32
class DISPATCHER_CONTEXT_NONVOLREG_ARM64(Union):
    Buffer: Byte * 152
    Anonymous: _Anonymous_e__Struct
    class _Anonymous_e__Struct(Structure):
        GpNvRegs: UInt64 * 11
        FpNvRegs: Double * 8
class ENLISTMENT_BASIC_INFORMATION(Structure):
    EnlistmentId: Guid
    TransactionId: Guid
    ResourceManagerId: Guid
class ENLISTMENT_CRM_INFORMATION(Structure):
    CrmTransactionManagerId: Guid
    CrmResourceManagerId: Guid
    CrmEnlistmentId: Guid
ENLISTMENT_INFORMATION_CLASS = Int32
EnlistmentBasicInformation: win32more.Windows.Win32.System.SystemServices.ENLISTMENT_INFORMATION_CLASS = 0
EnlistmentRecoveryInformation: win32more.Windows.Win32.System.SystemServices.ENLISTMENT_INFORMATION_CLASS = 1
EnlistmentCrmInformation: win32more.Windows.Win32.System.SystemServices.ENLISTMENT_INFORMATION_CLASS = 2
class FILE_NOTIFY_FULL_INFORMATION(Structure):
    NextEntryOffset: UInt32
    Action: UInt32
    CreationTime: Int64
    LastModificationTime: Int64
    LastChangeTime: Int64
    LastAccessTime: Int64
    AllocatedLength: Int64
    FileSize: Int64
    FileAttributes: UInt32
    Anonymous: _Anonymous_e__Union
    FileId: Int64
    ParentFileId: Int64
    FileNameLength: UInt16
    FileNameFlags: Byte
    Reserved: Byte
    FileName: Char * 1
    class _Anonymous_e__Union(Union):
        ReparsePointTag: UInt32
        EaSize: UInt32
class GDI_NONREMOTE(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        hInproc: Int32
        hRemote: POINTER(win32more.Windows.Win32.System.Com.DWORD_BLOB)
GESTURECONFIG_FLAGS = UInt32
GC_ALLGESTURES: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 1
GC_ZOOM: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 1
GC_PAN: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 1
GC_PAN_WITH_SINGLE_FINGER_VERTICALLY: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 2
GC_PAN_WITH_SINGLE_FINGER_HORIZONTALLY: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 4
GC_PAN_WITH_GUTTER: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 8
GC_PAN_WITH_INERTIA: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 16
GC_ROTATE: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 1
GC_TWOFINGERTAP: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 1
GC_PRESSANDTAP: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 1
GC_ROLLOVER: win32more.Windows.Win32.System.SystemServices.GESTURECONFIG_FLAGS = 1
class HEAP_OPTIMIZE_RESOURCES_INFORMATION(Structure):
    Version: UInt32
    Flags: UInt32
class HIBERFILE_BUCKET(Structure):
    MaxPhysicalMemory: UInt64
    PhysicalMemoryPercent: UInt32 * 3
HIBERFILE_BUCKET_SIZE = Int32
HiberFileBucket1GB: win32more.Windows.Win32.System.SystemServices.HIBERFILE_BUCKET_SIZE = 0
HiberFileBucket2GB: win32more.Windows.Win32.System.SystemServices.HIBERFILE_BUCKET_SIZE = 1
HiberFileBucket4GB: win32more.Windows.Win32.System.SystemServices.HIBERFILE_BUCKET_SIZE = 2
HiberFileBucket8GB: win32more.Windows.Win32.System.SystemServices.HIBERFILE_BUCKET_SIZE = 3
HiberFileBucket16GB: win32more.Windows.Win32.System.SystemServices.HIBERFILE_BUCKET_SIZE = 4
HiberFileBucket32GB: win32more.Windows.Win32.System.SystemServices.HIBERFILE_BUCKET_SIZE = 5
HiberFileBucketUnlimited: win32more.Windows.Win32.System.SystemServices.HIBERFILE_BUCKET_SIZE = 6
HiberFileBucketMax: win32more.Windows.Win32.System.SystemServices.HIBERFILE_BUCKET_SIZE = 7
IGP_ID = UInt32
IGP_GETIMEVERSION: win32more.Windows.Win32.System.SystemServices.IGP_ID = 4294967292
IGP_PROPERTY: win32more.Windows.Win32.System.SystemServices.IGP_ID = 4
IGP_CONVERSION: win32more.Windows.Win32.System.SystemServices.IGP_ID = 8
IGP_SENTENCE: win32more.Windows.Win32.System.SystemServices.IGP_ID = 12
IGP_UI: win32more.Windows.Win32.System.SystemServices.IGP_ID = 16
IGP_SETCOMPSTR: win32more.Windows.Win32.System.SystemServices.IGP_ID = 20
IGP_SELECT: win32more.Windows.Win32.System.SystemServices.IGP_ID = 24
class IMAGE_ALPHA64_RUNTIME_FUNCTION_ENTRY(Structure):
    BeginAddress: UInt64
    EndAddress: UInt64
    ExceptionHandler: UInt64
    HandlerData: UInt64
    PrologEndAddress: UInt64
    _pack_ = 4
class IMAGE_ALPHA_RUNTIME_FUNCTION_ENTRY(Structure):
    BeginAddress: UInt32
    EndAddress: UInt32
    ExceptionHandler: UInt32
    HandlerData: UInt32
    PrologEndAddress: UInt32
class IMAGE_ARCHITECTURE_ENTRY(Structure):
    FixupInstRVA: UInt32
    NewInst: UInt32
class IMAGE_ARCHITECTURE_HEADER(Structure):
    AmaskValue: Annotated[UInt32, 1]
    Anonymous1: Annotated[UInt32, 7]
    AmaskShift: Annotated[UInt32, 8]
    Anonymous2: Annotated[UInt32, 16]
    FirstEntryRVA: UInt32
class IMAGE_ARCHIVE_MEMBER_HEADER(Structure):
    Name: Byte * 16
    Date: Byte * 12
    UserID: Byte * 6
    GroupID: Byte * 6
    Mode: Byte * 8
    Size: Byte * 10
    EndHeader: Byte * 2
class IMAGE_ARM64_RUNTIME_FUNCTION_ENTRY_XDATA(Union):
    HeaderData: UInt32
    Anonymous: _Anonymous_e__Struct
    class _Anonymous_e__Struct(Structure):
        FunctionLength: Annotated[UInt32, 18]
        Version: Annotated[UInt32, 2]
        ExceptionDataPresent: Annotated[UInt32, 1]
        EpilogInHeader: Annotated[UInt32, 1]
        EpilogCount: Annotated[UInt32, 5]
        CodeWords: Annotated[UInt32, 5]
class IMAGE_ARM_RUNTIME_FUNCTION_ENTRY(Structure):
    BeginAddress: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        UnwindData: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            Flag: Annotated[UInt32, 2]
            FunctionLength: Annotated[UInt32, 11]
            Ret: Annotated[UInt32, 2]
            H: Annotated[UInt32, 1]
            Reg: Annotated[UInt32, 3]
            R: Annotated[UInt32, 1]
            L: Annotated[UInt32, 1]
            C: Annotated[UInt32, 1]
            StackAdjust: Annotated[UInt32, 10]
class IMAGE_AUX_SYMBOL(Union):
    Sym: _Sym_e__Struct
    File: _File_e__Struct
    Section: _Section_e__Struct
    TokenDef: win32more.Windows.Win32.System.SystemServices.IMAGE_AUX_SYMBOL_TOKEN_DEF
    CRC: _CRC_e__Struct
    class _Sym_e__Struct(Structure):
        TagIndex: UInt32
        Misc: _Misc_e__Union
        FcnAry: _FcnAry_e__Union
        TvIndex: UInt16
        _pack_ = 2
        class _Misc_e__Union(Union):
            LnSz: _LnSz_e__Struct
            TotalSize: UInt32
            _pack_ = 2
            class _LnSz_e__Struct(Structure):
                Linenumber: UInt16
                Size: UInt16
        class _FcnAry_e__Union(Union):
            Function: _Function_e__Struct
            Array: _Array_e__Struct
            class _Function_e__Struct(Structure):
                PointerToLinenumber: UInt32
                PointerToNextFunction: UInt32
                _pack_ = 2
            class _Array_e__Struct(Structure):
                Dimension: UInt16 * 4
    class _File_e__Struct(Structure):
        Name: Byte * 18
    class _Section_e__Struct(Structure):
        Length: UInt32
        NumberOfRelocations: UInt16
        NumberOfLinenumbers: UInt16
        CheckSum: UInt32
        Number: Int16
        Selection: Byte
        bReserved: Byte
        HighNumber: Int16
        _pack_ = 2
    class _CRC_e__Struct(Structure):
        crc: UInt32
        rgbReserved: Byte * 14
        _pack_ = 2
class IMAGE_AUX_SYMBOL_EX(Union):
    Sym: _Sym_e__Struct
    File: _File_e__Struct
    Section: _Section_e__Struct
    Anonymous: _Anonymous_e__Struct
    CRC: _CRC_e__Struct
    class _Sym_e__Struct(Structure):
        WeakDefaultSymIndex: UInt32
        WeakSearchType: UInt32
        rgbReserved: Byte * 12
        _pack_ = 2
    class _File_e__Struct(Structure):
        Name: Byte * 20
    class _Section_e__Struct(Structure):
        Length: UInt32
        NumberOfRelocations: UInt16
        NumberOfLinenumbers: UInt16
        CheckSum: UInt32
        Number: Int16
        Selection: Byte
        bReserved: Byte
        HighNumber: Int16
        rgbReserved: Byte * 2
        _pack_ = 2
    class _Anonymous_e__Struct(Structure):
        TokenDef: win32more.Windows.Win32.System.SystemServices.IMAGE_AUX_SYMBOL_TOKEN_DEF
        rgbReserved: Byte * 2
    class _CRC_e__Struct(Structure):
        crc: UInt32
        rgbReserved: Byte * 16
        _pack_ = 2
class IMAGE_AUX_SYMBOL_TOKEN_DEF(Structure):
    bAuxType: Byte
    bReserved: Byte
    SymbolTableIndex: UInt32
    rgbReserved: Byte * 12
    _pack_ = 2
IMAGE_AUX_SYMBOL_TYPE = Int32
IMAGE_AUX_SYMBOL_TYPE_TOKEN_DEF: win32more.Windows.Win32.System.SystemServices.IMAGE_AUX_SYMBOL_TYPE = 1
class IMAGE_BASE_RELOCATION(Structure):
    VirtualAddress: UInt32
    SizeOfBlock: UInt32
class IMAGE_BDD_DYNAMIC_RELOCATION(Structure):
    Left: UInt16
    Right: UInt16
    Value: UInt32
    _pack_ = 1
class IMAGE_BDD_INFO(Structure):
    Version: UInt32
    BDDSize: UInt32
    _pack_ = 1
class IMAGE_BOUND_FORWARDER_REF(Structure):
    TimeDateStamp: UInt32
    OffsetModuleName: UInt16
    Reserved: UInt16
class IMAGE_BOUND_IMPORT_DESCRIPTOR(Structure):
    TimeDateStamp: UInt32
    OffsetModuleName: UInt16
    NumberOfModuleForwarderRefs: UInt16
class IMAGE_CE_RUNTIME_FUNCTION_ENTRY(Structure):
    FuncStart: UInt32
    PrologLen: Annotated[UInt32, 8]
    FuncLen: Annotated[UInt32, 22]
    ThirtyTwoBit: Annotated[UInt32, 1]
    ExceptionFlag: Annotated[UInt32, 1]
class IMAGE_DEBUG_MISC(Structure):
    DataType: UInt32
    Length: UInt32
    Unicode: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved: Byte * 3
    Data: Byte * 1
class IMAGE_DOS_HEADER(Structure):
    e_magic: UInt16
    e_cblp: UInt16
    e_cp: UInt16
    e_crlc: UInt16
    e_cparhdr: UInt16
    e_minalloc: UInt16
    e_maxalloc: UInt16
    e_ss: UInt16
    e_sp: UInt16
    e_csum: UInt16
    e_ip: UInt16
    e_cs: UInt16
    e_lfarlc: UInt16
    e_ovno: UInt16
    e_res: UInt16 * 4
    e_oemid: UInt16
    e_oeminfo: UInt16
    e_res2: UInt16 * 10
    e_lfanew: Int32
    _pack_ = 2
class IMAGE_DYNAMIC_RELOCATION32(Structure):
    Symbol: UInt32
    BaseRelocSize: UInt32
    _pack_ = 1
class IMAGE_DYNAMIC_RELOCATION32_V2(Structure):
    HeaderSize: UInt32
    FixupInfoSize: UInt32
    Symbol: UInt32
    SymbolGroup: UInt32
    Flags: UInt32
    _pack_ = 1
class IMAGE_DYNAMIC_RELOCATION64(Structure):
    Symbol: UInt64
    BaseRelocSize: UInt32
    _pack_ = 1
class IMAGE_DYNAMIC_RELOCATION64_V2(Structure):
    HeaderSize: UInt32
    FixupInfoSize: UInt32
    Symbol: UInt64
    SymbolGroup: UInt32
    Flags: UInt32
    _pack_ = 1
class IMAGE_DYNAMIC_RELOCATION_TABLE(Structure):
    Version: UInt32
    Size: UInt32
class IMAGE_EPILOGUE_DYNAMIC_RELOCATION_HEADER(Structure):
    EpilogueCount: UInt32
    EpilogueByteCount: Byte
    BranchDescriptorElementSize: Byte
    BranchDescriptorCount: UInt16
    _pack_ = 1
class IMAGE_EXPORT_DIRECTORY(Structure):
    Characteristics: UInt32
    TimeDateStamp: UInt32
    MajorVersion: UInt16
    MinorVersion: UInt16
    Name: UInt32
    Base: UInt32
    NumberOfFunctions: UInt32
    NumberOfNames: UInt32
    AddressOfFunctions: UInt32
    AddressOfNames: UInt32
    AddressOfNameOrdinals: UInt32
class IMAGE_FUNCTION_OVERRIDE_DYNAMIC_RELOCATION(Structure):
    OriginalRva: UInt32
    BDDOffset: UInt32
    RvaSize: UInt32
    BaseRelocSize: UInt32
    _pack_ = 1
class IMAGE_FUNCTION_OVERRIDE_HEADER(Structure):
    FuncOverrideSize: UInt32
    _pack_ = 1
class IMAGE_HOT_PATCH_BASE(Structure):
    SequenceNumber: UInt32
    Flags: UInt32
    OriginalTimeDateStamp: UInt32
    OriginalCheckSum: UInt32
    CodeIntegrityInfo: UInt32
    CodeIntegritySize: UInt32
    PatchTable: UInt32
    BufferOffset: UInt32
class IMAGE_HOT_PATCH_HASHES(Structure):
    SHA256: Byte * 32
    SHA1: Byte * 20
class IMAGE_HOT_PATCH_INFO(Structure):
    Version: UInt32
    Size: UInt32
    SequenceNumber: UInt32
    BaseImageList: UInt32
    BaseImageCount: UInt32
    BufferOffset: UInt32
    ExtraPatchSize: UInt32
class IMAGE_IMPORT_BY_NAME(Structure):
    Hint: UInt16
    Name: win32more.Windows.Win32.Foundation.CHAR * 1
class IMAGE_IMPORT_CONTROL_TRANSFER_DYNAMIC_RELOCATION(Structure):
    PageRelativeOffset: Annotated[UInt32, 12]
    IndirectCall: Annotated[UInt32, 1]
    IATIndex: Annotated[UInt32, 19]
    _pack_ = 1
class IMAGE_IMPORT_DESCRIPTOR(Structure):
    Anonymous: _Anonymous_e__Union
    TimeDateStamp: UInt32
    ForwarderChain: UInt32
    Name: UInt32
    FirstThunk: UInt32
    class _Anonymous_e__Union(Union):
        Characteristics: UInt32
        OriginalFirstThunk: UInt32
class IMAGE_INDIR_CONTROL_TRANSFER_DYNAMIC_RELOCATION(Structure):
    PageRelativeOffset: Annotated[UInt16, 12]
    IndirectCall: Annotated[UInt16, 1]
    RexWPrefix: Annotated[UInt16, 1]
    CfgCheck: Annotated[UInt16, 1]
    Reserved: Annotated[UInt16, 1]
    _pack_ = 1
class IMAGE_LINENUMBER(Structure):
    Type: _Type_e__Union
    Linenumber: UInt16
    class _Type_e__Union(Union):
        SymbolTableIndex: UInt32
        VirtualAddress: UInt32
        _pack_ = 2
class IMAGE_OS2_HEADER(Structure):
    ne_magic: UInt16
    ne_ver: win32more.Windows.Win32.Foundation.CHAR
    ne_rev: win32more.Windows.Win32.Foundation.CHAR
    ne_enttab: UInt16
    ne_cbenttab: UInt16
    ne_crc: Int32
    ne_flags: UInt16
    ne_autodata: UInt16
    ne_heap: UInt16
    ne_stack: UInt16
    ne_csip: Int32
    ne_sssp: Int32
    ne_cseg: UInt16
    ne_cmod: UInt16
    ne_cbnrestab: UInt16
    ne_segtab: UInt16
    ne_rsrctab: UInt16
    ne_restab: UInt16
    ne_modtab: UInt16
    ne_imptab: UInt16
    ne_nrestab: Int32
    ne_cmovent: UInt16
    ne_align: UInt16
    ne_cres: UInt16
    ne_exetyp: Byte
    ne_flagsothers: Byte
    ne_pretthunks: UInt16
    ne_psegrefbytes: UInt16
    ne_swaparea: UInt16
    ne_expver: UInt16
    _pack_ = 2
class IMAGE_POLICY_ENTRY(Structure):
    Type: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE
    PolicyId: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID
    u: _u_e__Union
    class _u_e__Union(Union):
        None_: VoidPtr
        BoolValue: win32more.Windows.Win32.Foundation.BOOLEAN
        Int8Value: SByte
        UInt8Value: Byte
        Int16Value: Int16
        UInt16Value: UInt16
        Int32Value: Int32
        UInt32Value: UInt32
        Int64Value: Int64
        UInt64Value: UInt64
        AnsiStringValue: win32more.Windows.Win32.Foundation.PSTR
        UnicodeStringValue: win32more.Windows.Win32.Foundation.PWSTR
IMAGE_POLICY_ENTRY_TYPE = Int32
ImagePolicyEntryTypeNone: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 0
ImagePolicyEntryTypeBool: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 1
ImagePolicyEntryTypeInt8: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 2
ImagePolicyEntryTypeUInt8: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 3
ImagePolicyEntryTypeInt16: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 4
ImagePolicyEntryTypeUInt16: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 5
ImagePolicyEntryTypeInt32: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 6
ImagePolicyEntryTypeUInt32: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 7
ImagePolicyEntryTypeInt64: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 8
ImagePolicyEntryTypeUInt64: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 9
ImagePolicyEntryTypeAnsiString: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 10
ImagePolicyEntryTypeUnicodeString: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 11
ImagePolicyEntryTypeOverride: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 12
ImagePolicyEntryTypeMaximum: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY_TYPE = 13
IMAGE_POLICY_ID = Int32
ImagePolicyIdNone: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 0
ImagePolicyIdEtw: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 1
ImagePolicyIdDebug: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 2
ImagePolicyIdCrashDump: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 3
ImagePolicyIdCrashDumpKey: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 4
ImagePolicyIdCrashDumpKeyGuid: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 5
ImagePolicyIdParentSd: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 6
ImagePolicyIdParentSdRev: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 7
ImagePolicyIdSvn: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 8
ImagePolicyIdDeviceId: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 9
ImagePolicyIdCapability: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 10
ImagePolicyIdScenarioId: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 11
ImagePolicyIdMaximum: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ID = 12
class IMAGE_POLICY_METADATA(Structure):
    Version: Byte
    Reserved0: Byte * 7
    ApplicationId: UInt64
    Policies: win32more.Windows.Win32.System.SystemServices.IMAGE_POLICY_ENTRY * 1
class IMAGE_PROLOGUE_DYNAMIC_RELOCATION_HEADER(Structure):
    PrologueByteCount: Byte
class IMAGE_RELOCATION(Structure):
    Anonymous: _Anonymous_e__Union
    SymbolTableIndex: UInt32
    Type: UInt16
    _pack_ = 2
    class _Anonymous_e__Union(Union):
        VirtualAddress: UInt32
        RelocCount: UInt32
        _pack_ = 2
class IMAGE_RESOURCE_DATA_ENTRY(Structure):
    OffsetToData: UInt32
    Size: UInt32
    CodePage: UInt32
    Reserved: UInt32
class IMAGE_RESOURCE_DIRECTORY(Structure):
    Characteristics: UInt32
    TimeDateStamp: UInt32
    MajorVersion: UInt16
    MinorVersion: UInt16
    NumberOfNamedEntries: UInt16
    NumberOfIdEntries: UInt16
class IMAGE_RESOURCE_DIRECTORY_ENTRY(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        Anonymous: _Anonymous_e__Struct
        Name: UInt32
        Id: UInt16
        class _Anonymous_e__Struct(Structure):
            NameOffset: Annotated[UInt32, 31]
            NameIsString: Annotated[UInt32, 1]
    class _Anonymous2_e__Union(Union):
        OffsetToData: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            OffsetToDirectory: Annotated[UInt32, 31]
            DataIsDirectory: Annotated[UInt32, 1]
class IMAGE_RESOURCE_DIRECTORY_STRING(Structure):
    Length: UInt16
    NameString: win32more.Windows.Win32.Foundation.CHAR * 1
class IMAGE_RESOURCE_DIR_STRING_U(Structure):
    Length: UInt16
    NameString: Char * 1
class IMAGE_SEPARATE_DEBUG_HEADER(Structure):
    Signature: UInt16
    Flags: UInt16
    Machine: UInt16
    Characteristics: UInt16
    TimeDateStamp: UInt32
    CheckSum: UInt32
    ImageBase: UInt32
    SizeOfImage: UInt32
    NumberOfSections: UInt32
    ExportedNamesSize: UInt32
    DebugDirectorySize: UInt32
    SectionAlignment: UInt32
    Reserved: UInt32 * 2
class IMAGE_SWITCHTABLE_BRANCH_DYNAMIC_RELOCATION(Structure):
    PageRelativeOffset: Annotated[UInt16, 12]
    RegisterNumber: Annotated[UInt16, 4]
    _pack_ = 1
class IMAGE_SYMBOL(Structure):
    N: _N_e__Union
    Value: UInt32
    SectionNumber: Int16
    Type: UInt16
    StorageClass: Byte
    NumberOfAuxSymbols: Byte
    _pack_ = 2
    class _N_e__Union(Union):
        ShortName: Byte * 8
        Name: _Name_e__Struct
        LongName: UInt32 * 2
        _pack_ = 2
        class _Name_e__Struct(Structure):
            Short: UInt32
            Long: UInt32
            _pack_ = 2
class IMAGE_SYMBOL_EX(Structure):
    N: _N_e__Union
    Value: UInt32
    SectionNumber: Int32
    Type: UInt16
    StorageClass: Byte
    NumberOfAuxSymbols: Byte
    _pack_ = 2
    class _N_e__Union(Union):
        ShortName: Byte * 8
        Name: _Name_e__Struct
        LongName: UInt32 * 2
        _pack_ = 2
        class _Name_e__Struct(Structure):
            Short: UInt32
            Long: UInt32
            _pack_ = 2
class IMAGE_TLS_DIRECTORY32(Structure):
    StartAddressOfRawData: UInt32
    EndAddressOfRawData: UInt32
    AddressOfIndex: UInt32
    AddressOfCallBacks: UInt32
    SizeOfZeroFill: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Characteristics: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            Reserved0: Annotated[UInt32, 20]
            Alignment: Annotated[UInt32, 4]
            Reserved1: Annotated[UInt32, 8]
class IMAGE_TLS_DIRECTORY64(Structure):
    StartAddressOfRawData: UInt64
    EndAddressOfRawData: UInt64
    AddressOfIndex: UInt64
    AddressOfCallBacks: UInt64
    SizeOfZeroFill: UInt32
    Anonymous: _Anonymous_e__Union
    _pack_ = 4
    class _Anonymous_e__Union(Union):
        Characteristics: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            Reserved0: Annotated[UInt32, 20]
            Alignment: Annotated[UInt32, 4]
            Reserved1: Annotated[UInt32, 8]
class IMAGE_VXD_HEADER(Structure):
    e32_magic: UInt16
    e32_border: Byte
    e32_worder: Byte
    e32_level: UInt32
    e32_cpu: UInt16
    e32_os: UInt16
    e32_ver: UInt32
    e32_mflags: UInt32
    e32_mpages: UInt32
    e32_startobj: UInt32
    e32_eip: UInt32
    e32_stackobj: UInt32
    e32_esp: UInt32
    e32_pagesize: UInt32
    e32_lastpagesize: UInt32
    e32_fixupsize: UInt32
    e32_fixupsum: UInt32
    e32_ldrsize: UInt32
    e32_ldrsum: UInt32
    e32_objtab: UInt32
    e32_objcnt: UInt32
    e32_objmap: UInt32
    e32_itermap: UInt32
    e32_rsrctab: UInt32
    e32_rsrccnt: UInt32
    e32_restab: UInt32
    e32_enttab: UInt32
    e32_dirtab: UInt32
    e32_dircnt: UInt32
    e32_fpagetab: UInt32
    e32_frectab: UInt32
    e32_impmod: UInt32
    e32_impmodcnt: UInt32
    e32_impproc: UInt32
    e32_pagesum: UInt32
    e32_datapage: UInt32
    e32_preload: UInt32
    e32_nrestab: UInt32
    e32_cbnrestab: UInt32
    e32_nressum: UInt32
    e32_autodata: UInt32
    e32_debuginfo: UInt32
    e32_debuglen: UInt32
    e32_instpreload: UInt32
    e32_instdemand: UInt32
    e32_heapsize: UInt32
    e32_res3: Byte * 12
    e32_winresoff: UInt32
    e32_winreslen: UInt32
    e32_devid: UInt16
    e32_ddkver: UInt16
    _pack_ = 2
class IMPORT_OBJECT_HEADER(Structure):
    Sig1: UInt16
    Sig2: UInt16
    Version: UInt16
    Machine: UInt16
    TimeDateStamp: UInt32
    SizeOfData: UInt32
    Anonymous: _Anonymous_e__Union
    Type: Annotated[UInt16, 2]
    NameType: Annotated[UInt16, 3]
    Reserved: Annotated[UInt16, 11]
    class _Anonymous_e__Union(Union):
        Ordinal: UInt16
        Hint: UInt16
IMPORT_OBJECT_NAME_TYPE = Int32
IMPORT_OBJECT_ORDINAL: win32more.Windows.Win32.System.SystemServices.IMPORT_OBJECT_NAME_TYPE = 0
IMPORT_OBJECT_NAME: win32more.Windows.Win32.System.SystemServices.IMPORT_OBJECT_NAME_TYPE = 1
IMPORT_OBJECT_NAME_NO_PREFIX: win32more.Windows.Win32.System.SystemServices.IMPORT_OBJECT_NAME_TYPE = 2
IMPORT_OBJECT_NAME_UNDECORATE: win32more.Windows.Win32.System.SystemServices.IMPORT_OBJECT_NAME_TYPE = 3
IMPORT_OBJECT_NAME_EXPORTAS: win32more.Windows.Win32.System.SystemServices.IMPORT_OBJECT_NAME_TYPE = 4
IMPORT_OBJECT_TYPE = Int32
IMPORT_OBJECT_CODE: win32more.Windows.Win32.System.SystemServices.IMPORT_OBJECT_TYPE = 0
IMPORT_OBJECT_DATA: win32more.Windows.Win32.System.SystemServices.IMPORT_OBJECT_TYPE = 1
IMPORT_OBJECT_CONST: win32more.Windows.Win32.System.SystemServices.IMPORT_OBJECT_TYPE = 2
class KERNEL_CET_CONTEXT(Structure):
    Ssp: UInt64
    Rip: UInt64
    SegCs: UInt16
    Anonymous: _Anonymous_e__Union
    Fill: UInt16 * 2
    class _Anonymous_e__Union(Union):
        AllFlags: UInt16
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            UseWrss: Annotated[UInt16, 1]
            PopShadowStackOne: Annotated[UInt16, 1]
            Unused: Annotated[UInt16, 14]
class KTMOBJECT_CURSOR(Structure):
    LastQuery: Guid
    ObjectIdCount: UInt32
    ObjectIds: Guid * 1
KTMOBJECT_TYPE = Int32
KTMOBJECT_TRANSACTION: win32more.Windows.Win32.System.SystemServices.KTMOBJECT_TYPE = 0
KTMOBJECT_TRANSACTION_MANAGER: win32more.Windows.Win32.System.SystemServices.KTMOBJECT_TYPE = 1
KTMOBJECT_RESOURCE_MANAGER: win32more.Windows.Win32.System.SystemServices.KTMOBJECT_TYPE = 2
KTMOBJECT_ENLISTMENT: win32more.Windows.Win32.System.SystemServices.KTMOBJECT_TYPE = 3
KTMOBJECT_INVALID: win32more.Windows.Win32.System.SystemServices.KTMOBJECT_TYPE = 4
class MAXVERSIONTESTED_INFO(Structure):
    MaxVersionTested: UInt64
MODIFIERKEYS_FLAGS = UInt32
MK_LBUTTON: win32more.Windows.Win32.System.SystemServices.MODIFIERKEYS_FLAGS = 1
MK_RBUTTON: win32more.Windows.Win32.System.SystemServices.MODIFIERKEYS_FLAGS = 2
MK_SHIFT: win32more.Windows.Win32.System.SystemServices.MODIFIERKEYS_FLAGS = 4
MK_CONTROL: win32more.Windows.Win32.System.SystemServices.MODIFIERKEYS_FLAGS = 8
MK_MBUTTON: win32more.Windows.Win32.System.SystemServices.MODIFIERKEYS_FLAGS = 16
MK_XBUTTON1: win32more.Windows.Win32.System.SystemServices.MODIFIERKEYS_FLAGS = 32
MK_XBUTTON2: win32more.Windows.Win32.System.SystemServices.MODIFIERKEYS_FLAGS = 64
MONITOR_DISPLAY_STATE = Int32
PowerMonitorOff: win32more.Windows.Win32.System.SystemServices.MONITOR_DISPLAY_STATE = 0
PowerMonitorOn: win32more.Windows.Win32.System.SystemServices.MONITOR_DISPLAY_STATE = 1
PowerMonitorDim: win32more.Windows.Win32.System.SystemServices.MONITOR_DISPLAY_STATE = 2
class NETWORK_APP_INSTANCE_EA(Structure):
    AppInstanceID: Guid
    CsvFlags: UInt32
class NON_PAGED_DEBUG_INFO(Structure):
    Signature: UInt16
    Flags: UInt16
    Size: UInt32
    Machine: UInt16
    Characteristics: UInt16
    TimeDateStamp: UInt32
    CheckSum: UInt32
    SizeOfImage: UInt32
    ImageBase: UInt64
    _pack_ = 4
class NOTIFY_USER_POWER_SETTING(Structure):
    Guid: Guid
class NT_TIB32(Structure):
    ExceptionList: UInt32
    StackBase: UInt32
    StackLimit: UInt32
    SubSystemTib: UInt32
    Anonymous: _Anonymous_e__Union
    ArbitraryUserPointer: UInt32
    Self: UInt32
    class _Anonymous_e__Union(Union):
        FiberData: UInt32
        Version: UInt32
class NT_TIB64(Structure):
    ExceptionList: UInt64
    StackBase: UInt64
    StackLimit: UInt64
    SubSystemTib: UInt64
    Anonymous: _Anonymous_e__Union
    ArbitraryUserPointer: UInt64
    Self: UInt64
    class _Anonymous_e__Union(Union):
        FiberData: UInt64
        Version: UInt32
class PACKEDEVENTINFO(Structure):
    ulSize: UInt32
    ulNumEventsForLogFile: UInt32
    ulOffsets: UInt32 * 1
if ARCH in 'X64,ARM64':
    @winfunctype_pointer
    def PEXCEPTION_FILTER(ExceptionPointers: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.EXCEPTION_POINTERS), EstablisherFrame: VoidPtr) -> Int32: ...
@winfunctype_pointer
def PIMAGE_TLS_CALLBACK(DllHandle: VoidPtr, Reason: UInt32, Reserved: VoidPtr) -> Void: ...
if ARCH in 'ARM64':
    @winfunctype_pointer
    def POUT_OF_PROCESS_FUNCTION_TABLE_CALLBACK(Process: win32more.Windows.Win32.Foundation.HANDLE, TableAddress: VoidPtr, Entries: POINTER(UInt32), Functions: POINTER(POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.IMAGE_ARM64_RUNTIME_FUNCTION_ENTRY))) -> UInt32: ...
elif ARCH in 'X64':
    @winfunctype_pointer
    def POUT_OF_PROCESS_FUNCTION_TABLE_CALLBACK(Process: win32more.Windows.Win32.Foundation.HANDLE, TableAddress: VoidPtr, Entries: POINTER(UInt32), Functions: POINTER(POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.IMAGE_RUNTIME_FUNCTION_ENTRY))) -> UInt32: ...
class PROCESSOR_IDLESTATE_INFO(Structure):
    TimeCheck: UInt32
    DemotePercent: Byte
    PromotePercent: Byte
    Spare: Byte * 2
class PROCESSOR_IDLESTATE_POLICY(Structure):
    Revision: UInt16
    Flags: _Flags_e__Union
    PolicyCount: UInt32
    Policy: win32more.Windows.Win32.System.SystemServices.PROCESSOR_IDLESTATE_INFO * 3
    class _Flags_e__Union(Union):
        AsWORD: UInt16
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            AllowScaling: Annotated[UInt16, 1]
            Disabled: Annotated[UInt16, 1]
            Reserved: Annotated[UInt16, 14]
class PROCESSOR_PERFSTATE_POLICY(Structure):
    Revision: UInt32
    MaxThrottle: Byte
    MinThrottle: Byte
    BusyAdjThreshold: Byte
    Anonymous: _Anonymous_e__Union
    TimeCheck: UInt32
    IncreaseTime: UInt32
    DecreaseTime: UInt32
    IncreasePercent: UInt32
    DecreasePercent: UInt32
    class _Anonymous_e__Union(Union):
        Spare: Byte
        Flags: _Flags_e__Union
        class _Flags_e__Union(Union):
            AsBYTE: Byte
            Anonymous: _Anonymous_e__Struct
            class _Anonymous_e__Struct(Structure):
                NoDomainAccounting: Annotated[Byte, 1]
                IncreasePolicy: Annotated[Byte, 2]
                DecreasePolicy: Annotated[Byte, 2]
                Reserved: Annotated[Byte, 3]
class PROCESS_MITIGATION_ACTIVATION_CONTEXT_TRUST_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            AssemblyManifestRedirectionTrust: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 31]
class PROCESS_MITIGATION_ASLR_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            EnableBottomUpRandomization: Annotated[UInt32, 1]
            EnableForceRelocateImages: Annotated[UInt32, 1]
            EnableHighEntropy: Annotated[UInt32, 1]
            DisallowStrippedImages: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 28]
class PROCESS_MITIGATION_BINARY_SIGNATURE_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            MicrosoftSignedOnly: Annotated[UInt32, 1]
            StoreSignedOnly: Annotated[UInt32, 1]
            MitigationOptIn: Annotated[UInt32, 1]
            AuditMicrosoftSignedOnly: Annotated[UInt32, 1]
            AuditStoreSignedOnly: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 27]
class PROCESS_MITIGATION_CHILD_PROCESS_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            NoChildProcessCreation: Annotated[UInt32, 1]
            AuditNoChildProcessCreation: Annotated[UInt32, 1]
            AllowSecureProcessCreation: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 29]
class PROCESS_MITIGATION_CONTROL_FLOW_GUARD_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            EnableControlFlowGuard: Annotated[UInt32, 1]
            EnableExportSuppression: Annotated[UInt32, 1]
            StrictMode: Annotated[UInt32, 1]
            EnableXfg: Annotated[UInt32, 1]
            EnableXfgAuditMode: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 27]
class PROCESS_MITIGATION_DEP_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    Permanent: win32more.Windows.Win32.Foundation.BOOLEAN
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            Enable: Annotated[UInt32, 1]
            DisableAtlThunkEmulation: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 30]
class PROCESS_MITIGATION_DYNAMIC_CODE_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            ProhibitDynamicCode: Annotated[UInt32, 1]
            AllowThreadOptOut: Annotated[UInt32, 1]
            AllowRemoteDowngrade: Annotated[UInt32, 1]
            AuditProhibitDynamicCode: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 28]
class PROCESS_MITIGATION_EXTENSION_POINT_DISABLE_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            DisableExtensionPoints: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 31]
class PROCESS_MITIGATION_FONT_DISABLE_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            DisableNonSystemFonts: Annotated[UInt32, 1]
            AuditNonSystemFontLoading: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 30]
class PROCESS_MITIGATION_IMAGE_LOAD_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            NoRemoteImages: Annotated[UInt32, 1]
            NoLowMandatoryLabelImages: Annotated[UInt32, 1]
            PreferSystem32Images: Annotated[UInt32, 1]
            AuditNoRemoteImages: Annotated[UInt32, 1]
            AuditNoLowMandatoryLabelImages: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 27]
class PROCESS_MITIGATION_PAYLOAD_RESTRICTION_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            EnableExportAddressFilter: Annotated[UInt32, 1]
            AuditExportAddressFilter: Annotated[UInt32, 1]
            EnableExportAddressFilterPlus: Annotated[UInt32, 1]
            AuditExportAddressFilterPlus: Annotated[UInt32, 1]
            EnableImportAddressFilter: Annotated[UInt32, 1]
            AuditImportAddressFilter: Annotated[UInt32, 1]
            EnableRopStackPivot: Annotated[UInt32, 1]
            AuditRopStackPivot: Annotated[UInt32, 1]
            EnableRopCallerCheck: Annotated[UInt32, 1]
            AuditRopCallerCheck: Annotated[UInt32, 1]
            EnableRopSimExec: Annotated[UInt32, 1]
            AuditRopSimExec: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 20]
class PROCESS_MITIGATION_REDIRECTION_TRUST_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            EnforceRedirectionTrust: Annotated[UInt32, 1]
            AuditRedirectionTrust: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 30]
class PROCESS_MITIGATION_SEHOP_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            EnableSehop: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 31]
class PROCESS_MITIGATION_SIDE_CHANNEL_ISOLATION_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            SmtBranchTargetIsolation: Annotated[UInt32, 1]
            IsolateSecurityDomain: Annotated[UInt32, 1]
            DisablePageCombine: Annotated[UInt32, 1]
            SpeculativeStoreBypassDisable: Annotated[UInt32, 1]
            RestrictCoreSharing: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 27]
class PROCESS_MITIGATION_STRICT_HANDLE_CHECK_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            RaiseExceptionOnInvalidHandleReference: Annotated[UInt32, 1]
            HandleExceptionsPermanentlyEnabled: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 30]
class PROCESS_MITIGATION_SYSTEM_CALL_DISABLE_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            DisallowWin32kSystemCalls: Annotated[UInt32, 1]
            AuditDisallowWin32kSystemCalls: Annotated[UInt32, 1]
            DisallowFsctlSystemCalls: Annotated[UInt32, 1]
            AuditDisallowFsctlSystemCalls: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 28]
class PROCESS_MITIGATION_SYSTEM_CALL_FILTER_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            FilterId: Annotated[UInt32, 4]
            ReservedFlags: Annotated[UInt32, 28]
class PROCESS_MITIGATION_USER_POINTER_AUTH_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            EnablePointerAuthUserIp: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 31]
class PROCESS_MITIGATION_USER_SHADOW_STACK_POLICY(Structure):
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        Flags: UInt32
        Anonymous: _Anonymous_e__Struct
        class _Anonymous_e__Struct(Structure):
            EnableUserShadowStack: Annotated[UInt32, 1]
            AuditUserShadowStack: Annotated[UInt32, 1]
            SetContextIpValidation: Annotated[UInt32, 1]
            AuditSetContextIpValidation: Annotated[UInt32, 1]
            EnableUserShadowStackStrictMode: Annotated[UInt32, 1]
            BlockNonCetBinaries: Annotated[UInt32, 1]
            BlockNonCetBinariesNonEhcont: Annotated[UInt32, 1]
            AuditBlockNonCetBinaries: Annotated[UInt32, 1]
            CetDynamicApisOutOfProcOnly: Annotated[UInt32, 1]
            SetContextIpValidationRelaxedMode: Annotated[UInt32, 1]
            ReservedFlags: Annotated[UInt32, 22]
if ARCH in 'ARM64':
    @winfunctype_pointer
    def PTERMINATION_HANDLER(_abnormal_termination: win32more.Windows.Win32.Foundation.BOOLEAN, EstablisherFrame: UInt64) -> Void: ...
elif ARCH in 'X64':
    @winfunctype_pointer
    def PTERMINATION_HANDLER(_abnormal_termination: win32more.Windows.Win32.Foundation.BOOLEAN, EstablisherFrame: VoidPtr) -> Void: ...
@winfunctype_pointer
def PUMS_SCHEDULER_ENTRY_POINT(Reason: win32more.Windows.Win32.System.SystemServices.RTL_UMS_SCHEDULER_REASON, ActivationPayload: UIntPtr, SchedulerParam: VoidPtr) -> Void: ...
class QUOTA_LIMITS_EX(Structure):
    PagedPoolLimit: UIntPtr
    NonPagedPoolLimit: UIntPtr
    MinimumWorkingSetSize: UIntPtr
    MaximumWorkingSetSize: UIntPtr
    PagefileLimit: UIntPtr
    TimeLimit: Int64
    WorkingSetLimit: UIntPtr
    Reserved2: UIntPtr
    Reserved3: UIntPtr
    Reserved4: UIntPtr
    Flags: UInt32
    CpuRateLimit: win32more.Windows.Win32.System.SystemServices.RATE_QUOTA_LIMIT
class RATE_QUOTA_LIMIT(Union):
    RateData: UInt32
    Anonymous: _Anonymous_e__Struct
    class _Anonymous_e__Struct(Structure):
        RatePercent: Annotated[UInt32, 7]
        Reserved0: Annotated[UInt32, 25]
class REARRANGE_FILE_DATA(Structure):
    SourceStartingOffset: UInt64
    TargetOffset: UInt64
    SourceFileHandle: win32more.Windows.Win32.Foundation.HANDLE
    Length: UInt32
    Flags: UInt32
if ARCH in 'X64,ARM64':
    class REARRANGE_FILE_DATA32(Structure):
        SourceStartingOffset: UInt64
        TargetOffset: UInt64
        SourceFileHandle: UInt32
        Length: UInt32
        Flags: UInt32
RECO_FLAGS = UInt32
RECO_PASTE: win32more.Windows.Win32.System.SystemServices.RECO_FLAGS = 0
RECO_DROP: win32more.Windows.Win32.System.SystemServices.RECO_FLAGS = 1
RECO_COPY: win32more.Windows.Win32.System.SystemServices.RECO_FLAGS = 2
RECO_CUT: win32more.Windows.Win32.System.SystemServices.RECO_FLAGS = 3
RECO_DRAG: win32more.Windows.Win32.System.SystemServices.RECO_FLAGS = 4
class REDBOOK_DIGITAL_AUDIO_EXTRACTION_INFO(Structure):
    Version: UInt32
    Accurate: UInt32
    Supported: UInt32
    AccurateMask0: UInt32
class RESOURCEMANAGER_BASIC_INFORMATION(Structure):
    ResourceManagerId: Guid
    DescriptionLength: UInt32
    Description: Char * 1
class RESOURCEMANAGER_COMPLETION_INFORMATION(Structure):
    IoCompletionPortHandle: win32more.Windows.Win32.Foundation.HANDLE
    CompletionKey: UIntPtr
RESOURCEMANAGER_INFORMATION_CLASS = Int32
ResourceManagerBasicInformation: win32more.Windows.Win32.System.SystemServices.RESOURCEMANAGER_INFORMATION_CLASS = 0
ResourceManagerCompletionInformation: win32more.Windows.Win32.System.SystemServices.RESOURCEMANAGER_INFORMATION_CLASS = 1
RTL_UMS_SCHEDULER_REASON = Int32
UmsSchedulerStartup: win32more.Windows.Win32.System.SystemServices.RTL_UMS_SCHEDULER_REASON = 0
UmsSchedulerThreadBlocked: win32more.Windows.Win32.System.SystemServices.RTL_UMS_SCHEDULER_REASON = 1
UmsSchedulerThreadYield: win32more.Windows.Win32.System.SystemServices.RTL_UMS_SCHEDULER_REASON = 2
class RemHBITMAP(Structure):
    cbData: UInt32
    data: Byte * 1
class RemHBRUSH(Structure):
    cbData: UInt32
    data: Byte * 1
class RemHENHMETAFILE(Structure):
    cbData: UInt32
    data: Byte * 1
class RemHGLOBAL(Structure):
    fNullHGlobal: Int32
    cbData: UInt32
    data: Byte * 1
class RemHMETAFILEPICT(Structure):
    mm: Int32
    xExt: Int32
    yExt: Int32
    cbData: UInt32
    data: Byte * 1
class RemHPALETTE(Structure):
    cbData: UInt32
    data: Byte * 1
class RemotableHandle(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        hInproc: Int32
        hRemote: Int32
ReplacesCorHdrNumericDefines = Int32
COMIMAGE_FLAGS_ILONLY: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 1
COMIMAGE_FLAGS_32BITREQUIRED: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 2
COMIMAGE_FLAGS_IL_LIBRARY: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 4
COMIMAGE_FLAGS_STRONGNAMESIGNED: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 8
COMIMAGE_FLAGS_NATIVE_ENTRYPOINT: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 16
COMIMAGE_FLAGS_TRACKDEBUGDATA: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 65536
COMIMAGE_FLAGS_32BITPREFERRED: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 131072
COR_VERSION_MAJOR_V2: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 2
COR_VERSION_MAJOR: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 2
COR_VERSION_MINOR: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 5
COR_DELETED_NAME_LENGTH: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 8
COR_VTABLEGAP_NAME_LENGTH: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 8
NATIVE_TYPE_MAX_CB: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 1
COR_ILMETHOD_SECT_SMALL_MAX_DATASIZE: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 255
IMAGE_COR_MIH_METHODRVA: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 1
IMAGE_COR_MIH_EHRVA: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 2
IMAGE_COR_MIH_BASICBLOCK: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 8
COR_VTABLE_32BIT: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 1
COR_VTABLE_64BIT: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 2
COR_VTABLE_FROM_UNMANAGED: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 4
COR_VTABLE_FROM_UNMANAGED_RETAIN_APPDOMAIN: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 8
COR_VTABLE_CALL_MOST_DERIVED: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 16
IMAGE_COR_EATJ_THUNK_SIZE: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 32
MAX_CLASS_NAME: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 1024
MAX_PACKAGE_NAME: win32more.Windows.Win32.System.SystemServices.ReplacesCorHdrNumericDefines = 1024
class SCOPE_TABLE_AMD64(Structure):
    Count: UInt32
    ScopeRecord: _Anonymous_e__Struct * 1
    class _Anonymous_e__Struct(Structure):
        BeginAddress: UInt32
        EndAddress: UInt32
        HandlerAddress: UInt32
        JumpTarget: UInt32
class SCOPE_TABLE_ARM(Structure):
    Count: UInt32
    ScopeRecord: _Anonymous_e__Struct * 1
    class _Anonymous_e__Struct(Structure):
        BeginAddress: UInt32
        EndAddress: UInt32
        HandlerAddress: UInt32
        JumpTarget: UInt32
class SCOPE_TABLE_ARM64(Structure):
    Count: UInt32
    ScopeRecord: _Anonymous_e__Struct * 1
    class _Anonymous_e__Struct(Structure):
        BeginAddress: UInt32
        EndAddress: UInt32
        HandlerAddress: UInt32
        JumpTarget: UInt32
class SCRUB_DATA_INPUT(Structure):
    Size: UInt32
    Flags: UInt32
    MaximumIos: UInt32
    ObjectId: UInt32 * 4
    Reserved: UInt32 * 41
    ResumeContext: Byte * 1040
class SCRUB_DATA_OUTPUT(Structure):
    Size: UInt32
    Flags: UInt32
    Status: UInt32
    ErrorFileOffset: UInt64
    ErrorLength: UInt64
    NumberOfBytesRepaired: UInt64
    NumberOfBytesFailed: UInt64
    InternalFileReference: UInt64
    ResumeContextLength: UInt16
    ParityExtentDataOffset: UInt16
    Reserved: UInt32 * 9
    NumberOfMetadataBytesProcessed: UInt64
    NumberOfDataBytesProcessed: UInt64
    TotalNumberOfMetadataBytesInUse: UInt64
    TotalNumberOfDataBytesInUse: UInt64
    DataBytesSkippedDueToNoAllocation: UInt64
    DataBytesSkippedDueToInvalidRun: UInt64
    DataBytesSkippedDueToIntegrityStream: UInt64
    DataBytesSkippedDueToRegionBeingClean: UInt64
    DataBytesSkippedDueToLockConflict: UInt64
    DataBytesSkippedDueToNoScrubDataFlag: UInt64
    DataBytesSkippedDueToNoScrubNonIntegrityStreamFlag: UInt64
    DataBytesScrubbed: UInt64
    ResumeContext: Byte * 1040
class SCRUB_PARITY_EXTENT(Structure):
    Offset: Int64
    Length: UInt64
class SCRUB_PARITY_EXTENT_DATA(Structure):
    Size: UInt16
    Flags: UInt16
    NumberOfParityExtents: UInt16
    MaximumNumberOfParityExtents: UInt16
    ParityExtents: win32more.Windows.Win32.System.SystemServices.SCRUB_PARITY_EXTENT * 1
class SECURITY_OBJECT_AI_PARAMS(Structure):
    Size: UInt32
    ConstraintMask: UInt32
class SERVERSILO_BASIC_INFORMATION(Structure):
    ServiceSessionId: UInt32
    State: win32more.Windows.Win32.System.SystemServices.SERVERSILO_STATE
    ExitStatus: UInt32
    IsDownlevelContainer: win32more.Windows.Win32.Foundation.BOOLEAN
    ApiSetSchema: VoidPtr
    HostApiSetSchema: VoidPtr
SERVERSILO_STATE = Int32
SERVERSILO_INITING: win32more.Windows.Win32.System.SystemServices.SERVERSILO_STATE = 0
SERVERSILO_STARTED: win32more.Windows.Win32.System.SystemServices.SERVERSILO_STATE = 1
SERVERSILO_SHUTTING_DOWN: win32more.Windows.Win32.System.SystemServices.SERVERSILO_STATE = 2
SERVERSILO_TERMINATING: win32more.Windows.Win32.System.SystemServices.SERVERSILO_STATE = 3
SERVERSILO_TERMINATED: win32more.Windows.Win32.System.SystemServices.SERVERSILO_STATE = 4
SERVICE_ERROR_TYPE = Int32
IgnoreError: win32more.Windows.Win32.System.SystemServices.SERVICE_ERROR_TYPE = 0
NormalError: win32more.Windows.Win32.System.SystemServices.SERVICE_ERROR_TYPE = 1
SevereError: win32more.Windows.Win32.System.SystemServices.SERVICE_ERROR_TYPE = 2
CriticalError: win32more.Windows.Win32.System.SystemServices.SERVICE_ERROR_TYPE = 3
SERVICE_LOAD_TYPE = Int32
BootLoad: win32more.Windows.Win32.System.SystemServices.SERVICE_LOAD_TYPE = 0
SystemLoad: win32more.Windows.Win32.System.SystemServices.SERVICE_LOAD_TYPE = 1
AutoLoad: win32more.Windows.Win32.System.SystemServices.SERVICE_LOAD_TYPE = 2
DemandLoad: win32more.Windows.Win32.System.SystemServices.SERVICE_LOAD_TYPE = 3
DisableLoad: win32more.Windows.Win32.System.SystemServices.SERVICE_LOAD_TYPE = 4
SERVICE_NODE_TYPE = Int32
DriverType: win32more.Windows.Win32.System.SystemServices.SERVICE_NODE_TYPE = 1
FileSystemType: win32more.Windows.Win32.System.SystemServices.SERVICE_NODE_TYPE = 2
Win32ServiceOwnProcess: win32more.Windows.Win32.System.SystemServices.SERVICE_NODE_TYPE = 16
Win32ServiceShareProcess: win32more.Windows.Win32.System.SystemServices.SERVICE_NODE_TYPE = 32
AdapterType: win32more.Windows.Win32.System.SystemServices.SERVICE_NODE_TYPE = 4
RecognizerType: win32more.Windows.Win32.System.SystemServices.SERVICE_NODE_TYPE = 8
SE_IMAGE_SIGNATURE_TYPE = Int32
SeImageSignatureNone: win32more.Windows.Win32.System.SystemServices.SE_IMAGE_SIGNATURE_TYPE = 0
SeImageSignatureEmbedded: win32more.Windows.Win32.System.SystemServices.SE_IMAGE_SIGNATURE_TYPE = 1
SeImageSignatureCache: win32more.Windows.Win32.System.SystemServices.SE_IMAGE_SIGNATURE_TYPE = 2
SeImageSignatureCatalogCached: win32more.Windows.Win32.System.SystemServices.SE_IMAGE_SIGNATURE_TYPE = 3
SeImageSignatureCatalogNotCached: win32more.Windows.Win32.System.SystemServices.SE_IMAGE_SIGNATURE_TYPE = 4
SeImageSignatureCatalogHint: win32more.Windows.Win32.System.SystemServices.SE_IMAGE_SIGNATURE_TYPE = 5
SeImageSignaturePackageCatalog: win32more.Windows.Win32.System.SystemServices.SE_IMAGE_SIGNATURE_TYPE = 6
SeImageSignaturePplMitigated: win32more.Windows.Win32.System.SystemServices.SE_IMAGE_SIGNATURE_TYPE = 7
class SE_TOKEN_USER(Structure):
    Anonymous1: _Anonymous1_e__Union
    Anonymous2: _Anonymous2_e__Union
    class _Anonymous1_e__Union(Union):
        TokenUser: win32more.Windows.Win32.Security.TOKEN_USER
        User: win32more.Windows.Win32.Security.SID_AND_ATTRIBUTES
    class _Anonymous2_e__Union(Union):
        Sid: win32more.Windows.Win32.Security.SID
        Buffer: Byte * 68
SFGAO_FLAGS = UInt32
SFGAO_CANCOPY: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 1
SFGAO_CANMOVE: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 2
SFGAO_CANLINK: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 4
SFGAO_STORAGE: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 8
SFGAO_CANRENAME: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 16
SFGAO_CANDELETE: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 32
SFGAO_HASPROPSHEET: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 64
SFGAO_DROPTARGET: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 256
SFGAO_CAPABILITYMASK: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 375
SFGAO_PLACEHOLDER: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 2048
SFGAO_SYSTEM: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 4096
SFGAO_ENCRYPTED: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 8192
SFGAO_ISSLOW: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 16384
SFGAO_GHOSTED: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 32768
SFGAO_LINK: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 65536
SFGAO_SHARE: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 131072
SFGAO_READONLY: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 262144
SFGAO_HIDDEN: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 524288
SFGAO_DISPLAYATTRMASK: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 1032192
SFGAO_FILESYSANCESTOR: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 268435456
SFGAO_FOLDER: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 536870912
SFGAO_FILESYSTEM: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 1073741824
SFGAO_HASSUBFOLDER: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 2147483648
SFGAO_CONTENTSMASK: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 2147483648
SFGAO_VALIDATE: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 16777216
SFGAO_REMOVABLE: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 33554432
SFGAO_COMPRESSED: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 67108864
SFGAO_BROWSABLE: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 134217728
SFGAO_NONENUMERATED: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 1048576
SFGAO_NEWCONTENT: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 2097152
SFGAO_CANMONIKER: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 4194304
SFGAO_HASSTORAGE: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 4194304
SFGAO_STREAM: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 4194304
SFGAO_STORAGEANCESTOR: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 8388608
SFGAO_STORAGECAPMASK: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 1891958792
SFGAO_PKEYSFGAOMASK: win32more.Windows.Win32.System.SystemServices.SFGAO_FLAGS = 2164539392
class SHARED_VIRTUAL_DISK_SUPPORT(Structure):
    SharedVirtualDiskSupport: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskSupportType
    HandleState: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskHandleState
class SHUFFLE_FILE_DATA(Structure):
    StartingOffset: Int64
    Length: Int64
    Flags: UInt32
class SILOOBJECT_BASIC_INFORMATION(Structure):
    SiloId: UInt32
    SiloParentId: UInt32
    NumberOfProcesses: UInt32
    IsInServerSilo: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved: Byte * 3
STATIC_STYLES = UInt32
SS_LEFT: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 0
SS_CENTER: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 1
SS_RIGHT: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 2
SS_ICON: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 3
SS_BLACKRECT: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 4
SS_GRAYRECT: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 5
SS_WHITERECT: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 6
SS_BLACKFRAME: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 7
SS_GRAYFRAME: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 8
SS_WHITEFRAME: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 9
SS_USERITEM: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 10
SS_SIMPLE: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 11
SS_LEFTNOWORDWRAP: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 12
SS_OWNERDRAW: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 13
SS_BITMAP: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 14
SS_ENHMETAFILE: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 15
SS_ETCHEDHORZ: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 16
SS_ETCHEDVERT: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 17
SS_ETCHEDFRAME: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 18
SS_TYPEMASK: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 31
SS_REALSIZECONTROL: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 64
SS_NOPREFIX: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 128
SS_NOTIFY: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 256
SS_CENTERIMAGE: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 512
SS_RIGHTJUST: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 1024
SS_REALSIZEIMAGE: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 2048
SS_SUNKEN: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 4096
SS_EDITCONTROL: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 8192
SS_ENDELLIPSIS: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 16384
SS_PATHELLIPSIS: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 32768
SS_WORDELLIPSIS: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 49152
SS_ELLIPSISMASK: win32more.Windows.Win32.System.SystemServices.STATIC_STYLES = 49152
class SUPPORTED_OS_INFO(Structure):
    MajorVersion: UInt16
    MinorVersion: UInt16
SharedVirtualDiskHandleState = Int32
SharedVirtualDiskHandleStateNone: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskHandleState = 0
SharedVirtualDiskHandleStateFileShared: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskHandleState = 1
SharedVirtualDiskHandleStateHandleShared: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskHandleState = 3
SharedVirtualDiskSupportType = Int32
SharedVirtualDisksUnsupported: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskSupportType = 0
SharedVirtualDisksSupported: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskSupportType = 1
SharedVirtualDiskSnapshotsSupported: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskSupportType = 3
SharedVirtualDiskCDPSnapshotsSupported: win32more.Windows.Win32.System.SystemServices.SharedVirtualDiskSupportType = 7
class TAPE_CREATE_PARTITION(Structure):
    Method: UInt32
    Count: UInt32
    Size: UInt32
TAPE_DRIVE_PROBLEM_TYPE = Int32
TapeDriveProblemNone: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 0
TapeDriveReadWriteWarning: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 1
TapeDriveReadWriteError: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 2
TapeDriveReadWarning: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 3
TapeDriveWriteWarning: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 4
TapeDriveReadError: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 5
TapeDriveWriteError: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 6
TapeDriveHardwareError: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 7
TapeDriveUnsupportedMedia: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 8
TapeDriveScsiConnectionError: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 9
TapeDriveTimetoClean: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 10
TapeDriveCleanDriveNow: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 11
TapeDriveMediaLifeExpired: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 12
TapeDriveSnappedTape: win32more.Windows.Win32.System.SystemServices.TAPE_DRIVE_PROBLEM_TYPE = 13
class TAPE_GET_DRIVE_PARAMETERS(Structure):
    ECC: win32more.Windows.Win32.Foundation.BOOLEAN
    Compression: win32more.Windows.Win32.Foundation.BOOLEAN
    DataPadding: win32more.Windows.Win32.Foundation.BOOLEAN
    ReportSetmarks: win32more.Windows.Win32.Foundation.BOOLEAN
    DefaultBlockSize: UInt32
    MaximumBlockSize: UInt32
    MinimumBlockSize: UInt32
    MaximumPartitionCount: UInt32
    FeaturesLow: UInt32
    FeaturesHigh: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH
    EOTWarningZoneSize: UInt32
TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = UInt32
TAPE_DRIVE_ABS_BLK_IMMED: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147491840
TAPE_DRIVE_ABSOLUTE_BLK: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147487744
TAPE_DRIVE_END_OF_DATA: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147549184
TAPE_DRIVE_FILEMARKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147745792
TAPE_DRIVE_LOAD_UNLOAD: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483649
TAPE_DRIVE_LOAD_UNLD_IMMED: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483680
TAPE_DRIVE_LOCK_UNLOCK: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483652
TAPE_DRIVE_LOCK_UNLK_IMMED: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483776
TAPE_DRIVE_LOG_BLK_IMMED: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147516416
TAPE_DRIVE_LOGICAL_BLK: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147500032
TAPE_DRIVE_RELATIVE_BLKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147614720
TAPE_DRIVE_REVERSE_POSITION: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2151677952
TAPE_DRIVE_REWIND_IMMEDIATE: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483656
TAPE_DRIVE_SEQUENTIAL_FMKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2148007936
TAPE_DRIVE_SEQUENTIAL_SMKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2149580800
TAPE_DRIVE_SET_BLOCK_SIZE: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483664
TAPE_DRIVE_SET_COMPRESSION: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147484160
TAPE_DRIVE_SET_ECC: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483904
TAPE_DRIVE_SET_PADDING: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147484672
TAPE_DRIVE_SET_REPORT_SMKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147485696
TAPE_DRIVE_SETMARKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2148532224
TAPE_DRIVE_SPACE_IMMEDIATE: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2155872256
TAPE_DRIVE_TENSION: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483650
TAPE_DRIVE_TENSION_IMMED: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2147483712
TAPE_DRIVE_WRITE_FILEMARKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2181038080
TAPE_DRIVE_WRITE_LONG_FMKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2281701376
TAPE_DRIVE_WRITE_MARK_IMMED: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2415919104
TAPE_DRIVE_WRITE_SETMARKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2164260864
TAPE_DRIVE_WRITE_SHORT_FMKS: win32more.Windows.Win32.System.SystemServices.TAPE_GET_DRIVE_PARAMETERS_FEATURES_HIGH = 2214592512
class TAPE_GET_MEDIA_PARAMETERS(Structure):
    Capacity: Int64
    Remaining: Int64
    BlockSize: UInt32
    PartitionCount: UInt32
    WriteProtected: win32more.Windows.Win32.Foundation.BOOLEAN
class TAPE_SET_DRIVE_PARAMETERS(Structure):
    ECC: win32more.Windows.Win32.Foundation.BOOLEAN
    Compression: win32more.Windows.Win32.Foundation.BOOLEAN
    DataPadding: win32more.Windows.Win32.Foundation.BOOLEAN
    ReportSetmarks: win32more.Windows.Win32.Foundation.BOOLEAN
    EOTWarningZoneSize: UInt32
class TAPE_SET_MEDIA_PARAMETERS(Structure):
    BlockSize: UInt32
class TAPE_WMI_OPERATIONS(Structure):
    Method: UInt32
    DataBufferSize: UInt32
    DataBuffer: VoidPtr
class TOKEN_BNO_ISOLATION_INFORMATION(Structure):
    IsolationPrefix: win32more.Windows.Win32.Foundation.PWSTR
    IsolationEnabled: win32more.Windows.Win32.Foundation.BOOLEAN
class TOKEN_SID_INFORMATION(Structure):
    Sid: win32more.Windows.Win32.Security.PSID
class TRANSACTIONMANAGER_BASIC_INFORMATION(Structure):
    TmIdentity: Guid
    VirtualClock: Int64
TRANSACTIONMANAGER_INFORMATION_CLASS = Int32
TransactionManagerBasicInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTIONMANAGER_INFORMATION_CLASS = 0
TransactionManagerLogInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTIONMANAGER_INFORMATION_CLASS = 1
TransactionManagerLogPathInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTIONMANAGER_INFORMATION_CLASS = 2
TransactionManagerRecoveryInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTIONMANAGER_INFORMATION_CLASS = 4
TransactionManagerOnlineProbeInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTIONMANAGER_INFORMATION_CLASS = 3
TransactionManagerOldestTransactionInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTIONMANAGER_INFORMATION_CLASS = 5
class TRANSACTIONMANAGER_LOGPATH_INFORMATION(Structure):
    LogPathLength: UInt32
    LogPath: Char * 1
class TRANSACTIONMANAGER_LOG_INFORMATION(Structure):
    LogIdentity: Guid
class TRANSACTIONMANAGER_OLDEST_INFORMATION(Structure):
    OldestTransactionGuid: Guid
class TRANSACTIONMANAGER_RECOVERY_INFORMATION(Structure):
    LastRecoveredLsn: UInt64
class TRANSACTION_BASIC_INFORMATION(Structure):
    TransactionId: Guid
    State: UInt32
    Outcome: UInt32
class TRANSACTION_BIND_INFORMATION(Structure):
    TmHandle: win32more.Windows.Win32.Foundation.HANDLE
class TRANSACTION_ENLISTMENTS_INFORMATION(Structure):
    NumberOfEnlistments: UInt32
    EnlistmentPair: win32more.Windows.Win32.System.SystemServices.TRANSACTION_ENLISTMENT_PAIR * 1
class TRANSACTION_ENLISTMENT_PAIR(Structure):
    EnlistmentId: Guid
    ResourceManagerId: Guid
TRANSACTION_INFORMATION_CLASS = Int32
TransactionBasicInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTION_INFORMATION_CLASS = 0
TransactionPropertiesInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTION_INFORMATION_CLASS = 1
TransactionEnlistmentInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTION_INFORMATION_CLASS = 2
TransactionSuperiorEnlistmentInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTION_INFORMATION_CLASS = 3
TransactionBindInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTION_INFORMATION_CLASS = 4
TransactionDTCPrivateInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTION_INFORMATION_CLASS = 5
class TRANSACTION_LIST_ENTRY(Structure):
    UOW: Guid
class TRANSACTION_LIST_INFORMATION(Structure):
    NumberOfTransactions: UInt32
    TransactionInformation: win32more.Windows.Win32.System.SystemServices.TRANSACTION_LIST_ENTRY * 1
class TRANSACTION_PROPERTIES_INFORMATION(Structure):
    IsolationLevel: UInt32
    IsolationFlags: UInt32
    Timeout: Int64
    Outcome: UInt32
    DescriptionLength: UInt32
    Description: Char * 1
TRANSACTION_STATE = Int32
TransactionStateNormal: win32more.Windows.Win32.System.SystemServices.TRANSACTION_STATE = 1
TransactionStateIndoubt: win32more.Windows.Win32.System.SystemServices.TRANSACTION_STATE = 2
TransactionStateCommittedNotify: win32more.Windows.Win32.System.SystemServices.TRANSACTION_STATE = 3
class TRANSACTION_SUPERIOR_ENLISTMENT_INFORMATION(Structure):
    SuperiorEnlistmentPair: win32more.Windows.Win32.System.SystemServices.TRANSACTION_ENLISTMENT_PAIR
class UMS_CREATE_THREAD_ATTRIBUTES(Structure):
    UmsVersion: UInt32
    UmsContext: VoidPtr
    UmsCompletionList: VoidPtr
WORD_WHEEL_OPEN_FLAGS = UInt32
ITWW_OPEN_CONNECT: win32more.Windows.Win32.System.SystemServices.WORD_WHEEL_OPEN_FLAGS = 0
class XSAVE_CET_U_FORMAT(Structure):
    Ia32CetUMsr: UInt64
    Ia32Pl3SspMsr: UInt64
class remoteMETAFILEPICT(Structure):
    mm: Int32
    xExt: Int32
    yExt: Int32
    hMF: POINTER(win32more.Windows.Win32.System.SystemServices.userHMETAFILE)
class userBITMAP(Structure):
    bmType: Int32
    bmWidth: Int32
    bmHeight: Int32
    bmWidthBytes: Int32
    bmPlanes: UInt16
    bmBitsPixel: UInt16
    cbSize: UInt32
    pBuffer: Byte * 1
class userCLIPFORMAT(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        dwValue: UInt32
        pwszName: win32more.Windows.Win32.Foundation.PWSTR
class userHBITMAP(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        hInproc: Int32
        hRemote: POINTER(win32more.Windows.Win32.System.SystemServices.userBITMAP)
        hInproc64: Int64
class userHENHMETAFILE(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        hInproc: Int32
        hRemote: POINTER(win32more.Windows.Win32.System.Com.BYTE_BLOB)
        hInproc64: Int64
class userHGLOBAL(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        hInproc: Int32
        hRemote: POINTER(win32more.Windows.Win32.System.Com.FLAGGED_BYTE_BLOB)
        hInproc64: Int64
class userHMETAFILE(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        hInproc: Int32
        hRemote: POINTER(win32more.Windows.Win32.System.Com.BYTE_BLOB)
        hInproc64: Int64
class userHMETAFILEPICT(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        hInproc: Int32
        hRemote: POINTER(win32more.Windows.Win32.System.SystemServices.remoteMETAFILEPICT)
        hInproc64: Int64
class userHPALETTE(Structure):
    fContext: Int32
    u: _u_e__Struct
    class _u_e__Struct(Union):
        hInproc: Int32
        hRemote: POINTER(win32more.Windows.Win32.Graphics.Gdi.LOGPALETTE)
        hInproc64: Int64


make_ready(__name__)
